# electron-releases

![Test](https://github.com/electron/releases/workflows/Test/badge.svg)

> Complete and up-to-date info about every release of Electron.

This package:

- includes all [GitHub Releases](https://developer.github.com/v3/repos/releases/#get-a-single-release) data about Electron.
- does not include draft releases.
- includes prereleases which are not published to npm.
- tracks which versions are published to npm.
- tracks [npm dist-tags](https://docs.npmjs.com/cli/dist-tag) like `latest` and `beta`.
- includes V8, Chromium, and Node.js version data.
- includes [GitHub-flavored HTML](https://ghub.io/hubdown) for each release's changelog.
- ignores npm versions from the days before [Electron was `electron`](https://electronjs.org/blog/npm-install-electron).
- is [updated regularly](#updates).

## Sources

This module collects metadata from various sources:

- [GitHub Releases of `electron/electron`](https://github.com/electron/electron)
- [dist-tags from npm registry for `electron`](https://registry.npmjs.com/electron)
- [dist-tags from npm registry `electron-prebuilt`](https://registry.npmjs.com/electron-prebuilt)
- [Dependency data for Chromium, Node.js, V8, etc](https://atom.io/download/electron/index.json)

## Installation

```sh
npm i electron-releases
```

## Usage

The module exports an array of release objects:

```js
const releases = require('electron-releases')

// find newest version:
releases[0].tag_name // => 'v1.8.2-beta.3'

// find `latest` on npm, which is not necessarily the most recent release:
releases.find(release => release.npm_dist_tag === 'latest')

// find `beta` on npm:
releases.find(release => release.npm_dist_tag === 'beta')
```

### Lite Version

The default export is about 75MB, as it includes a lot of metadata from the
GitHub API like release assets.

If you just need the basic info like version numbers, npm dist tags, and publish dates, there's a much smaller (<500K) dataset you can use:

```js
require('electron-releases/lite.json')
```

You can also get this at [unpkg.com/electron-releases/lite.json](https://unpkg.com/electron-releases/lite.json)

### Data

Each release contains all the data returned by the
[GitHub Releases API](https://docs.github.com/en/free-pro-team@latest/rest/reference/repos#releases),
plus some extra properties:

- `version` (String) - the same thing as `dist_tag`, but without the `v` for convenient [semver comparisons](https://github.com/npm/node-semver#usage).
- `npm_dist_tags` (Array<String>) - an array of [npm dist-tags](https://docs.npmjs.com/cli/dist-tag) like `"latest"` or `"beta"`. Most releases will have an empty array for this property.
- `npm_package_name` (String) - For packages published to npm, this will be `electron` or `electron-prebuilt`. For packages not published to npm, this property will not exist.
- `total_downloads` (Number) - Total downloads of all assets in the release that
  have a [detectable platform](https://github.com/zeke/platform-utils#api) in their
  filename like `.zip`, `.dmg`, `.exe`, `.rpm`, `.deb`, etc.
- `deps` (Object) - version numbers for Electron dependencies.
  - `v8` (String)
  - `chromium` (String)
  - `node` (String)
  - etc..

## Updates

This module is self-publishing. It runs in a GitHub Action cron job every
six hours. A new version of this module is published if any of
the following change:

- number of Electron releases on GitHub
- number of Electron releases on npm
- npm `electron@beta` version
- npm `electron@latest` version

If none of these has changed, the build process aborts and runs again ten minutes
later. For more detail, see [script/release.sh](script/release.sh)

The Heroku app is also synced to the GitHub repo, so every push to the
`master` branch will automatically deploy a new version of this app.

### Manually update

If you need to modify any file in the `script` folder, you'll also want
to manually regenerate this module's output files. You can do so with
the following steps:

1. Create a [personal access token](https://help.github.com/articles/creating-a-personal-access-token-for-the-command-line/#creating-a-token). Note that if Electron maintainers must enable SSO
for the `electron` org for this token to work.
1. Copy the `.env.example` file into a separate `.env` file.
    ```sh
    cp .env.example .env
    ```
1. Paste your token into the `GH_TOKEN` field of the `.env` file.
1. Build the module.
    ```sh
    npm run build
    ```
1. Check if all tests passed:
    ```sh
    npm test
    ```

## Tests

```sh
npm install
npm test
```

## License

MIT

## Releases

<!-- START RELEASES TABLE -->
|Tag|Published|npm|Prerelease|Module Version|Node|Chrome|Downloads|
|----|----|----|----|----|----|----|----|
|[v23.0.0-nightly.20221013](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221013)|2022-10-13||yes|110|16.17.1|108.0.5329.0|132|
|[v23.0.0-nightly.20221012](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221012)|2022-10-12|nightly|yes|110|16.17.1|108.0.5329.0|162|
|[v23.0.0-nightly.20221011](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221011)|2022-10-11||yes|110|16.17.1|108.0.5329.0|157|
|[v23.0.0-nightly.20221010](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221010)|2022-10-11||yes|110|16.17.1|108.0.5329.0|165|
|[v23.0.0-nightly.20221007](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221007)|2022-10-07||yes|110|16.17.1|108.0.5329.0|242|
|[v23.0.0-nightly.20221006](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221006)|2022-10-06||yes|110|16.17.1|108.0.5329.0|176|
|[v23.0.0-nightly.20221005](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221005)|2022-10-05||yes|110|16.17.1|108.0.5329.0|166|
|[v23.0.0-nightly.20221004](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221004)|2022-10-04||yes|110|16.17.1|108.0.5329.0|179|
|[v23.0.0-nightly.20221003](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20221003)|2022-10-03||yes|110|16.17.1|107.0.5286.0|187|
|[v23.0.0-nightly.20220930](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20220930)|2022-09-30||yes|110|16.17.1|107.0.5286.0|243|
|[v23.0.0-nightly.20220929](https://github.com/electron/electron/releases/tag/v23.0.0-nightly.20220929)|2022-09-29||yes|110|16.17.1|107.0.5286.0|197|
|[v22.0.0-nightly.20220928](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220928)|2022-09-28||yes|110|16.17.1|107.0.5286.0|175|
|[v22.0.0-nightly.20220927](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220927)|2022-09-27||yes|110|16.17.1|107.0.5286.0|181|
|[v22.0.0-nightly.20220926](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220926)|2022-09-26||yes|110|16.17.1|107.0.5286.0|190|
|[v22.0.0-nightly.20220923](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220923)|2022-09-23||yes|109|16.17.0|107.0.5286.0|326|
|[v22.0.0-nightly.20220922](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220922)|2022-09-22||yes|109|16.17.0|107.0.5286.0|241|
|[v22.0.0-nightly.20220921](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220921)|2022-09-21||yes|109|16.17.0|107.0.5286.0|246|
|[v22.0.0-nightly.20220920](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220920)|2022-09-20||yes|109|16.17.0|107.0.5286.0|261|
|[v22.0.0-nightly.20220919](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220919)|2022-09-19||yes|109|16.17.0|107.0.5286.0|245|
|[v22.0.0-nightly.20220916](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220916)|2022-09-16||yes|109|16.17.0|107.0.5286.0|300|
|[v22.0.0-nightly.20220915](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220915)|2022-09-15||yes|109|16.17.0|107.0.5286.0|254|
|[v22.0.0-nightly.20220914](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220914)|2022-09-14||yes|109|16.17.0|107.0.5286.0|255|
|[v22.0.0-nightly.20220913](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220913)|2022-09-13||yes|109|16.17.0|107.0.5286.0|315|
|[v22.0.0-nightly.20220912](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220912)|2022-09-12||yes|109|16.17.0|107.0.5286.0|246|
|[v22.0.0-nightly.20220909](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220909)|2022-09-09||yes|109|16.17.0|107.0.5286.0|309|
|[v22.0.0-nightly.20220908](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220908)|2022-09-08||yes|109|16.17.0|107.0.5274.0|257|
|[v22.0.0-nightly.20220905](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220905)|2022-09-05||yes|109|16.17.0|106.0.5216.0|443|
|[v22.0.0-nightly.20220902](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220902)|2022-09-02||yes|109|16.17.0|106.0.5216.0|290|
|[v22.0.0-nightly.20220901](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220901)|2022-09-01||yes|109|16.17.0|106.0.5216.0|280|
|[v22.0.0-nightly.20220831](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220831)|2022-08-31||yes|109|16.17.0|106.0.5216.0|326|
|[v22.0.0-nightly.20220830](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220830)|2022-08-30||yes|109|16.17.0|106.0.5216.0|309|
|[v22.0.0-nightly.20220829](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220829)|2022-08-29||yes|109|16.16.0|106.0.5216.0|306|
|[v22.0.0-nightly.20220825](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220825)|2022-08-26||yes|109|16.16.0|106.0.5216.0|352|
|[v22.0.0-nightly.20220824](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220824)|2022-08-24||yes|109|16.16.0|106.0.5216.0|332|
|[v22.0.0-nightly.20220823](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220823)|2022-08-23||yes|109|16.16.0|106.0.5216.0|295|
|[v22.0.0-nightly.20220822](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220822)|2022-08-22||yes|109|16.16.0|106.0.5216.0|304|
|[v22.0.0-nightly.20220817](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220817)|2022-08-17||yes|109|16.16.0|105.0.5187.0|396|
|[v22.0.0-nightly.20220816](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220816)|2022-08-16||yes|109|16.16.0|105.0.5187.0|313|
|[v22.0.0-nightly.20220815](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220815)|2022-08-15||yes|109|16.16.0|105.0.5187.0|301|
|[v22.0.0-nightly.20220812](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220812)|2022-08-12||yes|109|16.16.0|105.0.5187.0|411|
|[v22.0.0-nightly.20220811](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220811)|2022-08-11||yes|109|16.16.0|105.0.5187.0|348|
|[v22.0.0-nightly.20220810](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220810)|2022-08-10||yes|109|16.16.0|105.0.5187.0|350|
|[v22.0.0-nightly.20220809](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220809)|2022-08-09||yes|109|16.16.0|105.0.5187.0|183|
|[v22.0.0-nightly.20220808](https://github.com/electron/electron/releases/tag/v22.0.0-nightly.20220808)|2022-08-08||yes|109|16.16.0|105.0.5187.0|343|
|[v22.0.0-alpha.5](https://github.com/electron/electron/releases/tag/v22.0.0-alpha.5)|2022-10-13||yes|110|16.17.1|108.0.5329.0|141|
|[v22.0.0-alpha.4](https://github.com/electron/electron/releases/tag/v22.0.0-alpha.4)|2022-10-11|alpha, alpha-22-x-y|yes|110|16.17.1|108.0.5329.0|671|
|[v22.0.0-alpha.3](https://github.com/electron/electron/releases/tag/v22.0.0-alpha.3)|2022-10-06||yes|110|16.17.1|108.0.5329.0|1024|
|[v22.0.0-alpha.1](https://github.com/electron/electron/releases/tag/v22.0.0-alpha.1)|2022-09-28||yes|110|16.17.1|107.0.5286.0|1382|
|[v21.1.1](https://github.com/electron/electron/releases/tag/v21.1.1)|2022-10-12|latest, 21-x-y|no|109|16.16.0|106.0.5249.103|6271|
|[v21.1.0](https://github.com/electron/electron/releases/tag/v21.1.0)|2022-10-05||no|109|16.16.0|106.0.5249.91|42183|
|[v21.0.1](https://github.com/electron/electron/releases/tag/v21.0.1)|2022-09-28||no|109|16.16.0|106.0.5249.61|61772|
|[v21.0.0](https://github.com/electron/electron/releases/tag/v21.0.0)|2022-09-26||no|109|16.16.0|106.0.5249.51|20718|
|[v21.0.0-nightly.20220802](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220802)|2022-08-02||yes|107|16.16.0|105.0.5187.0|520|
|[v21.0.0-nightly.20220801](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220801)|2022-08-01||yes|107|16.16.0|105.0.5187.0|343|
|[v21.0.0-nightly.20220728](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220728)|2022-07-28||yes|107|16.16.0|105.0.5187.0|429|
|[v21.0.0-nightly.20220727](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220727)|2022-07-27||yes|107|16.16.0|105.0.5187.0|360|
|[v21.0.0-nightly.20220726](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220726)|2022-07-26||yes|107|16.16.0|105.0.5187.0|330|
|[v21.0.0-nightly.20220725](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220725)|2022-07-25||yes|107|16.15.1|105.0.5187.0|394|
|[v21.0.0-nightly.20220722](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220722)|2022-07-22||yes|107|16.15.1|105.0.5187.0|380|
|[v21.0.0-nightly.20220721](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220721)|2022-07-21||yes|107|16.15.1|105.0.5187.0|352|
|[v21.0.0-nightly.20220720](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220720)|2022-07-20||yes|107|16.15.1|105.0.5187.0|338|
|[v21.0.0-nightly.20220719](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220719)|2022-07-19||yes|107|16.15.1|105.0.5173.0|343|
|[v21.0.0-nightly.20220718](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220718)|2022-07-18||yes|107|16.15.1|105.0.5173.0|347|
|[v21.0.0-nightly.20220715](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220715)|2022-07-16||yes|107|16.15.1|105.0.5173.0|405|
|[v21.0.0-nightly.20220713](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220713)|2022-07-13||yes|107|16.15.1|105.0.5129.0|395|
|[v21.0.0-nightly.20220712](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220712)|2022-07-12||yes|107|16.15.1|105.0.5129.0|169|
|[v21.0.0-nightly.20220711](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220711)|2022-07-11||yes|107|16.15.1|105.0.5129.0|353|
|[v21.0.0-nightly.20220708](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220708)|2022-07-08||yes|107|16.15.1|105.0.5129.0|276|
|[v21.0.0-nightly.20220707](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220707)|2022-07-07||yes|107|16.15.1|105.0.5129.0|343|
|[v21.0.0-nightly.20220706](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220706)|2022-07-06||yes|107|16.15.1|105.0.5129.0|171|
|[v21.0.0-nightly.20220705](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220705)|2022-07-05||yes|107|16.15.1|105.0.5129.0|179|
|[v21.0.0-nightly.20220704](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220704)|2022-07-04||yes|107|16.15.1|105.0.5129.0|167|
|[v21.0.0-nightly.20220701](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220701)|2022-07-01||yes|107|16.15.1|105.0.5129.0|226|
|[v21.0.0-nightly.20220630](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220630)|2022-06-30||yes|107|16.15.1|105.0.5129.0|362|
|[v21.0.0-nightly.20220629](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220629)|2022-06-29||yes|107|16.15.1|105.0.5129.0|347|
|[v21.0.0-nightly.20220628](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220628)|2022-06-29||yes|107|16.15.1|105.0.5129.0|341|
|[v21.0.0-nightly.20220627](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220627)|2022-06-27||yes|107|16.15.1|104.0.5073.0|350|
|[v21.0.0-nightly.20220624](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220624)|2022-06-24||yes|107|16.15.1|104.0.5073.0|384|
|[v21.0.0-nightly.20220623](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220623)|2022-06-23||yes|107|16.15.1|104.0.5073.0|348|
|[v21.0.0-nightly.20220622](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220622)|2022-06-22||yes|107|16.15.1|104.0.5073.0|348|
|[v21.0.0-nightly.20220621](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220621)|2022-06-21||yes|107|16.15.1|104.0.5073.0|159|
|[v21.0.0-nightly.20220620](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220620)|2022-06-20||yes|107|16.15.1|104.0.5073.0|166|
|[v21.0.0-nightly.20220617](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220617)|2022-06-17||yes|107|16.15.1|104.0.5073.0|394|
|[v21.0.0-nightly.20220616](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220616)|2022-06-16||yes|107|16.15.1|104.0.5073.0|340|
|[v21.0.0-nightly.20220615](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220615)|2022-06-15||yes|107|16.15.1|104.0.5073.0|342|
|[v21.0.0-nightly.20220614](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220614)|2022-06-14||yes|107|16.15.1|104.0.5073.0|330|
|[v21.0.0-nightly.20220613](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220613)|2022-06-13||yes|107|16.15.1|104.0.5073.0|290|
|[v21.0.0-nightly.20220610](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220610)|2022-06-10||yes|107|16.15.1|104.0.5073.0|353|
|[v21.0.0-nightly.20220609](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220609)|2022-06-09||yes|107|16.15.1|104.0.5073.0|301|
|[v21.0.0-nightly.20220608](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220608)|2022-06-08||yes|107|16.15.1|104.0.5073.0|296|
|[v21.0.0-nightly.20220607](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220607)|2022-06-07||yes|107|16.15.1|104.0.5073.0|295|
|[v21.0.0-nightly.20220606](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220606)|2022-06-06||yes|107|16.15.1|104.0.5073.0|299|
|[v21.0.0-nightly.20220603](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220603)|2022-06-03||yes|107|16.15.0|104.0.5073.0|414|
|[v21.0.0-nightly.20220602](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220602)|2022-06-03||yes|107|16.15.0|104.0.5073.0|295|
|[v21.0.0-nightly.20220531](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220531)|2022-05-31||yes|107|16.15.0|103.0.5044.0|328|
|[v21.0.0-nightly.20220530](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220530)|2022-05-30||yes|107|16.15.0|103.0.5044.0|307|
|[v21.0.0-nightly.20220527](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220527)|2022-05-27||yes|107|16.15.0|103.0.5044.0|358|
|[v21.0.0-nightly.20220526](https://github.com/electron/electron/releases/tag/v21.0.0-nightly.20220526)|2022-05-26||yes|107|16.15.0|103.0.5044.0|305|
|[v21.0.0-beta.8](https://github.com/electron/electron/releases/tag/v21.0.0-beta.8)|2022-09-22|beta, beta-21-x-y|yes|109|16.16.0|106.0.5249.40|2403|
|[v21.0.0-beta.7](https://github.com/electron/electron/releases/tag/v21.0.0-beta.7)|2022-09-19||yes|109|16.16.0|106.0.5249.40|2133|
|[v21.0.0-beta.6](https://github.com/electron/electron/releases/tag/v21.0.0-beta.6)|2022-09-15||yes|109|16.16.0|106.0.5249.40|1226|
|[v21.0.0-beta.5](https://github.com/electron/electron/releases/tag/v21.0.0-beta.5)|2022-09-12||yes|109|16.16.0|106.0.5216.0|1447|
|[v21.0.0-beta.4](https://github.com/electron/electron/releases/tag/v21.0.0-beta.4)|2022-09-08||yes|109|16.16.0|106.0.5216.0|2745|
|[v21.0.0-beta.3](https://github.com/electron/electron/releases/tag/v21.0.0-beta.3)|2022-09-07||yes|109|16.16.0|106.0.5216.0|1357|
|[v21.0.0-beta.2](https://github.com/electron/electron/releases/tag/v21.0.0-beta.2)|2022-09-01||yes|109|16.16.0|106.0.5216.0|1943|
|[v21.0.0-beta.1](https://github.com/electron/electron/releases/tag/v21.0.0-beta.1)|2022-08-30||yes|109|16.16.0|106.0.5216.0|1380|
|[v21.0.0-alpha.6](https://github.com/electron/electron/releases/tag/v21.0.0-alpha.6)|2022-08-30|alpha-21-x-y|yes|109|16.16.0|106.0.5216.0|1326|
|[v21.0.0-alpha.5](https://github.com/electron/electron/releases/tag/v21.0.0-alpha.5)|2022-08-23||yes|109|16.16.0|105.0.5187.0|1606|
|[v21.0.0-alpha.4](https://github.com/electron/electron/releases/tag/v21.0.0-alpha.4)|2022-08-18||yes|109|16.16.0|105.0.5187.0|1486|
|[v21.0.0-alpha.3](https://github.com/electron/electron/releases/tag/v21.0.0-alpha.3)|2022-08-15||yes|109|16.16.0|105.0.5187.0|1390|
|[v21.0.0-alpha.2](https://github.com/electron/electron/releases/tag/v21.0.0-alpha.2)|2022-08-11||yes|109|16.16.0|105.0.5187.0|1486|
|[v21.0.0-alpha.1](https://github.com/electron/electron/releases/tag/v21.0.0-alpha.1)|2022-08-03||yes|109|16.16.0|105.0.5187.0|1952|
|[v20.3.2](https://github.com/electron/electron/releases/tag/v20.3.2)|2022-10-12|20-x-y|no|107|16.15.0|104.0.5112.124|1666|
|[v20.3.1](https://github.com/electron/electron/releases/tag/v20.3.1)|2022-10-05||no|107|16.15.0|104.0.5112.124|9385|
|[v20.3.0](https://github.com/electron/electron/releases/tag/v20.3.0)|2022-09-28||no|107|16.15.0|104.0.5112.124|13078|
|[v20.2.0](https://github.com/electron/electron/releases/tag/v20.2.0)|2022-09-22||no|107|16.15.0|104.0.5112.124|56439|
|[v20.1.4](https://github.com/electron/electron/releases/tag/v20.1.4)|2022-09-14||no|107|16.15.0|104.0.5112.114|85994|
|[v20.1.3](https://github.com/electron/electron/releases/tag/v20.1.3)|2022-09-08||no|107|16.15.0|104.0.5112.114|67937|
|[v20.1.2](https://github.com/electron/electron/releases/tag/v20.1.2)|2022-09-07||no|107|16.15.0|104.0.5112.114|17548|
|[v20.1.1](https://github.com/electron/electron/releases/tag/v20.1.1)|2022-08-31||no|107|16.15.0|104.0.5112.102|71997|
|[v20.1.0](https://github.com/electron/electron/releases/tag/v20.1.0)|2022-08-24||no|107|16.15.0|104.0.5112.102|65702|
|[v20.0.3](https://github.com/electron/electron/releases/tag/v20.0.3)|2022-08-17||no|107|16.15.0|104.0.5112.81|112525|
|[v20.0.2](https://github.com/electron/electron/releases/tag/v20.0.2)|2022-08-10||no|107|16.15.0|104.0.5112.81|101087|
|[v20.0.1](https://github.com/electron/electron/releases/tag/v20.0.1)|2022-08-03||no|107|16.15.0|104.0.5112.81|95653|
|[v20.0.0](https://github.com/electron/electron/releases/tag/v20.0.0)|2022-08-01||no|107|16.15.0|104.0.5112.65|47610|
|[v20.0.0-nightly.20220524](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220524)|2022-05-24||yes|107|16.15.0|103.0.5044.0|406|
|[v20.0.0-nightly.20220523](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220523)|2022-05-23||yes|107|16.15.0|103.0.5044.0|330|
|[v20.0.0-nightly.20220520](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220520)|2022-05-20||yes|107|16.15.0|103.0.5044.0|357|
|[v20.0.0-nightly.20220519](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220519)|2022-05-19||yes|107|16.15.0|103.0.5044.0|300|
|[v20.0.0-nightly.20220518](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220518)|2022-05-18||yes|107|16.15.0|103.0.5044.0|380|
|[v20.0.0-nightly.20220517](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220517)|2022-05-17||yes|107|16.15.0|102.0.4999.0|323|
|[v20.0.0-nightly.20220516](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220516)|2022-05-16||yes|107|16.15.0|102.0.4999.0|178|
|[v20.0.0-nightly.20220513](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220513)|2022-05-13||yes|107|16.15.0|102.0.4999.0|385|
|[v20.0.0-nightly.20220512](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220512)|2022-05-12||yes|107|16.15.0|102.0.4999.0|383|
|[v20.0.0-nightly.20220511](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220511)|2022-05-11||yes|107|16.15.0|102.0.4999.0|441|
|[v20.0.0-nightly.20220509](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220509)|2022-05-09||yes|107|16.14.2|102.0.4999.0|319|
|[v20.0.0-nightly.20220506](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220506)|2022-05-06||yes|107|16.14.2|102.0.4999.0|337|
|[v20.0.0-nightly.20220505](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220505)|2022-05-05||yes|107|16.14.2|102.0.4999.0|189|
|[v20.0.0-nightly.20220504](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220504)|2022-05-04||yes|107|16.14.2|102.0.4999.0|150|
|[v20.0.0-nightly.20220503](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220503)|2022-05-03||yes|107|16.14.2|102.0.4999.0|295|
|[v20.0.0-nightly.20220502](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220502)|2022-05-02||yes|107|16.14.2|102.0.4999.0|291|
|[v20.0.0-nightly.20220429](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220429)|2022-04-29||yes|107|16.14.2|102.0.4999.0|180|
|[v20.0.0-nightly.20220428](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220428)|2022-04-28||yes|107|16.14.2|102.0.4999.0|300|
|[v20.0.0-nightly.20220427](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220427)|2022-04-27||yes|107|16.14.2|102.0.4999.0|288|
|[v20.0.0-nightly.20220426](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220426)|2022-04-27||yes|107|16.14.2|102.0.4999.0|290|
|[v20.0.0-nightly.20220425](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220425)|2022-04-26||yes|107|16.14.2|102.0.4999.0|286|
|[v20.0.0-nightly.20220421](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220421)|2022-04-21||yes|107|16.14.2|102.0.4989.0|411|
|[v20.0.0-nightly.20220420](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220420)|2022-04-20||yes|107|16.14.2|102.0.4989.0|186|
|[v20.0.0-nightly.20220419](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220419)|2022-04-19||yes|107|16.14.2|102.0.4989.0|326|
|[v20.0.0-nightly.20220418](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220418)|2022-04-18||yes|107|16.14.2|102.0.4989.0|334|
|[v20.0.0-nightly.20220415](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220415)|2022-04-15||yes|107|16.14.2|102.0.4989.0|379|
|[v20.0.0-nightly.20220414](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220414)|2022-04-15||yes|107|16.14.2|102.0.4989.0|329|
|[v20.0.0-nightly.20220411](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220411)|2022-04-11||yes|107|16.14.2|102.0.4971.0|423|
|[v20.0.0-nightly.20220330](https://github.com/electron/electron/releases/tag/v20.0.0-nightly.20220330)|2022-03-30||yes|107|16.14.2|102.0.4962.3|647|
|[v20.0.0-beta.13](https://github.com/electron/electron/releases/tag/v20.0.0-beta.13)|2022-07-28|beta-20-x-y|yes|107|16.15.0|104.0.5112.57|2859|
|[v20.0.0-beta.12](https://github.com/electron/electron/releases/tag/v20.0.0-beta.12)|2022-07-25||yes|107|16.15.0|104.0.5112.48|2826|
|[v20.0.0-beta.11](https://github.com/electron/electron/releases/tag/v20.0.0-beta.11)|2022-07-21||yes|107|16.15.0|104.0.5112.48|3018|
|[v20.0.0-beta.10](https://github.com/electron/electron/releases/tag/v20.0.0-beta.10)|2022-07-18||yes|107|16.15.0|104.0.5112.48|2756|
|[v20.0.0-beta.9](https://github.com/electron/electron/releases/tag/v20.0.0-beta.9)|2022-07-14||yes|107|16.15.0|104.0.5112.39|1899|
|[v20.0.0-beta.8](https://github.com/electron/electron/releases/tag/v20.0.0-beta.8)|2022-07-11||yes|107|16.15.0|104.0.5073.0|4116|
|[v20.0.0-beta.7](https://github.com/electron/electron/releases/tag/v20.0.0-beta.7)|2022-07-08||yes|107|16.15.0|104.0.5073.0|1543|
|[v20.0.0-beta.6](https://github.com/electron/electron/releases/tag/v20.0.0-beta.6)|2022-07-07||yes|107|16.15.0|104.0.5073.0|1235|
|[v20.0.0-beta.5](https://github.com/electron/electron/releases/tag/v20.0.0-beta.5)|2022-07-04||yes|107|16.15.0|104.0.5073.0|1510|
|[v20.0.0-beta.4](https://github.com/electron/electron/releases/tag/v20.0.0-beta.4)|2022-06-30||yes|107|16.15.0|104.0.5073.0|1235|
|[v20.0.0-beta.3](https://github.com/electron/electron/releases/tag/v20.0.0-beta.3)|2022-06-27||yes|107|16.15.0|104.0.5073.0|1655|
|[v20.0.0-beta.2](https://github.com/electron/electron/releases/tag/v20.0.0-beta.2)|2022-06-23||yes|107|16.15.0|104.0.5073.0|1688|
|[v20.0.0-beta.1](https://github.com/electron/electron/releases/tag/v20.0.0-beta.1)|2022-06-21||yes|107|16.15.0|104.0.5073.0|1649|
|[v20.0.0-alpha.7](https://github.com/electron/electron/releases/tag/v20.0.0-alpha.7)|2022-06-20|alpha-20-x-y|yes|107|16.15.0|104.0.5073.0|1771|
|[v20.0.0-alpha.6](https://github.com/electron/electron/releases/tag/v20.0.0-alpha.6)|2022-06-16||yes|107|16.15.0|104.0.5073.0|1506|
|[v20.0.0-alpha.5](https://github.com/electron/electron/releases/tag/v20.0.0-alpha.5)|2022-06-13||yes|107|16.15.0|104.0.5073.0|1579|
|[v20.0.0-alpha.4](https://github.com/electron/electron/releases/tag/v20.0.0-alpha.4)|2022-06-09||yes|107|16.15.0|104.0.5073.0|1498|
|[v20.0.0-alpha.3](https://github.com/electron/electron/releases/tag/v20.0.0-alpha.3)|2022-06-06||yes|107|16.15.0|104.0.5073.0|1787|
|[v20.0.0-alpha.2](https://github.com/electron/electron/releases/tag/v20.0.0-alpha.2)|2022-06-03||yes|107|16.15.0|104.0.5073.0|1401|
|[v20.0.0-alpha.1](https://github.com/electron/electron/releases/tag/v20.0.0-alpha.1)|2022-05-25||yes|107|16.15.0|103.0.5044.0|2230|
|[v19.1.3](https://github.com/electron/electron/releases/tag/v19.1.3)|2022-10-12|19-x-y|no|106|16.14.2|102.0.5005.167|1604|
|[v19.1.2](https://github.com/electron/electron/releases/tag/v19.1.2)|2022-10-05||no|106|16.14.2|102.0.5005.167|8374|
|[v19.1.1](https://github.com/electron/electron/releases/tag/v19.1.1)|2022-09-28||no|106|16.14.2|102.0.5005.167|15575|
|[v19.1.0](https://github.com/electron/electron/releases/tag/v19.1.0)|2022-09-23||no|106|16.14.2|102.0.5005.167|15742|
|[v19.0.17](https://github.com/electron/electron/releases/tag/v19.0.17)|2022-09-14||no|106|16.14.2|102.0.5005.167|59207|
|[v19.0.16](https://github.com/electron/electron/releases/tag/v19.0.16)|2022-09-08||no|106|16.14.2|102.0.5005.167|32374|
|[v19.0.15](https://github.com/electron/electron/releases/tag/v19.0.15)|2022-08-31||no|106|16.14.2|102.0.5005.167|32860|
|[v19.0.14](https://github.com/electron/electron/releases/tag/v19.0.14)|2022-08-24||no|106|16.14.2|102.0.5005.167|22733|
|[v19.0.13](https://github.com/electron/electron/releases/tag/v19.0.13)|2022-08-17||no|106|16.14.2|102.0.5005.167|31168|
|[v19.0.12](https://github.com/electron/electron/releases/tag/v19.0.12)|2022-08-10||no|106|16.14.2|102.0.5005.167|65548|
|[v19.0.11](https://github.com/electron/electron/releases/tag/v19.0.11)|2022-08-03||no|106|16.14.2|102.0.5005.167|69764|
|[v19.0.10](https://github.com/electron/electron/releases/tag/v19.0.10)|2022-07-27||no|106|16.14.2|102.0.5005.167|115048|
|[v19.0.9](https://github.com/electron/electron/releases/tag/v19.0.9)|2022-07-21||no|106|16.14.2|102.0.5005.167|105569|
|[v19.0.8](https://github.com/electron/electron/releases/tag/v19.0.8)|2022-07-06||no|106|16.14.2|102.0.5005.148|226879|
|[v19.0.7](https://github.com/electron/electron/releases/tag/v19.0.7)|2022-06-30||no|106|16.14.2|102.0.5005.134|120295|
|[v19.0.6](https://github.com/electron/electron/releases/tag/v19.0.6)|2022-06-22||no|106|16.14.2|102.0.5005.115|154378|
|[v19.0.5](https://github.com/electron/electron/releases/tag/v19.0.5)|2022-06-20||no|106|16.14.2|102.0.5005.115|34900|
|[v19.0.4](https://github.com/electron/electron/releases/tag/v19.0.4)|2022-06-08||no|106|16.14.2|102.0.5005.63|163477|
|[v19.0.3](https://github.com/electron/electron/releases/tag/v19.0.3)|2022-06-03||no|106|16.14.2|102.0.5005.63|102872|
|[v19.0.2](https://github.com/electron/electron/releases/tag/v19.0.2)|2022-06-01||no|106|16.14.2|102.0.5005.63|41133|
|[v19.0.1](https://github.com/electron/electron/releases/tag/v19.0.1)|2022-05-25||no|106|16.14.2|102.0.5005.61|57220|
|[v19.0.0](https://github.com/electron/electron/releases/tag/v19.0.0)|2022-05-23||no|106|16.14.2|102.0.5005.61|71654|
|[v19.0.0-nightly.20220329](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220329)|2022-03-29||yes|106|16.14.2|102.0.4962.3|613|
|[v19.0.0-nightly.20220328](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220328)|2022-03-29||yes|106|16.14.2|102.0.4962.3|359|
|[v19.0.0-nightly.20220325](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220325)|2022-03-25||yes|106|16.14.2|102.0.4961.0|421|
|[v19.0.0-nightly.20220324](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220324)|2022-03-24||yes|106|16.14.2|100.0.4894.0|356|
|[v19.0.0-nightly.20220323](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220323)|2022-03-23||yes|106|16.13.2|100.0.4894.0|190|
|[v19.0.0-nightly.20220322](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220322)|2022-03-23||yes|106|16.13.2|100.0.4894.0|333|
|[v19.0.0-nightly.20220321](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220321)|2022-03-21||yes|106|16.13.2|100.0.4894.0|360|
|[v19.0.0-nightly.20220318](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220318)|2022-03-18||yes|106|16.13.2|100.0.4894.0|394|
|[v19.0.0-nightly.20220317](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220317)|2022-03-17||yes|106|16.13.2|100.0.4894.0|357|
|[v19.0.0-nightly.20220316](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220316)|2022-03-16||yes|106|16.13.2|100.0.4894.0|491|
|[v19.0.0-nightly.20220315](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220315)|2022-03-15||yes|106|16.13.2|100.0.4894.0|356|
|[v19.0.0-nightly.20220314](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220314)|2022-03-14||yes|106|16.13.2|100.0.4894.0|204|
|[v19.0.0-nightly.20220311](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220311)|2022-03-11||yes|106|16.13.2|100.0.4894.0|372|
|[v19.0.0-nightly.20220310](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220310)|2022-03-10||yes|106|16.13.2|100.0.4894.0|191|
|[v19.0.0-nightly.20220309](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220309)|2022-03-09||yes|106|16.13.2|100.0.4894.0|395|
|[v19.0.0-nightly.20220308](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220308)|2022-03-08||yes|106|16.13.2|100.0.4894.0|352|
|[v19.0.0-nightly.20220209](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220209)|2022-02-09||yes|106|16.13.2|99.0.4767.0|1400|
|[v19.0.0-nightly.20220208](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220208)|2022-02-08||yes|106|16.13.2|99.0.4767.0|315|
|[v19.0.0-nightly.20220207](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220207)|2022-02-07||yes|106|16.13.2|99.0.4767.0|324|
|[v19.0.0-nightly.20220204](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220204)|2022-02-04||yes|106|16.13.2|99.0.4767.0|444|
|[v19.0.0-nightly.20220203](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220203)|2022-02-03||yes|106|16.13.2|99.0.4767.0|328|
|[v19.0.0-nightly.20220202](https://github.com/electron/electron/releases/tag/v19.0.0-nightly.20220202)|2022-02-02||yes|103|16.13.2|99.0.4767.0|321|
|[v19.0.0-beta.8](https://github.com/electron/electron/releases/tag/v19.0.0-beta.8)|2022-05-19|beta-19-x-y|yes|106|16.14.2|102.0.5005.49|3632|
|[v19.0.0-beta.7](https://github.com/electron/electron/releases/tag/v19.0.0-beta.7)|2022-05-16||yes|106|16.14.2|102.0.5005.40|3468|
|[v19.0.0-beta.6](https://github.com/electron/electron/releases/tag/v19.0.0-beta.6)|2022-05-12||yes|106|16.14.2|102.0.5005.40|3011|
|[v19.0.0-beta.5](https://github.com/electron/electron/releases/tag/v19.0.0-beta.5)|2022-05-09||yes|106|16.14.2|102.0.5005.40|3110|
|[v19.0.0-beta.4](https://github.com/electron/electron/releases/tag/v19.0.0-beta.4)|2022-05-05||yes|106|16.14.2|102.0.5005.27|4767|
|[v19.0.0-beta.3](https://github.com/electron/electron/releases/tag/v19.0.0-beta.3)|2022-05-02||yes|106|16.14.2|102.0.4999.0|2252|
|[v19.0.0-beta.2](https://github.com/electron/electron/releases/tag/v19.0.0-beta.2)|2022-04-29||yes|106|16.14.2|102.0.4999.0|1714|
|[v19.0.0-beta.1](https://github.com/electron/electron/releases/tag/v19.0.0-beta.1)|2022-04-28||yes|106|16.14.2|102.0.4999.0|2073|
|[v19.0.0-alpha.5](https://github.com/electron/electron/releases/tag/v19.0.0-alpha.5)|2022-04-25|alpha-19-x-y|yes|106|16.14.2|102.0.4989.0|2104|
|[v19.0.0-alpha.4](https://github.com/electron/electron/releases/tag/v19.0.0-alpha.4)|2022-04-21||yes|106|16.14.2|102.0.4989.0|2592|
|[v19.0.0-alpha.3](https://github.com/electron/electron/releases/tag/v19.0.0-alpha.3)|2022-04-18||yes|106|16.14.2|102.0.4971.0|2104|
|[v19.0.0-alpha.2](https://github.com/electron/electron/releases/tag/v19.0.0-alpha.2)|2022-04-15||yes|106|16.14.2|102.0.4971.0|2419|
|[v19.0.0-alpha.1](https://github.com/electron/electron/releases/tag/v19.0.0-alpha.1)|2022-03-30||yes|106|16.14.2|102.0.4962.3|2791|
|[v18.3.15](https://github.com/electron/electron/releases/tag/v18.3.15)|2022-09-27|18-x-y|no|103|16.13.2|100.0.4896.160|11570|
|[v18.3.14](https://github.com/electron/electron/releases/tag/v18.3.14)|2022-09-24||no|103|16.13.2|100.0.4896.160|3794|
|[v18.3.13](https://github.com/electron/electron/releases/tag/v18.3.13)|2022-09-14||no|103|16.13.2|100.0.4896.160|9678|
|[v18.3.12](https://github.com/electron/electron/releases/tag/v18.3.12)|2022-09-08||no|103|16.13.2|100.0.4896.160|6045|
|[v18.3.11](https://github.com/electron/electron/releases/tag/v18.3.11)|2022-08-31||no|103|16.13.2|100.0.4896.160|10147|
|[v18.3.9](https://github.com/electron/electron/releases/tag/v18.3.9)|2022-08-17||no|103|16.13.2|100.0.4896.160|20034|
|[v18.3.8](https://github.com/electron/electron/releases/tag/v18.3.8)|2022-08-10||no|103|16.13.2|100.0.4896.160|10231|
|[v18.3.7](https://github.com/electron/electron/releases/tag/v18.3.7)|2022-08-03||no|103|16.13.2|100.0.4896.160|11598|
|[v18.3.6](https://github.com/electron/electron/releases/tag/v18.3.6)|2022-07-28||no|103|16.13.2|100.0.4896.160|17815|
|[v18.3.5](https://github.com/electron/electron/releases/tag/v18.3.5)|2022-06-22||no|103|16.13.2|100.0.4896.160|177977|
|[v18.3.4](https://github.com/electron/electron/releases/tag/v18.3.4)|2022-06-15||no|103|16.13.2|100.0.4896.160|38652|
|[v18.3.3](https://github.com/electron/electron/releases/tag/v18.3.3)|2022-06-08||no|103|16.13.2|100.0.4896.160|24344|
|[v18.3.2](https://github.com/electron/electron/releases/tag/v18.3.2)|2022-06-01||no|103|16.13.2|100.0.4896.160|25298|
|[v18.3.1](https://github.com/electron/electron/releases/tag/v18.3.1)|2022-05-25||no|103|16.13.2|100.0.4896.160|36637|
|[v18.3.0](https://github.com/electron/electron/releases/tag/v18.3.0)|2022-05-23||no|103|16.13.2|100.0.4896.160|48300|
|[v18.2.4](https://github.com/electron/electron/releases/tag/v18.2.4)|2022-05-18||no|103|16.13.2|100.0.4896.160|82505|
|[v18.2.3](https://github.com/electron/electron/releases/tag/v18.2.3)|2022-05-11||no|103|16.13.2|100.0.4896.143|127830|
|[v18.2.2](https://github.com/electron/electron/releases/tag/v18.2.2)|2022-05-11||no|103|16.13.2|100.0.4896.143|40704|
|[v18.2.1](https://github.com/electron/electron/releases/tag/v18.2.1)|2022-05-04||no|103|16.13.2|100.0.4896.143|4920|
|[v18.2.0](https://github.com/electron/electron/releases/tag/v18.2.0)|2022-04-29||no|103|16.13.2|100.0.4896.143|219158|
|[v18.1.0](https://github.com/electron/electron/releases/tag/v18.1.0)|2022-04-21||no|103|16.13.2|100.0.4896.127|265531|
|[v18.0.4](https://github.com/electron/electron/releases/tag/v18.0.4)|2022-04-14||no|103|16.13.2|100.0.4896.75|100615|
|[v18.0.3](https://github.com/electron/electron/releases/tag/v18.0.3)|2022-04-07||no|103|16.13.2|100.0.4896.75|199586|
|[v18.0.2](https://github.com/electron/electron/releases/tag/v18.0.2)|2022-04-05||no|103|16.13.2|100.0.4896.60|31082|
|[v18.0.1](https://github.com/electron/electron/releases/tag/v18.0.1)|2022-03-30||no|103|16.13.2|100.0.4896.60|124095|
|[v18.0.0](https://github.com/electron/electron/releases/tag/v18.0.0)|2022-03-29||no|103|16.13.2|100.0.4896.56|74102|
|[v18.0.0-nightly.20220201](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220201)|2022-02-01||yes|103|16.13.2|99.0.4767.0|189|
|[v18.0.0-nightly.20220131](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220131)|2022-01-31||yes|103|16.13.2|99.0.4767.0|244|
|[v18.0.0-nightly.20220128](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220128)|2022-01-28||yes|103|16.13.2|99.0.4767.0|394|
|[v18.0.0-nightly.20220127](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220127)|2022-01-27||yes|103|16.13.2|99.0.4767.0|206|
|[v18.0.0-nightly.20220125](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220125)|2022-01-25||yes|103|16.13.2|99.0.4767.0|372|
|[v18.0.0-nightly.20220124](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220124)|2022-01-24||yes|103|16.13.2|99.0.4767.0|351|
|[v18.0.0-nightly.20220121](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220121)|2022-01-21||yes|103|16.13.2|99.0.4767.0|383|
|[v18.0.0-nightly.20220119](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220119)|2022-01-19||yes|103|16.13.2|99.0.4767.0|367|
|[v18.0.0-nightly.20220118](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220118)|2022-01-18||yes|103|16.13.2|99.0.4767.0|333|
|[v18.0.0-nightly.20220117](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220117)|2022-01-17||yes|103|16.13.2|99.0.4767.0|353|
|[v18.0.0-nightly.20220114](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220114)|2022-01-14||yes|103|16.13.2|99.0.4767.0|404|
|[v18.0.0-nightly.20220113](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220113)|2022-01-13||yes|103|16.13.2|99.0.4767.0|320|
|[v18.0.0-nightly.20220112](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220112)|2022-01-12||yes|103|16.13.2|99.0.4767.0|341|
|[v18.0.0-nightly.20220111](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220111)|2022-01-11||yes|103|16.13.1|99.0.4767.0|337|
|[v18.0.0-nightly.20220110](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220110)|2022-01-10||yes|103|16.13.1|98.0.4706.0|326|
|[v18.0.0-nightly.20220107](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220107)|2022-01-07||yes|103|16.13.1|98.0.4706.0|383|
|[v18.0.0-nightly.20220106](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220106)|2022-01-06||yes|103|16.13.1|98.0.4706.0|330|
|[v18.0.0-nightly.20220105](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220105)|2022-01-05||yes|103|16.13.1|98.0.4706.0|327|
|[v18.0.0-nightly.20220104](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220104)|2022-01-04||yes|103|16.13.1|98.0.4706.0|311|
|[v18.0.0-nightly.20220103](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20220103)|2022-01-03||yes|103|16.13.1|98.0.4706.0|318|
|[v18.0.0-nightly.20211231](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211231)|2021-12-31||yes|103|16.13.1|98.0.4706.0|499|
|[v18.0.0-nightly.20211229](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211229)|2021-12-29||yes|103|16.13.1|98.0.4706.0|452|
|[v18.0.0-nightly.20211228](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211228)|2021-12-28||yes|103|16.13.1|98.0.4706.0|470|
|[v18.0.0-nightly.20211223](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211223)|2021-12-24||yes|103|16.13.1|98.0.4706.0|502|
|[v18.0.0-nightly.20211222](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211222)|2021-12-22||yes|103|16.13.1|98.0.4706.0|557|
|[v18.0.0-nightly.20211221](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211221)|2021-12-21||yes|103|16.13.1|98.0.4706.0|450|
|[v18.0.0-nightly.20211220](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211220)|2021-12-20||yes|103|16.13.1|98.0.4706.0|457|
|[v18.0.0-nightly.20211217](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211217)|2021-12-17||yes|103|16.13.1|98.0.4706.0|484|
|[v18.0.0-nightly.20211216](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211216)|2021-12-16||yes|103|16.13.0|98.0.4706.0|464|
|[v18.0.0-nightly.20211215](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211215)|2021-12-15||yes|103|16.13.0|98.0.4706.0|542|
|[v18.0.0-nightly.20211214](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211214)|2021-12-14||yes|103|16.13.0|98.0.4706.0|541|
|[v18.0.0-nightly.20211213](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211213)|2021-12-13||yes|103|16.13.0|98.0.4706.0|529|
|[v18.0.0-nightly.20211210](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211210)|2021-12-10||yes|103|16.13.0|98.0.4706.0|605|
|[v18.0.0-nightly.20211209](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211209)|2021-12-09||yes|103|16.13.0|98.0.4706.0|541|
|[v18.0.0-nightly.20211208](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211208)|2021-12-08||yes|103|16.13.0|98.0.4706.0|542|
|[v18.0.0-nightly.20211207](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211207)|2021-12-08||yes|103|16.13.0|98.0.4706.0|516|
|[v18.0.0-nightly.20211206](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211206)|2021-12-06||yes|103|16.13.0|98.0.4706.0|530|
|[v18.0.0-nightly.20211203](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211203)|2021-12-03||yes|103|16.13.0|98.0.4706.0|586|
|[v18.0.0-nightly.20211202](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211202)|2021-12-02||yes|103|16.13.0|98.0.4706.0|544|
|[v18.0.0-nightly.20211201](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211201)|2021-12-01||yes|103|16.13.0|98.0.4706.0|610|
|[v18.0.0-nightly.20211130](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211130)|2021-11-30||yes|103|16.13.0|98.0.4706.0|409|
|[v18.0.0-nightly.20211129](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211129)|2021-11-29||yes|103|16.13.0|98.0.4706.0|404|
|[v18.0.0-nightly.20211126](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211126)|2021-11-26||yes|103|16.13.0|98.0.4706.0|483|
|[v18.0.0-nightly.20211125](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211125)|2021-11-25||yes|103|16.13.0|98.0.4706.0|403|
|[v18.0.0-nightly.20211124](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211124)|2021-11-24||yes|103|16.13.0|98.0.4706.0|397|
|[v18.0.0-nightly.20211123](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211123)|2021-11-23||yes|103|16.13.0|96.0.4664.4|400|
|[v18.0.0-nightly.20211122](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211122)|2021-11-22||yes|103|16.13.0|96.0.4664.4|395|
|[v18.0.0-nightly.20211119](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211119)|2021-11-20||yes|103|16.13.0|96.0.4664.4|451|
|[v18.0.0-nightly.20211118](https://github.com/electron/electron/releases/tag/v18.0.0-nightly.20211118)|2021-11-18||yes|103|16.13.0|96.0.4664.4|403|
|[v18.0.0-beta.6](https://github.com/electron/electron/releases/tag/v18.0.0-beta.6)|2022-03-24|beta-18-x-y|yes|103|16.13.2|100.0.4894.0|3496|
|[v18.0.0-beta.5](https://github.com/electron/electron/releases/tag/v18.0.0-beta.5)|2022-03-21||yes|103|16.13.2|100.0.4894.0|3697|
|[v18.0.0-beta.4](https://github.com/electron/electron/releases/tag/v18.0.0-beta.4)|2022-03-17||yes|103|16.13.2|100.0.4894.0|2885|
|[v18.0.0-beta.3](https://github.com/electron/electron/releases/tag/v18.0.0-beta.3)|2022-03-14||yes|103|16.13.2|100.0.4894.0|4588|
|[v18.0.0-beta.2](https://github.com/electron/electron/releases/tag/v18.0.0-beta.2)|2022-03-10||yes|103|16.13.2|100.0.4894.0|2975|
|[v18.0.0-beta.1](https://github.com/electron/electron/releases/tag/v18.0.0-beta.1)|2022-03-08||yes|103|16.13.2|100.0.4894.0|2160|
|[v18.0.0-alpha.5](https://github.com/electron/electron/releases/tag/v18.0.0-alpha.5)|2022-02-28|alpha-18-x-y|yes|103|16.13.2|99.0.4767.0|2246|
|[v18.0.0-alpha.4](https://github.com/electron/electron/releases/tag/v18.0.0-alpha.4)|2022-02-24||yes|103|16.13.2|99.0.4767.0|3411|
|[v18.0.0-alpha.3](https://github.com/electron/electron/releases/tag/v18.0.0-alpha.3)|2022-02-14||yes|103|16.13.2|99.0.4767.0|2039|
|[v18.0.0-alpha.2](https://github.com/electron/electron/releases/tag/v18.0.0-alpha.2)|2022-02-08||yes|103|16.13.2|99.0.4767.0|3282|
|[v18.0.0-alpha.1](https://github.com/electron/electron/releases/tag/v18.0.0-alpha.1)|2022-02-02||yes|103|16.13.2|99.0.4767.0|2965|
|[v17.4.11](https://github.com/electron/electron/releases/tag/v17.4.11)|2022-08-01|17-x-y|no|101|16.13.0|98.0.4758.141|64098|
|[v17.4.10](https://github.com/electron/electron/releases/tag/v17.4.10)|2022-07-07||no|101|16.13.0|98.0.4758.141|33299|
|[v17.4.9](https://github.com/electron/electron/releases/tag/v17.4.9)|2022-06-30||no|101|16.13.0|98.0.4758.141|10191|
|[v17.4.8](https://github.com/electron/electron/releases/tag/v17.4.8)|2022-06-20||no|101|16.13.0|98.0.4758.141|17119|
|[v17.4.7](https://github.com/electron/electron/releases/tag/v17.4.7)|2022-06-01||no|101|16.13.0|98.0.4758.141|85352|
|[v17.4.6](https://github.com/electron/electron/releases/tag/v17.4.6)|2022-05-25||no|101|16.13.0|98.0.4758.141|21500|
|[v17.4.5](https://github.com/electron/electron/releases/tag/v17.4.5)|2022-05-18||no|101|16.13.0|98.0.4758.141|17050|
|[v17.4.4](https://github.com/electron/electron/releases/tag/v17.4.4)|2022-05-11||no|101|16.13.0|98.0.4758.141|53364|
|[v17.4.3](https://github.com/electron/electron/releases/tag/v17.4.3)|2022-05-05||no|101|16.13.0|98.0.4758.141|27509|
|[v17.4.2](https://github.com/electron/electron/releases/tag/v17.4.2)|2022-04-29||no|101|16.13.0|98.0.4758.141|44390|
|[v17.4.1](https://github.com/electron/electron/releases/tag/v17.4.1)|2022-04-20||no|101|16.13.0|98.0.4758.141|53191|
|[v17.4.0](https://github.com/electron/electron/releases/tag/v17.4.0)|2022-04-05||no|101|16.13.0|98.0.4758.141|78183|
|[v17.3.1](https://github.com/electron/electron/releases/tag/v17.3.1)|2022-03-30||no|101|16.13.0|98.0.4758.141|55615|
|[v17.3.0](https://github.com/electron/electron/releases/tag/v17.3.0)|2022-03-29||no|101|16.13.0|98.0.4758.141|25368|
|[v17.2.0](https://github.com/electron/electron/releases/tag/v17.2.0)|2022-03-23||no|101|16.13.0|98.0.4758.109|195911|
|[v17.1.2](https://github.com/electron/electron/releases/tag/v17.1.2)|2022-03-09||no|101|16.13.0|98.0.4758.109|217982|
|[v17.1.1](https://github.com/electron/electron/releases/tag/v17.1.1)|2022-03-07||no|101|16.13.0|98.0.4758.109|96823|
|[v17.1.0](https://github.com/electron/electron/releases/tag/v17.1.0)|2022-02-23||no|101|16.13.0|98.0.4758.102|194649|
|[v17.0.1](https://github.com/electron/electron/releases/tag/v17.0.1)|2022-02-15||no|101|16.13.0|98.0.4758.82|162624|
|[v17.0.0](https://github.com/electron/electron/releases/tag/v17.0.0)|2022-02-01||no|101|16.13.0|98.0.4758.74|325010|
|[v17.0.0-nightly.20211117](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211117)|2021-11-17||yes|101|16.13.0|96.0.4664.4|746|
|[v17.0.0-nightly.20211116](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211116)|2021-11-16||yes|101|16.13.0|96.0.4664.4|402|
|[v17.0.0-nightly.20211115](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211115)|2021-11-15||yes|101|16.13.0|96.0.4664.4|417|
|[v17.0.0-nightly.20211112](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211112)|2021-11-12||yes|101|16.13.0|96.0.4664.4|473|
|[v17.0.0-nightly.20211111](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211111)|2021-11-11||yes|101|16.13.0|96.0.4664.4|415|
|[v17.0.0-nightly.20211110](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211110)|2021-11-10||yes|101|16.13.0|96.0.4664.4|393|
|[v17.0.0-nightly.20211109](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211109)|2021-11-09||yes|101|16.13.0|96.0.4664.4|471|
|[v17.0.0-nightly.20211108](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211108)|2021-11-08||yes|101|16.13.0|96.0.4664.4|418|
|[v17.0.0-nightly.20211105](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211105)|2021-11-05||yes|101|16.13.0|96.0.4664.4|475|
|[v17.0.0-nightly.20211104](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211104)|2021-11-04||yes|101|16.13.0|96.0.4664.4|405|
|[v17.0.0-nightly.20211103](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211103)|2021-11-03||yes|101|16.13.0|96.0.4664.4|408|
|[v17.0.0-nightly.20211102](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211102)|2021-11-02||yes|101|16.13.0|96.0.4664.4|406|
|[v17.0.0-nightly.20211101](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211101)|2021-11-01||yes|101|16.12.0|96.0.4664.4|477|
|[v17.0.0-nightly.20211029](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211029)|2021-10-29||yes|101|16.12.0|96.0.4664.4|346|
|[v17.0.0-nightly.20211028](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211028)|2021-10-28||yes|101|16.12.0|96.0.4664.4|262|
|[v17.0.0-nightly.20211027](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211027)|2021-10-27||yes|101|16.12.0|96.0.4664.4|257|
|[v17.0.0-nightly.20211026](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211026)|2021-10-26||yes|101|16.12.0|96.0.4664.4|250|
|[v17.0.0-nightly.20211025](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211025)|2021-10-25||yes|101|16.11.1|96.0.4664.4|260|
|[v17.0.0-nightly.20211022](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211022)|2021-10-23||yes|101|16.11.1|96.0.4664.4|452|
|[v17.0.0-nightly.20211021](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211021)|2021-10-21||yes|101|16.11.1|96.0.4647.0|265|
|[v17.0.0-nightly.20211020](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211020)|2021-10-20||yes|101|16.11.1|96.0.4647.0|273|
|[v17.0.0-nightly.20211019](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211019)|2021-10-19||yes|101|16.11.1|96.0.4647.0|258|
|[v17.0.0-nightly.20211018](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211018)|2021-10-18||yes|101|16.11.1|96.0.4647.0|396|
|[v17.0.0-nightly.20211015](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211015)|2021-10-15||yes|101|16.11.1|96.0.4647.0|465|
|[v17.0.0-nightly.20211014](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211014)|2021-10-14||yes|101|16.11.1|96.0.4647.0|261|
|[v17.0.0-nightly.20211013](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211013)|2021-10-14||yes|101|16.10.0|96.0.4647.0|395|
|[v17.0.0-nightly.20211012](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211012)|2021-10-12||yes|101|16.10.0|96.0.4647.0|273|
|[v17.0.0-nightly.20211011](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211011)|2021-10-11||yes|101|16.10.0|96.0.4647.0|258|
|[v17.0.0-nightly.20211008](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211008)|2021-10-08||yes|101|16.10.0|96.0.4647.0|454|
|[v17.0.0-nightly.20211007](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211007)|2021-10-07||yes|99|16.10.0|96.0.4647.0|258|
|[v17.0.0-nightly.20211006](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211006)|2021-10-06||yes|99|16.10.0|96.0.4647.0|251|
|[v17.0.0-nightly.20211005](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211005)|2021-10-05||yes|99|16.10.0|95.0.4629.0|407|
|[v17.0.0-nightly.20211004](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211004)|2021-10-04||yes|99|16.10.0|95.0.4629.0|398|
|[v17.0.0-nightly.20211001](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20211001)|2021-10-01||yes|99|16.10.0|95.0.4629.0|463|
|[v17.0.0-nightly.20210930](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20210930)|2021-09-30||yes|99|16.10.0|95.0.4629.0|416|
|[v17.0.0-nightly.20210929](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20210929)|2021-09-29||yes|99|16.10.0|95.0.4629.0|385|
|[v17.0.0-nightly.20210928](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20210928)|2021-09-28||yes|99|16.10.0|95.0.4629.0|393|
|[v17.0.0-nightly.20210927](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20210927)|2021-09-27||yes|99|16.9.1|95.0.4629.0|241|
|[v17.0.0-nightly.20210924](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20210924)|2021-09-24||yes|99|16.9.1|95.0.4629.0|456|
|[v17.0.0-nightly.20210923](https://github.com/electron/electron/releases/tag/v17.0.0-nightly.20210923)|2021-09-23||yes|99|16.9.1|95.0.4629.0|410|
|[v17.0.0-beta.9](https://github.com/electron/electron/releases/tag/v17.0.0-beta.9)|2022-01-31|beta-17-x-y|yes|101|16.13.0|98.0.4758.11|3451|
|[v17.0.0-beta.8](https://github.com/electron/electron/releases/tag/v17.0.0-beta.8)|2022-01-27||yes|101|16.13.0|98.0.4758.11|3916|
|[v17.0.0-beta.7](https://github.com/electron/electron/releases/tag/v17.0.0-beta.7)|2022-01-24||yes|101|16.13.0|98.0.4758.11|2311|
|[v17.0.0-beta.6](https://github.com/electron/electron/releases/tag/v17.0.0-beta.6)|2022-01-21||yes|101|16.13.0|98.0.4758.11|3646|
|[v17.0.0-beta.5](https://github.com/electron/electron/releases/tag/v17.0.0-beta.5)|2022-01-17||yes|101|16.13.0|98.0.4758.11|4026|
|[v17.0.0-beta.4](https://github.com/electron/electron/releases/tag/v17.0.0-beta.4)|2022-01-13||yes|101|16.13.0|98.0.4758.11|11088|
|[v17.0.0-beta.3](https://github.com/electron/electron/releases/tag/v17.0.0-beta.3)|2022-01-11||yes|101|16.13.0|98.0.4758.9|2668|
|[v17.0.0-beta.2](https://github.com/electron/electron/releases/tag/v17.0.0-beta.2)|2022-01-10||yes|101|16.13.0|98.0.4706.0|2984|
|[v17.0.0-beta.1](https://github.com/electron/electron/releases/tag/v17.0.0-beta.1)|2022-01-06||yes|101|16.13.0|98.0.4706.0|2908|
|[v17.0.0-alpha.6](https://github.com/electron/electron/releases/tag/v17.0.0-alpha.6)|2022-01-03|alpha-17-x-y|yes|101|16.13.0|98.0.4706.0|1817|
|[v17.0.0-alpha.5](https://github.com/electron/electron/releases/tag/v17.0.0-alpha.5)|2021-12-16||yes|101|16.13.0|98.0.4706.0|1994|
|[v17.0.0-alpha.4](https://github.com/electron/electron/releases/tag/v17.0.0-alpha.4)|2021-11-25||yes|101|16.13.0|98.0.4706.0|3401|
|[v17.0.0-alpha.3](https://github.com/electron/electron/releases/tag/v17.0.0-alpha.3)|2021-11-22||yes|101|16.13.0|96.0.4664.4|2381|
|[v17.0.0-alpha.2](https://github.com/electron/electron/releases/tag/v17.0.0-alpha.2)|2021-11-18||yes|101|16.13.0|96.0.4664.4|2428|
|[v17.0.0-alpha.1](https://github.com/electron/electron/releases/tag/v17.0.0-alpha.1)|2021-11-17||yes|101|16.13.0|96.0.4664.4|2199|
|[v16.2.8](https://github.com/electron/electron/releases/tag/v16.2.8)|2022-05-24|16-x-y|no|99|16.9.1|96.0.4664.174|112061|
|[v16.2.7](https://github.com/electron/electron/releases/tag/v16.2.7)|2022-05-18||no|99|16.9.1|96.0.4664.174|26014|
|[v16.2.6](https://github.com/electron/electron/releases/tag/v16.2.6)|2022-05-11||no|99|16.9.1|96.0.4664.174|24675|
|[v16.2.5](https://github.com/electron/electron/releases/tag/v16.2.5)|2022-05-04||no|99|16.9.1|96.0.4664.174|25518|
|[v16.2.4](https://github.com/electron/electron/releases/tag/v16.2.4)|2022-04-28||no|99|16.9.1|96.0.4664.174|9936|
|[v16.2.3](https://github.com/electron/electron/releases/tag/v16.2.3)|2022-04-20||no|99|16.9.1|96.0.4664.174|18862|
|[v16.2.2](https://github.com/electron/electron/releases/tag/v16.2.2)|2022-04-06||no|99|16.9.1|96.0.4664.174|39167|
|[v16.2.1](https://github.com/electron/electron/releases/tag/v16.2.1)|2022-03-30||no|99|16.9.1|96.0.4664.174|20379|
|[v16.2.0](https://github.com/electron/electron/releases/tag/v16.2.0)|2022-03-28||no|99|16.9.1|96.0.4664.174|12621|
|[v16.1.1](https://github.com/electron/electron/releases/tag/v16.1.1)|2022-03-23||no|99|16.9.1|96.0.4664.174|22260|
|[v16.1.0](https://github.com/electron/electron/releases/tag/v16.1.0)|2022-03-09||no|99|16.9.1|96.0.4664.174|62346|
|[v16.0.10](https://github.com/electron/electron/releases/tag/v16.0.10)|2022-02-23||no|99|16.9.1|96.0.4664.174|57064|
|[v16.0.9](https://github.com/electron/electron/releases/tag/v16.0.9)|2022-02-15||no|99|16.9.1|96.0.4664.174|102194|
|[v16.0.8](https://github.com/electron/electron/releases/tag/v16.0.8)|2022-01-27||no|99|16.9.1|96.0.4664.110|177606|
|[v16.0.7](https://github.com/electron/electron/releases/tag/v16.0.7)|2022-01-11||no|99|16.9.1|96.0.4664.110|242564|
|[v16.0.6](https://github.com/electron/electron/releases/tag/v16.0.6)|2022-01-03||no|99|16.9.1|96.0.4664.110|275819|
|[v16.0.5](https://github.com/electron/electron/releases/tag/v16.0.5)|2021-12-17||no|99|16.9.1|96.0.4664.55|264874|
|[v16.0.4](https://github.com/electron/electron/releases/tag/v16.0.4)|2021-12-03||no|99|16.9.1|96.0.4664.55|216202|
|[v16.0.3](https://github.com/electron/electron/releases/tag/v16.0.3)|2021-11-30||no|99|16.9.1|96.0.4664.55|54082|
|[v16.0.2](https://github.com/electron/electron/releases/tag/v16.0.2)|2021-11-24||no|99|16.9.1|96.0.4664.55|151675|
|[v16.0.1](https://github.com/electron/electron/releases/tag/v16.0.1)|2021-11-18||no|99|16.9.1|96.0.4664.45|82939|
|[v16.0.0](https://github.com/electron/electron/releases/tag/v16.0.0)|2021-11-16||no|99|16.9.1|96.0.4664.45|100191|
|[v16.0.0-nightly.20210922](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210922)|2021-09-22||yes|99|16.9.1|95.0.4629.0|451|
|[v16.0.0-nightly.20210921](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210921)|2021-09-21||yes|99|16.9.1|95.0.4629.0|414|
|[v16.0.0-nightly.20210920](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210920)|2021-09-20||yes|99|16.9.1|95.0.4629.0|417|
|[v16.0.0-nightly.20210917](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210917)|2021-09-17||yes|99|16.9.1|95.0.4629.0|472|
|[v16.0.0-nightly.20210916](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210916)|2021-09-16||yes|99|16.9.1|95.0.4629.0|420|
|[v16.0.0-nightly.20210915](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210915)|2021-09-15||yes|89|16.9.0|95.0.4629.0|402|
|[v16.0.0-nightly.20210914](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210914)|2021-09-15||yes|89|16.9.0|95.0.4629.0|392|
|[v16.0.0-nightly.20210913](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210913)|2021-09-13||yes|89|16.9.0|95.0.4629.0|505|
|[v16.0.0-nightly.20210910](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210910)|2021-09-10||yes|89|16.9.0|95.0.4629.0|555|
|[v16.0.0-nightly.20210909](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210909)|2021-09-09||yes|89|16.9.0|95.0.4629.0|480|
|[v16.0.0-nightly.20210908](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210908)|2021-09-08||yes|89|16.8.0|95.0.4629.0|482|
|[v16.0.0-nightly.20210907](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210907)|2021-09-07||yes|89|16.8.0|95.0.4629.0|506|
|[v16.0.0-nightly.20210906](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210906)|2021-09-07||yes|89|16.8.0|95.0.4629.0|472|
|[v16.0.0-nightly.20210903](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210903)|2021-09-03||yes|89|16.8.0|95.0.4629.0|664|
|[v16.0.0-nightly.20210902](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210902)|2021-09-03||yes|89|16.8.0|95.0.4629.0|469|
|[v16.0.0-nightly.20210901](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210901)|2021-09-01||yes|89|16.8.0|95.0.4612.5|522|
|[v16.0.0-nightly.20210831](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210831)|2021-08-31||yes|89|16.7.0|95.0.4612.5|519|
|[v16.0.0-nightly.20210830](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210830)|2021-08-30||yes|89|16.7.0|95.0.4612.5|501|
|[v16.0.0-nightly.20210827](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210827)|2021-08-27||yes|89|16.7.0|95.0.4612.5|413|
|[v16.0.0-nightly.20210826](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210826)|2021-08-26||yes|89|16.7.0|95.0.4612.5|332|
|[v16.0.0-nightly.20210825](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210825)|2021-08-25||yes|89|16.7.0|95.0.4612.5|494|
|[v16.0.0-nightly.20210824](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210824)|2021-08-24||yes|89|16.7.0|95.0.4612.5|510|
|[v16.0.0-nightly.20210823](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210823)|2021-08-23||yes|89|16.7.0|94.0.4590.2|1000|
|[v16.0.0-nightly.20210820](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210820)|2021-08-20||yes|89|16.5.0|94.0.4590.2|567|
|[v16.0.0-nightly.20210819](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210819)|2021-08-19||yes|89|16.5.0|94.0.4590.2|501|
|[v16.0.0-nightly.20210818](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210818)|2021-08-18||yes|89|16.5.0|94.0.4590.2|521|
|[v16.0.0-nightly.20210817](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210817)|2021-08-17||yes|89|16.5.0|94.0.4590.2|491|
|[v16.0.0-nightly.20210816](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210816)|2021-08-16||yes|89|16.5.0|94.0.4590.2|498|
|[v16.0.0-nightly.20210813](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210813)|2021-08-13||yes|89|16.5.0|94.0.4590.2|545|
|[v16.0.0-nightly.20210812](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210812)|2021-08-12||yes|89|16.5.0|94.0.4590.2|493|
|[v16.0.0-nightly.20210811](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210811)|2021-08-11||yes|89|16.5.0|94.0.4584.0|505|
|[v16.0.0-nightly.20210810](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210810)|2021-08-10||yes|89|16.5.0|94.0.4584.0|506|
|[v16.0.0-nightly.20210809](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210809)|2021-08-09||yes|89|16.5.0|94.0.4584.0|497|
|[v16.0.0-nightly.20210806](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210806)|2021-08-06||yes|89|16.5.0|94.0.4584.0|580|
|[v16.0.0-nightly.20210805](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210805)|2021-08-05||yes|89|16.5.0|94.0.4584.0|516|
|[v16.0.0-nightly.20210804](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210804)|2021-08-04||yes|89|16.5.0|94.0.4584.0|511|
|[v16.0.0-nightly.20210803](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210803)|2021-08-03||yes|89|16.5.0|94.0.4584.0|515|
|[v16.0.0-nightly.20210802](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210802)|2021-08-02||yes|89|16.5.0|94.0.4584.0|493|
|[v16.0.0-nightly.20210730](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210730)|2021-07-30||yes|89|16.5.0|94.0.4584.0|612|
|[v16.0.0-nightly.20210729](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210729)|2021-07-29||yes|89|16.5.0|94.0.4584.0|574|
|[v16.0.0-nightly.20210728](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210728)|2021-07-28||yes|89|16.5.0|94.0.4584.0|493|
|[v16.0.0-nightly.20210727](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210727)|2021-07-27||yes|89|16.5.0|94.0.4584.0|486|
|[v16.0.0-nightly.20210726](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210726)|2021-07-26||yes|89|16.5.0|93.0.4566.0|472|
|[v16.0.0-nightly.20210723](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210723)|2021-07-23||yes|89|16.5.0|93.0.4566.0|551|
|[v16.0.0-nightly.20210722](https://github.com/electron/electron/releases/tag/v16.0.0-nightly.20210722)|2021-07-22||yes|89|16.5.0|93.0.4566.0|492|
|[v16.0.0-beta.9](https://github.com/electron/electron/releases/tag/v16.0.0-beta.9)|2021-11-11|beta-16-x-y|yes|99|16.9.1|96.0.4664.35|4052|
|[v16.0.0-beta.8](https://github.com/electron/electron/releases/tag/v16.0.0-beta.8)|2021-11-08||yes|99|16.9.1|96.0.4664.35|3573|
|[v16.0.0-beta.7](https://github.com/electron/electron/releases/tag/v16.0.0-beta.7)|2021-11-04||yes|99|16.9.1|96.0.4664.27|3160|
|[v16.0.0-beta.6](https://github.com/electron/electron/releases/tag/v16.0.0-beta.6)|2021-11-01||yes|99|16.9.1|96.0.4664.27|3680|
|[v16.0.0-beta.5](https://github.com/electron/electron/releases/tag/v16.0.0-beta.5)|2021-10-28||yes|99|16.9.1|96.0.4664.18|2416|
|[v16.0.0-beta.4](https://github.com/electron/electron/releases/tag/v16.0.0-beta.4)|2021-10-27||yes|99|16.9.1|96.0.4664.18|2170|
|[v16.0.0-beta.3](https://github.com/electron/electron/releases/tag/v16.0.0-beta.3)|2021-10-25||yes|99|16.9.1|96.0.4647.0|3124|
|[v16.0.0-beta.2](https://github.com/electron/electron/releases/tag/v16.0.0-beta.2)|2021-10-21||yes|99|16.9.1|96.0.4647.0|3437|
|[v16.0.0-beta.1](https://github.com/electron/electron/releases/tag/v16.0.0-beta.1)|2021-10-20||yes|99|16.9.1|96.0.4647.0|1851|
|[v16.0.0-alpha.9](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.9)|2021-10-18|alpha-16-x-y|yes|99|16.9.1|96.0.4647.0|2712|
|[v16.0.0-alpha.8](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.8)|2021-10-14||yes|99|16.9.1|96.0.4647.0|2432|
|[v16.0.0-alpha.7](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.7)|2021-10-11||yes|99|16.9.1|95.0.4629.0|2057|
|[v16.0.0-alpha.6](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.6)|2021-10-07||yes|99|16.9.1|95.0.4629.0|2195|
|[v16.0.0-alpha.5](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.5)|2021-10-04||yes|99|16.9.1|95.0.4629.0|3188|
|[v16.0.0-alpha.4](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.4)|2021-10-04||yes|99|16.9.1|95.0.4629.0|2527|
|[v16.0.0-alpha.3](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.3)|2021-09-30||yes|99|16.9.1|95.0.4629.0|2586|
|[v16.0.0-alpha.2](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.2)|2021-09-30||yes|99|16.9.1|95.0.4629.0|2394|
|[v16.0.0-alpha.1](https://github.com/electron/electron/releases/tag/v16.0.0-alpha.1)|2021-09-22||yes|99|16.9.1|95.0.4629.0|3521|
|[v15.5.7](https://github.com/electron/electron/releases/tag/v15.5.7)|2022-05-24|15-x-y|no|98|16.5.0|94.0.4606.81|239715|
|[v15.5.6](https://github.com/electron/electron/releases/tag/v15.5.6)|2022-05-23||no|98|16.5.0|94.0.4606.81|2791|
|[v15.5.5](https://github.com/electron/electron/releases/tag/v15.5.5)|2022-05-11||no|98|16.5.0|94.0.4606.81|78632|
|[v15.5.4](https://github.com/electron/electron/releases/tag/v15.5.4)|2022-05-04||no|98|16.5.0|94.0.4606.81|10173|
|[v15.5.3](https://github.com/electron/electron/releases/tag/v15.5.3)|2022-04-30||no|98|16.5.0|94.0.4606.81|8811|
|[v15.5.2](https://github.com/electron/electron/releases/tag/v15.5.2)|2022-04-06||no|98|16.5.0|94.0.4606.81|39047|
|[v15.5.1](https://github.com/electron/electron/releases/tag/v15.5.1)|2022-03-30||no|98|16.5.0|94.0.4606.81|31981|
|[v15.5.0](https://github.com/electron/electron/releases/tag/v15.5.0)|2022-03-29||no|98|16.5.0|94.0.4606.81|3922|
|[v15.4.2](https://github.com/electron/electron/releases/tag/v15.4.2)|2022-03-23||no|98|16.5.0|94.0.4606.81|26209|
|[v15.4.1](https://github.com/electron/electron/releases/tag/v15.4.1)|2022-03-09||no|98|16.5.0|94.0.4606.81|14342|
|[v15.4.0](https://github.com/electron/electron/releases/tag/v15.4.0)|2022-03-01||no|98|16.5.0|94.0.4606.81|14400|
|[v15.3.7](https://github.com/electron/electron/releases/tag/v15.3.7)|2022-02-14||no|98|16.5.0|94.0.4606.81|48377|
|[v15.3.6](https://github.com/electron/electron/releases/tag/v15.3.6)|2022-01-27||no|98|16.5.0|94.0.4606.81|82704|
|[v15.3.5](https://github.com/electron/electron/releases/tag/v15.3.5)|2022-01-11||no|98|16.5.0|94.0.4606.81|78690|
|[v15.3.4](https://github.com/electron/electron/releases/tag/v15.3.4)|2021-12-16||no|98|16.5.0|94.0.4606.81|99026|
|[v15.3.3](https://github.com/electron/electron/releases/tag/v15.3.3)|2021-11-30||no|98|16.5.0|94.0.4606.81|50687|
|[v15.3.2](https://github.com/electron/electron/releases/tag/v15.3.2)|2021-11-16||no|98|16.5.0|94.0.4606.81|86586|
|[v15.3.1](https://github.com/electron/electron/releases/tag/v15.3.1)|2021-11-08||no|98|16.5.0|94.0.4606.81|122857|
|[v15.3.0](https://github.com/electron/electron/releases/tag/v15.3.0)|2021-10-20||no|98|16.5.0|94.0.4606.81|364363|
|[v15.2.0](https://github.com/electron/electron/releases/tag/v15.2.0)|2021-10-14||no|98|16.5.0|94.0.4606.81|119412|
|[v15.1.2](https://github.com/electron/electron/releases/tag/v15.1.2)|2021-10-08||no|98|16.5.0|94.0.4606.71|105284|
|[v15.1.1](https://github.com/electron/electron/releases/tag/v15.1.1)|2021-10-04||no|98|16.5.0|94.0.4606.61|75656|
|[v15.1.0](https://github.com/electron/electron/releases/tag/v15.1.0)|2021-10-01||no|98|16.5.0|94.0.4606.61|55614|
|[v15.0.0](https://github.com/electron/electron/releases/tag/v15.0.0)|2021-09-21||no|98|16.5.0|94.0.4606.51|153393|
|[v15.0.0-nightly.20210721](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210721)|2021-07-21||yes|89|16.5.0|93.0.4566.0|659|
|[v15.0.0-nightly.20210720](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210720)|2021-07-20||yes|89|16.5.0|93.0.4566.0|510|
|[v15.0.0-nightly.20210719](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210719)|2021-07-19||yes|89|16.5.0|93.0.4566.0|496|
|[v15.0.0-nightly.20210716](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210716)|2021-07-16||yes|89|16.5.0|93.0.4566.0|561|
|[v15.0.0-nightly.20210715](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210715)|2021-07-15||yes|89|16.4.1|93.0.4566.0|493|
|[v15.0.0-nightly.20210714](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210714)|2021-07-14||yes|89|16.4.1|93.0.4566.0|494|
|[v15.0.0-nightly.20210713](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210713)|2021-07-13||yes|89|16.4.1|93.0.4566.0|489|
|[v15.0.0-nightly.20210712](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210712)|2021-07-12||yes|89|16.4.1|93.0.4566.0|485|
|[v15.0.0-nightly.20210709](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210709)|2021-07-09||yes|89|16.4.1|93.0.4566.0|523|
|[v15.0.0-nightly.20210708](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210708)|2021-07-08||yes|89|16.4.1|93.0.4566.0|472|
|[v15.0.0-nightly.20210707](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210707)|2021-07-07||yes|89|16.4.1|93.0.4566.0|464|
|[v15.0.0-nightly.20210706](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210706)|2021-07-06||yes|89|16.4.1|93.0.4566.0|487|
|[v15.0.0-nightly.20210705](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210705)|2021-07-05||yes|89|16.4.0|93.0.4558.0|477|
|[v15.0.0-nightly.20210702](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210702)|2021-07-02||yes|89|16.4.0|93.0.4558.0|581|
|[v15.0.0-nightly.20210701](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210701)|2021-07-01||yes|89|16.4.0|93.0.4558.0|556|
|[v15.0.0-nightly.20210630](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210630)|2021-06-30||yes|89|16.4.0|93.0.4558.0|486|
|[v15.0.0-nightly.20210629](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210629)|2021-06-29||yes|89|16.4.0|93.0.4552.0|485|
|[v15.0.0-nightly.20210628](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210628)|2021-06-28||yes|89|16.2.0|93.0.4552.0|480|
|[v15.0.0-nightly.20210625](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210625)|2021-06-25||yes|89|16.2.0|93.0.4552.0|545|
|[v15.0.0-nightly.20210624](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210624)|2021-06-24||yes|89|16.2.0|93.0.4550.0|497|
|[v15.0.0-nightly.20210623](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210623)|2021-06-23||yes|89|16.2.0|93.0.4550.0|488|
|[v15.0.0-nightly.20210622](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210622)|2021-06-22||yes|89|16.2.0|93.0.4539.0|460|
|[v15.0.0-nightly.20210621](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210621)|2021-06-21||yes|89|16.2.0|93.0.4539.0|512|
|[v15.0.0-nightly.20210618](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210618)|2021-06-18||yes|89|16.2.0|93.0.4539.0|590|
|[v15.0.0-nightly.20210617](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210617)|2021-06-17||yes|89|16.2.0|93.0.4539.0|471|
|[v15.0.0-nightly.20210616](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210616)|2021-06-16||yes|89|14.17.0|93.0.4536.0|495|
|[v15.0.0-nightly.20210615](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210615)|2021-06-15||yes|89|14.17.0|93.0.4536.0|406|
|[v15.0.0-nightly.20210614](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210614)|2021-06-14||yes|89|14.17.0|93.0.4536.0|473|
|[v15.0.0-nightly.20210611](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210611)|2021-06-11||yes|89|14.17.0|93.0.4536.0|546|
|[v15.0.0-nightly.20210610](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210610)|2021-06-10||yes|89|14.17.0|93.0.4536.0|474|
|[v15.0.0-nightly.20210609](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210609)|2021-06-09||yes|89|14.17.0|93.0.4536.0|488|
|[v15.0.0-nightly.20210608](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210608)|2021-06-08||yes|89|14.17.0|93.0.4535.0|450|
|[v15.0.0-nightly.20210604](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210604)|2021-06-04||yes|89|14.17.0|93.0.4530.0|572|
|[v15.0.0-nightly.20210603](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210603)|2021-06-03||yes|89|14.17.0|93.0.4530.0|470|
|[v15.0.0-nightly.20210602](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210602)|2021-06-02||yes|89|14.17.0|92.0.4511.0|497|
|[v15.0.0-nightly.20210601](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210601)|2021-06-03||yes|89|14.17.0|92.0.4511.0|452|
|[v15.0.0-nightly.20210531](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210531)|2021-05-31||yes|89|14.17.0|92.0.4511.0|506|
|[v15.0.0-nightly.20210528](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210528)|2021-05-28||yes|89|14.17.0|92.0.4511.0|351|
|[v15.0.0-nightly.20210527](https://github.com/electron/electron/releases/tag/v15.0.0-nightly.20210527)|2021-05-27||yes|89|14.17.0|92.0.4511.0|512|
|[v15.0.0-beta.7](https://github.com/electron/electron/releases/tag/v15.0.0-beta.7)|2021-09-16|beta-15-x-y|yes|98|16.5.0|94.0.4606.31|3383|
|[v15.0.0-beta.6](https://github.com/electron/electron/releases/tag/v15.0.0-beta.6)|2021-09-15||yes|89|16.5.0|94.0.4606.31|4001|
|[v15.0.0-beta.5](https://github.com/electron/electron/releases/tag/v15.0.0-beta.5)|2021-09-13||yes|89|16.5.0|94.0.4606.31|2209|
|[v15.0.0-beta.4](https://github.com/electron/electron/releases/tag/v15.0.0-beta.4)|2021-09-09||yes|89|16.5.0|94.0.4606.31|2939|
|[v15.0.0-beta.3](https://github.com/electron/electron/releases/tag/v15.0.0-beta.3)|2021-09-07||yes|89|16.5.0|94.0.4606.31|4030|
|[v15.0.0-beta.2](https://github.com/electron/electron/releases/tag/v15.0.0-beta.2)|2021-09-02||yes|89|16.5.0|94.0.4606.20|3794|
|[v15.0.0-beta.1](https://github.com/electron/electron/releases/tag/v15.0.0-beta.1)|2021-08-31||yes|89|16.5.0|94.0.4606.20|3997|
|[v15.0.0-alpha.10](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.10)|2021-08-26|alpha-15-x-y|yes|89|16.5.0|94.0.4606.12|2208|
|[v15.0.0-alpha.9](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.9)|2021-08-23||yes|89|16.5.0|94.0.4590.2|2424|
|[v15.0.0-alpha.8](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.8)|2021-08-19||yes|89|16.5.0|94.0.4590.2|2807|
|[v15.0.0-alpha.7](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.7)|2021-08-17||yes|89|16.5.0|94.0.4590.2|2111|
|[v15.0.0-alpha.6](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.6)|2021-08-12||yes|89|16.5.0|94.0.4584.0|2944|
|[v15.0.0-alpha.5](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.5)|2021-08-09||yes|89|16.5.0|94.0.4584.0|2167|
|[v15.0.0-alpha.4](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.4)|2021-08-05||yes|89|16.5.0|94.0.4584.0|2848|
|[v15.0.0-alpha.3](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.3)|2021-08-02||yes|89|16.5.0|94.0.4584.0|2495|
|[v15.0.0-alpha.2](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.2)|2021-07-26||yes|89|16.5.0|93.0.4566.0|6117|
|[v15.0.0-alpha.1](https://github.com/electron/electron/releases/tag/v15.0.0-alpha.1)|2021-07-21||yes|89|16.5.0|93.0.4566.0|2477|
|[v14.2.9](https://github.com/electron/electron/releases/tag/v14.2.9)|2022-03-30|14-x-y|no|97|14.17.0|93.0.4577.82|117078|
|[v14.2.8](https://github.com/electron/electron/releases/tag/v14.2.8)|2022-03-24||no|97|14.17.0|93.0.4577.82|7644|
|[v14.2.7](https://github.com/electron/electron/releases/tag/v14.2.7)|2022-03-09||no|97|14.17.0|93.0.4577.82|18142|
|[v14.2.6](https://github.com/electron/electron/releases/tag/v14.2.6)|2022-02-15||no|97|14.17.0|93.0.4577.82|30241|
|[v14.2.5](https://github.com/electron/electron/releases/tag/v14.2.5)|2022-01-27||no|97|14.17.0|93.0.4577.82|16908|
|[v14.2.4](https://github.com/electron/electron/releases/tag/v14.2.4)|2022-01-11||no|97|14.17.0|93.0.4577.82|28947|
|[v14.2.3](https://github.com/electron/electron/releases/tag/v14.2.3)|2021-12-16||no|97|14.17.0|93.0.4577.82|41693|
|[v14.2.2](https://github.com/electron/electron/releases/tag/v14.2.2)|2021-12-01||no|97|14.17.0|93.0.4577.82|20103|
|[v14.2.1](https://github.com/electron/electron/releases/tag/v14.2.1)|2021-11-08||no|97|14.17.0|93.0.4577.82|63167|
|[v14.2.0](https://github.com/electron/electron/releases/tag/v14.2.0)|2021-10-20||no|97|14.17.0|93.0.4577.82|73108|
|[v14.1.1](https://github.com/electron/electron/releases/tag/v14.1.1)|2021-10-08||no|97|14.17.0|93.0.4577.82|42484|
|[v14.1.0](https://github.com/electron/electron/releases/tag/v14.1.0)|2021-09-30||no|97|14.17.0|93.0.4577.82|73670|
|[v14.0.2](https://github.com/electron/electron/releases/tag/v14.0.2)|2021-09-29||no|97|14.17.0|93.0.4577.82|25558|
|[v14.0.1](https://github.com/electron/electron/releases/tag/v14.0.1)|2021-09-13||no|89|14.17.0|93.0.4577.63|111344|
|[v14.0.0](https://github.com/electron/electron/releases/tag/v14.0.0)|2021-08-30||no|89|14.17.0|93.0.4577.58|279509|
|[v14.0.0-nightly.20210524](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210524)|2021-05-24||yes|89|14.17.0|92.0.4511.0|693|
|[v14.0.0-nightly.20210523](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210523)|2021-05-24||yes|89|14.17.0|92.0.4511.0|505|
|[v14.0.0-nightly.20210520](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210520)|2021-05-20||yes|89|14.17.0|92.0.4511.0|560|
|[v14.0.0-nightly.20210519](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210519)|2021-05-19||yes|89|14.16.1|92.0.4505.0|324|
|[v14.0.0-nightly.20210518](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210518)|2021-05-18||yes|89|14.16.1|92.0.4505.0|588|
|[v14.0.0-nightly.20210517](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210517)|2021-05-17||yes|89|14.16.1|92.0.4505.0|468|
|[v14.0.0-nightly.20210514](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210514)|2021-05-14||yes|89|14.16.1|92.0.4505.0|651|
|[v14.0.0-nightly.20210513](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210513)|2021-05-13||yes|89|14.16.1|92.0.4499.0|465|
|[v14.0.0-nightly.20210512](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210512)|2021-05-12||yes|89|14.16.1|92.0.4499.0|476|
|[v14.0.0-nightly.20210511](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210511)|2021-05-11||yes|89|14.16.1|92.0.4499.0|475|
|[v14.0.0-nightly.20210510](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210510)|2021-05-10||yes|89|14.16.1|92.0.4499.0|469|
|[v14.0.0-nightly.20210507](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210507)|2021-05-07||yes|89|14.16.1|92.0.4499.0|535|
|[v14.0.0-nightly.20210506](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210506)|2021-05-06||yes|89|14.16.1|92.0.4498.0|481|
|[v14.0.0-nightly.20210505](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210505)|2021-05-05||yes|89|14.16.1|92.0.4496.0|475|
|[v14.0.0-nightly.20210503](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210503)|2021-05-04||yes|89|14.16.1|92.0.4488.0|522|
|[v14.0.0-nightly.20210430](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210430)|2021-04-30||yes|89|14.16.1|92.0.4488.0|474|
|[v14.0.0-nightly.20210427](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210427)|2021-04-27||yes|89|14.16.1|92.0.4475.0|560|
|[v14.0.0-nightly.20210426](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210426)|2021-04-26||yes|89|14.16.1|92.0.4475.0|503|
|[v14.0.0-nightly.20210413](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210413)|2021-04-13||yes|89|14.16.1|91.0.4448.0|862|
|[v14.0.0-nightly.20210409](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210409)|2021-04-09||yes|89|14.16.1|91.0.4448.0|636|
|[v14.0.0-nightly.20210408](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210408)|2021-04-08||yes|89|14.16.1|91.0.4448.0|507|
|[v14.0.0-nightly.20210407](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210407)|2021-04-07||yes|89|14.16.0|91.0.4448.0|512|
|[v14.0.0-nightly.20210406](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210406)|2021-04-06||yes|89|14.16.0|91.0.4448.0|542|
|[v14.0.0-nightly.20210402](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210402)|2021-04-02||yes|89|14.16.0|91.0.4448.0|588|
|[v14.0.0-nightly.20210401](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210401)|2021-04-01||yes|89|14.16.0|91.0.4448.0|594|
|[v14.0.0-nightly.20210331](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210331)|2021-03-31||yes|89|14.16.0|91.0.4448.0|458|
|[v14.0.0-nightly.20210330](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210330)|2021-03-30||yes|89|14.16.0|90.0.4415.0|491|
|[v14.0.0-nightly.20210329](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210329)|2021-03-29||yes|89|14.16.0|90.0.4415.0|306|
|[v14.0.0-nightly.20210326](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210326)|2021-03-26||yes|89|14.16.0|90.0.4415.0|502|
|[v14.0.0-nightly.20210325](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210325)|2021-03-25||yes|89|14.16.0|90.0.4415.0|476|
|[v14.0.0-nightly.20210324](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210324)|2021-03-24||yes|89|14.16.0|90.0.4415.0|477|
|[v14.0.0-nightly.20210323](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210323)|2021-03-23||yes|89|14.16.0|90.0.4415.0|475|
|[v14.0.0-nightly.20210319](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210319)|2021-03-19||yes|89|14.16.0|90.0.4415.0|568|
|[v14.0.0-nightly.20210318](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210318)|2021-03-18||yes|89|14.16.0|90.0.4415.0|456|
|[v14.0.0-nightly.20210317](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210317)|2021-03-17||yes|89|14.16.0|90.0.4415.0|471|
|[v14.0.0-nightly.20210316](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210316)|2021-03-16||yes|89|14.16.0|90.0.4415.0|477|
|[v14.0.0-nightly.20210315](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210315)|2021-03-15||yes|89|14.16.0|90.0.4415.0|479|
|[v14.0.0-nightly.20210311](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210311)|2021-03-11||yes|89|14.16.0|90.0.4415.0|575|
|[v14.0.0-nightly.20210309](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210309)|2021-03-09||yes|89|14.16.0|90.0.4415.0|602|
|[v14.0.0-nightly.20210308](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210308)|2021-03-08||yes|89|14.16.0|90.0.4415.0|485|
|[v14.0.0-nightly.20210305](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210305)|2021-03-05||yes|89|14.16.0|90.0.4415.0|531|
|[v14.0.0-nightly.20210304](https://github.com/electron/electron/releases/tag/v14.0.0-nightly.20210304)|2021-03-04||yes|89|14.16.0|90.0.4402.0|505|
|[v14.0.0-beta.25](https://github.com/electron/electron/releases/tag/v14.0.0-beta.25)|2021-08-30|beta-14-x-y|yes|89|14.17.0|93.0.4577.51|4136|
|[v14.0.0-beta.24](https://github.com/electron/electron/releases/tag/v14.0.0-beta.24)|2021-08-26||yes|89|14.17.0|93.0.4577.51|2674|
|[v14.0.0-beta.23](https://github.com/electron/electron/releases/tag/v14.0.0-beta.23)|2021-08-19||yes|89|14.17.0|93.0.4577.25|2982|
|[v14.0.0-beta.22](https://github.com/electron/electron/releases/tag/v14.0.0-beta.22)|2021-08-17||yes|89|14.17.0|93.0.4577.25|2806|
|[v14.0.0-beta.21](https://github.com/electron/electron/releases/tag/v14.0.0-beta.21)|2021-08-12||yes|89|14.17.0|93.0.4577.15|3484|
|[v14.0.0-beta.20](https://github.com/electron/electron/releases/tag/v14.0.0-beta.20)|2021-08-09||yes|89|14.17.0|93.0.4577.15|4384|
|[v14.0.0-beta.19](https://github.com/electron/electron/releases/tag/v14.0.0-beta.19)|2021-08-05||yes|89|14.17.0|93.0.4577.15|3136|
|[v14.0.0-beta.18](https://github.com/electron/electron/releases/tag/v14.0.0-beta.18)|2021-08-02||yes|89|14.17.0|93.0.4577.15|2871|
|[v14.0.0-beta.17](https://github.com/electron/electron/releases/tag/v14.0.0-beta.17)|2021-07-26||yes|89|14.17.0|93.0.4566.0|4152|
|[v14.0.0-beta.16](https://github.com/electron/electron/releases/tag/v14.0.0-beta.16)|2021-07-22||yes|89|14.17.0|93.0.4566.0|4490|
|[v14.0.0-beta.15](https://github.com/electron/electron/releases/tag/v14.0.0-beta.15)|2021-07-20||yes|89|14.17.0|93.0.4566.0|2337|
|[v14.0.0-beta.14](https://github.com/electron/electron/releases/tag/v14.0.0-beta.14)|2021-07-15||yes|89|14.17.0|93.0.4566.0|3635|
|[v14.0.0-beta.13](https://github.com/electron/electron/releases/tag/v14.0.0-beta.13)|2021-07-12||yes|89|14.17.0|93.0.4566.0|2880|
|[v14.0.0-beta.12](https://github.com/electron/electron/releases/tag/v14.0.0-beta.12)|2021-07-05||yes|89|14.17.0|93.0.4557.4|3099|
|[v14.0.0-beta.11](https://github.com/electron/electron/releases/tag/v14.0.0-beta.11)|2021-07-01||yes|89|14.17.0|93.0.4557.4|2792|
|[v14.0.0-beta.10](https://github.com/electron/electron/releases/tag/v14.0.0-beta.10)|2021-06-28||yes|89|14.17.0|93.0.4539.0|2552|
|[v14.0.0-beta.9](https://github.com/electron/electron/releases/tag/v14.0.0-beta.9)|2021-06-25||yes|89|14.17.0|93.0.4539.0|2521|
|[v14.0.0-beta.8](https://github.com/electron/electron/releases/tag/v14.0.0-beta.8)|2021-06-21||yes|89|14.17.0|93.0.4536.0|2393|
|[v14.0.0-beta.7](https://github.com/electron/electron/releases/tag/v14.0.0-beta.7)|2021-06-17||yes|89|14.17.0|93.0.4536.0|2412|
|[v14.0.0-beta.6](https://github.com/electron/electron/releases/tag/v14.0.0-beta.6)|2021-06-14||yes|89|14.17.0|93.0.4536.0|2313|
|[v14.0.0-beta.5](https://github.com/electron/electron/releases/tag/v14.0.0-beta.5)|2021-06-10||yes|89|14.17.0|93.0.4536.0|5886|
|[v14.0.0-beta.3](https://github.com/electron/electron/releases/tag/v14.0.0-beta.3)|2021-06-03||yes|89|14.17.0|92.0.4511.0|3237|
|[v14.0.0-beta.2](https://github.com/electron/electron/releases/tag/v14.0.0-beta.2)|2021-05-31||yes|89|14.17.0|92.0.4511.0|2602|
|[v14.0.0-beta.1](https://github.com/electron/electron/releases/tag/v14.0.0-beta.1)|2021-05-26||yes|89|14.17.0|92.0.4511.0|12735|
|[v13.6.9](https://github.com/electron/electron/releases/tag/v13.6.9)|2022-02-01|13-x-y|no|89|14.16.0|91.0.4472.164|384350|
|[v13.6.8](https://github.com/electron/electron/releases/tag/v13.6.8)|2022-01-26||no|89|14.16.0|91.0.4472.164|31234|
|[v13.6.7](https://github.com/electron/electron/releases/tag/v13.6.7)|2022-01-12||no|89|14.16.0|91.0.4472.164|107871|
|[v13.6.6](https://github.com/electron/electron/releases/tag/v13.6.6)|2022-01-04||no|89|14.16.0|91.0.4472.164|136112|
|[v13.6.3](https://github.com/electron/electron/releases/tag/v13.6.3)|2021-12-01||no|89|14.16.0|91.0.4472.164|144526|
|[v13.6.2](https://github.com/electron/electron/releases/tag/v13.6.2)|2021-11-16||no|89|14.16.0|91.0.4472.164|94582|
|[v13.6.1](https://github.com/electron/electron/releases/tag/v13.6.1)|2021-10-28||no|89|14.16.0|91.0.4472.164|151649|
|[v13.6.0](https://github.com/electron/electron/releases/tag/v13.6.0)|2021-10-21||no|89|14.16.0|91.0.4472.164|80901|
|[v13.5.2](https://github.com/electron/electron/releases/tag/v13.5.2)|2021-10-11||no|89|14.16.0|91.0.4472.164|180791|
|[v13.5.1](https://github.com/electron/electron/releases/tag/v13.5.1)|2021-09-30||no|89|14.16.0|91.0.4472.164|305370|
|[v13.5.0](https://github.com/electron/electron/releases/tag/v13.5.0)|2021-09-27||no|89|14.16.0|91.0.4472.164|70875|
|[v13.4.0](https://github.com/electron/electron/releases/tag/v13.4.0)|2021-09-13||no|89|14.16.0|91.0.4472.164|166303|
|[v13.3.0](https://github.com/electron/electron/releases/tag/v13.3.0)|2021-08-31||no|89|14.16.0|91.0.4472.164|192715|
|[v13.2.3](https://github.com/electron/electron/releases/tag/v13.2.3)|2021-08-27||no|89|14.16.0|91.0.4472.164|91218|
|[v13.2.2](https://github.com/electron/electron/releases/tag/v13.2.2)|2021-08-23||no|89|14.16.0|91.0.4472.164|73481|
|[v13.2.1](https://github.com/electron/electron/releases/tag/v13.2.1)|2021-08-17||no|89|14.16.0|91.0.4472.164|140097|
|[v13.2.0](https://github.com/electron/electron/releases/tag/v13.2.0)|2021-08-17||no|89|14.16.0|91.0.4472.164|18877|
|[v13.1.9](https://github.com/electron/electron/releases/tag/v13.1.9)|2021-08-10||no|89|14.16.0|91.0.4472.164|171529|
|[v13.1.8](https://github.com/electron/electron/releases/tag/v13.1.8)|2021-08-03||no|89|14.16.0|91.0.4472.164|202453|
|[v13.1.7](https://github.com/electron/electron/releases/tag/v13.1.7)|2021-07-15||no|89|14.16.0|91.0.4472.124|342384|
|[v13.1.6](https://github.com/electron/electron/releases/tag/v13.1.6)|2021-07-05||no|89|14.16.0|91.0.4472.124|192613|
|[v13.1.5](https://github.com/electron/electron/releases/tag/v13.1.5)|2021-07-01||no|89|14.16.0|91.0.4472.124|100639|
|[v13.1.4](https://github.com/electron/electron/releases/tag/v13.1.4)|2021-06-22||no|89|14.16.0|91.0.4472.106|215667|
|[v13.1.3](https://github.com/electron/electron/releases/tag/v13.1.3)|2021-06-21||no|89|14.16.0|91.0.4472.106|24149|
|[v13.1.2](https://github.com/electron/electron/releases/tag/v13.1.2)|2021-06-09||no|89|14.16.0|91.0.4472.77|212592|
|[v13.1.1](https://github.com/electron/electron/releases/tag/v13.1.1)|2021-06-04||no|89|14.16.0|91.0.4472.77|64398|
|[v13.1.0](https://github.com/electron/electron/releases/tag/v13.1.0)|2021-06-03||no|89|14.16.0|91.0.4472.77|42300|
|[v13.0.1](https://github.com/electron/electron/releases/tag/v13.0.1)|2021-05-25||no|89|14.16.0|91.0.4472.69|132212|
|[v13.0.0](https://github.com/electron/electron/releases/tag/v13.0.0)|2021-05-25||no|89|14.16.0|91.0.4472.69|524544|
|[v13.0.0-nightly.20210303](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210303)|2021-03-03||yes|89|14.16.0|90.0.4402.0|587|
|[v13.0.0-nightly.20210302](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210302)|2021-03-02||yes|89|14.16.0|90.0.4402.0|464|
|[v13.0.0-nightly.20210301](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210301)|2021-03-01||yes|89|14.16.0|90.0.4402.0|470|
|[v13.0.0-nightly.20210226](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210226)|2021-02-26||yes|89|14.16.0|90.0.4402.0|552|
|[v13.0.0-nightly.20210225](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210225)|2021-02-25||yes|89|14.15.4|90.0.4402.0|446|
|[v13.0.0-nightly.20210222](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210222)|2021-02-22||yes|89|14.15.4|90.0.4402.0|511|
|[v13.0.0-nightly.20210219](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210219)|2021-02-19||yes|89|14.15.4|90.0.4402.0|507|
|[v13.0.0-nightly.20210218](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210218)|2021-02-18||yes|89|14.15.4|90.0.4402.0|422|
|[v13.0.0-nightly.20210217](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210217)|2021-02-17||yes|89|14.15.4|90.0.4402.0|420|
|[v13.0.0-nightly.20210216](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210216)|2021-02-16||yes|89|14.15.4|90.0.4402.0|421|
|[v13.0.0-nightly.20210212](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210212)|2021-02-12||yes|89|14.15.4|90.0.4402.0|443|
|[v13.0.0-nightly.20210211](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210211)|2021-02-11||yes|89|14.15.4|90.0.4402.0|583|
|[v13.0.0-nightly.20210210](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210210)|2021-02-10||yes|89|14.15.4|90.0.4402.0|505|
|[v13.0.0-nightly.20210209](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210209)|2021-02-09||yes|89|14.15.4|89.0.4389.0|480|
|[v13.0.0-nightly.20210208](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210208)|2021-02-08||yes|89|14.15.4|89.0.4389.0|452|
|[v13.0.0-nightly.20210205](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210205)|2021-02-05||yes|89|14.15.4|89.0.4389.0|595|
|[v13.0.0-nightly.20210203](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210203)|2021-02-03||yes|89|14.15.4|89.0.4389.0|517|
|[v13.0.0-nightly.20210202](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210202)|2021-02-02||yes|89|14.15.4|89.0.4389.0|479|
|[v13.0.0-nightly.20210201](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210201)|2021-02-01||yes|89|14.15.4|89.0.4389.0|479|
|[v13.0.0-nightly.20210129](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210129)|2021-01-29||yes|89|14.15.4|89.0.4389.0|570|
|[v13.0.0-nightly.20210128](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210128)|2021-01-28||yes|89|14.15.4|89.0.4389.0|480|
|[v13.0.0-nightly.20210127](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210127)|2021-01-27||yes|89|14.15.4|89.0.4389.0|467|
|[v13.0.0-nightly.20210125](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210125)|2021-01-25||yes|89|14.15.4|89.0.4386.0|524|
|[v13.0.0-nightly.20210122](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210122)|2021-01-22||yes|89|14.15.4|89.0.4386.0|537|
|[v13.0.0-nightly.20210118](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210118)|2021-01-18||yes|89|14.15.4|89.0.4386.0|581|
|[v13.0.0-nightly.20210114](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210114)|2021-01-14||yes|89|14.15.4|89.0.4386.0|791|
|[v13.0.0-nightly.20210113](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210113)|2021-01-13||yes|89|14.15.4|89.0.4386.0|485|
|[v13.0.0-nightly.20210111](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210111)|2021-01-11||yes|89|14.15.4|89.0.4359.0|518|
|[v13.0.0-nightly.20210108](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210108)|2021-01-08||yes|89|14.15.4|89.0.4359.0|549|
|[v13.0.0-nightly.20210104](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20210104)|2021-01-04||yes|89|14.15.2|89.0.4359.0|563|
|[v13.0.0-nightly.20201223](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201223)|2020-12-23||yes|89|14.15.2|89.0.4359.0|935|
|[v13.0.0-nightly.20201222](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201222)|2020-12-22||yes|89|14.15.2|89.0.4349.0|582|
|[v13.0.0-nightly.20201221](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201221)|2020-12-21||yes|89|14.15.2|89.0.4349.0|574|
|[v13.0.0-nightly.20201216](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201216)|2020-12-16||yes|89|14.15.1|89.0.4349.0|678|
|[v13.0.0-nightly.20201215](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201215)|2020-12-15||yes|89|14.15.1|89.0.4349.0|543|
|[v13.0.0-nightly.20201214](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201214)|2020-12-14||yes|89|14.15.1|89.0.4328.0|546|
|[v13.0.0-nightly.20201211](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201211)|2020-12-11||yes|89|14.15.1|89.0.4328.0|619|
|[v13.0.0-nightly.20201210](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201210)|2020-12-10||yes|89|14.15.1|89.0.4328.0|555|
|[v13.0.0-nightly.20201209](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201209)|2020-12-09||yes|89|14.15.1|89.0.4328.0|557|
|[v13.0.0-nightly.20201208](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201208)|2020-12-08||yes|89|14.15.1|89.0.4328.0|551|
|[v13.0.0-nightly.20201207](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201207)|2020-12-07||yes|89|14.15.1|89.0.4328.0|461|
|[v13.0.0-nightly.20201204](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201204)|2020-12-04||yes|89|14.15.1|89.0.4328.0|499|
|[v13.0.0-nightly.20201203](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201203)|2020-12-03||yes|89|14.15.1|89.0.4328.0|536|
|[v13.0.0-nightly.20201202](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201202)|2020-12-02||yes|89|14.15.1|89.0.4328.0|537|
|[v13.0.0-nightly.20201201](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201201)|2020-12-01||yes|89|14.15.1|89.0.4328.0|549|
|[v13.0.0-nightly.20201130](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201130)|2020-11-30||yes|89|14.15.1|89.0.4328.0|671|
|[v13.0.0-nightly.20201127](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201127)|2020-11-27||yes|89|14.15.1|89.0.4328.0|737|
|[v13.0.0-nightly.20201126](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201126)|2020-11-26||yes|89|14.15.1|89.0.4328.0|678|
|[v13.0.0-nightly.20201124](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201124)|2020-11-24||yes|89|14.15.1|89.0.4328.0|698|
|[v13.0.0-nightly.20201123](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201123)|2020-11-23||yes|87|14.15.1|89.0.4328.0|683|
|[v13.0.0-nightly.20201119](https://github.com/electron/electron/releases/tag/v13.0.0-nightly.20201119)|2020-11-19||yes|87|14.15.1|89.0.4328.0|753|
|[v13.0.0-beta.28](https://github.com/electron/electron/releases/tag/v13.0.0-beta.28)|2021-05-20|beta-13-x-y|yes|89|14.16.0|91.0.4472.38|2381|
|[v13.0.0-beta.27](https://github.com/electron/electron/releases/tag/v13.0.0-beta.27)|2021-05-17||yes|89|14.16.0|91.0.4472.38|6389|
|[v13.0.0-beta.26](https://github.com/electron/electron/releases/tag/v13.0.0-beta.26)|2021-05-13||yes|89|14.16.0|91.0.4472.38|2488|
|[v13.0.0-beta.24](https://github.com/electron/electron/releases/tag/v13.0.0-beta.24)|2021-05-11||yes|89|14.16.0|91.0.4472.38|3073|
|[v13.0.0-beta.23](https://github.com/electron/electron/releases/tag/v13.0.0-beta.23)|2021-05-07||yes|89|14.16.0|91.0.4472.33|2181|
|[v13.0.0-beta.22](https://github.com/electron/electron/releases/tag/v13.0.0-beta.22)|2021-05-06||yes|89|14.16.0|91.0.4472.33|1559|
|[v13.0.0-beta.21](https://github.com/electron/electron/releases/tag/v13.0.0-beta.21)|2021-05-05||yes|89|14.16.0|91.0.4472.33|3235|
|[v13.0.0-beta.20](https://github.com/electron/electron/releases/tag/v13.0.0-beta.20)|2021-05-04||yes|89|14.16.0|91.0.4448.0|2050|
|[v13.0.0-beta.18](https://github.com/electron/electron/releases/tag/v13.0.0-beta.18)|2021-04-26||yes|89|14.16.0|91.0.4448.0|3276|
|[v13.0.0-beta.17](https://github.com/electron/electron/releases/tag/v13.0.0-beta.17)|2021-04-22||yes|89|14.16.0|91.0.4448.0|2009|
|[v13.0.0-beta.16](https://github.com/electron/electron/releases/tag/v13.0.0-beta.16)|2021-04-20||yes|89|14.16.0|91.0.4448.0|1841|
|[v13.0.0-beta.14](https://github.com/electron/electron/releases/tag/v13.0.0-beta.14)|2021-04-14||yes|89|14.16.0|91.0.4448.0|2493|
|[v13.0.0-beta.13](https://github.com/electron/electron/releases/tag/v13.0.0-beta.13)|2021-04-12||yes|89|14.16.0|90.0.4415.0|2199|
|[v13.0.0-beta.12](https://github.com/electron/electron/releases/tag/v13.0.0-beta.12)|2021-04-08||yes|89|14.16.0|90.0.4415.0|10543|
|[v13.0.0-beta.11](https://github.com/electron/electron/releases/tag/v13.0.0-beta.11)|2021-04-05||yes|89|14.16.0|90.0.4415.0|2022|
|[v13.0.0-beta.9](https://github.com/electron/electron/releases/tag/v13.0.0-beta.9)|2021-03-29||yes|89|14.16.0|90.0.4415.0|2392|
|[v13.0.0-beta.8](https://github.com/electron/electron/releases/tag/v13.0.0-beta.8)|2021-03-25||yes|89|14.16.0|90.0.4415.0|3265|
|[v13.0.0-beta.7](https://github.com/electron/electron/releases/tag/v13.0.0-beta.7)|2021-03-22||yes|89|14.16.0|90.0.4415.0|1941|
|[v13.0.0-beta.6](https://github.com/electron/electron/releases/tag/v13.0.0-beta.6)|2021-03-18||yes|89|14.16.0|90.0.4415.0|1974|
|[v13.0.0-beta.5](https://github.com/electron/electron/releases/tag/v13.0.0-beta.5)|2021-03-15||yes|89|14.16.0|90.0.4415.0|2154|
|[v13.0.0-beta.4](https://github.com/electron/electron/releases/tag/v13.0.0-beta.4)|2021-03-11||yes|89|14.16.0|90.0.4415.0|3565|
|[v13.0.0-beta.3](https://github.com/electron/electron/releases/tag/v13.0.0-beta.3)|2021-03-08||yes|89|14.16.0|90.0.4402.0|2024|
|[v13.0.0-beta.2](https://github.com/electron/electron/releases/tag/v13.0.0-beta.2)|2021-03-05||yes|89|14.16.0|90.0.4402.0|1838|
|[v12.2.3](https://github.com/electron/electron/releases/tag/v12.2.3)|2021-11-15|12-x-y|no|87|14.16.0|89.0.4389.128|755916|
|[v12.2.2](https://github.com/electron/electron/releases/tag/v12.2.2)|2021-10-11||no|87|14.16.0|89.0.4389.128|141036|
|[v12.2.1](https://github.com/electron/electron/releases/tag/v12.2.1)|2021-09-30||no|87|14.16.0|89.0.4389.128|150309|
|[v12.2.0](https://github.com/electron/electron/releases/tag/v12.2.0)|2021-09-28||no|87|14.16.0|89.0.4389.128|20098|
|[v12.1.2](https://github.com/electron/electron/releases/tag/v12.1.2)|2021-09-20||no|87|14.16.0|89.0.4389.128|35309|
|[v12.1.1](https://github.com/electron/electron/releases/tag/v12.1.1)|2021-09-13||no|87|14.16.0|89.0.4389.128|31975|
|[v12.1.0](https://github.com/electron/electron/releases/tag/v12.1.0)|2021-08-31||no|87|14.16.0|89.0.4389.128|138353|
|[v12.0.18](https://github.com/electron/electron/releases/tag/v12.0.18)|2021-08-27||no|87|14.16.0|89.0.4389.128|20459|
|[v12.0.17](https://github.com/electron/electron/releases/tag/v12.0.17)|2021-08-18||no|87|14.16.0|89.0.4389.128|50472|
|[v12.0.16](https://github.com/electron/electron/releases/tag/v12.0.16)|2021-08-03||no|87|14.16.0|89.0.4389.128|85031|
|[v12.0.15](https://github.com/electron/electron/releases/tag/v12.0.15)|2021-07-15||no|87|14.16.0|89.0.4389.128|69798|
|[v12.0.14](https://github.com/electron/electron/releases/tag/v12.0.14)|2021-07-06||no|87|14.16.0|89.0.4389.128|49959|
|[v12.0.13](https://github.com/electron/electron/releases/tag/v12.0.13)|2021-06-29||no|87|14.16.0|89.0.4389.128|114585|
|[v12.0.12](https://github.com/electron/electron/releases/tag/v12.0.12)|2021-06-21||no|87|14.16.0|89.0.4389.128|63560|
|[v12.0.11](https://github.com/electron/electron/releases/tag/v12.0.11)|2021-06-09||no|87|14.16.0|89.0.4389.128|80765|
|[v12.0.10](https://github.com/electron/electron/releases/tag/v12.0.10)|2021-06-03||no|87|14.16.0|89.0.4389.128|39319|
|[v12.0.9](https://github.com/electron/electron/releases/tag/v12.0.9)|2021-05-19||no|87|14.16.0|89.0.4389.128|213604|
|[v12.0.8](https://github.com/electron/electron/releases/tag/v12.0.8)|2021-05-17||no|87|14.16.0|89.0.4389.128|74081|
|[v12.0.7](https://github.com/electron/electron/releases/tag/v12.0.7)|2021-05-07||no|87|14.16.0|89.0.4389.128|213581|
|[v12.0.6](https://github.com/electron/electron/releases/tag/v12.0.6)|2021-04-30||no|87|14.16.0|89.0.4389.128|178940|
|[v12.0.5](https://github.com/electron/electron/releases/tag/v12.0.5)|2021-04-21||no|87|14.16.0|89.0.4389.128|240057|
|[v12.0.4](https://github.com/electron/electron/releases/tag/v12.0.4)|2021-04-13||no|87|14.16.0|89.0.4389.114|214296|
|[v12.0.3](https://github.com/electron/electron/releases/tag/v12.0.3)|2021-04-13||no|87|14.16.0|89.0.4389.114|80920|
|[v12.0.2](https://github.com/electron/electron/releases/tag/v12.0.2)|2021-03-24||no|87|14.16.0|89.0.4389.90|360784|
|[v12.0.1](https://github.com/electron/electron/releases/tag/v12.0.1)|2021-03-10||no|87|14.16.0|89.0.4389.82|250474|
|[v12.0.0](https://github.com/electron/electron/releases/tag/v12.0.0)|2021-03-02||no|87|14.16.0|89.0.4389.69|637545|
|[v12.0.0-nightly.20201116](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201116)|2020-11-17||yes|87|14.15.0|88.0.4324.0|1130|
|[v12.0.0-nightly.20201112](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201112)|2020-11-12||yes|87|14.15.0|88.0.4306.0|852|
|[v12.0.0-nightly.20201111](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201111)|2020-11-11||yes|87|14.15.0|88.0.4306.0|685|
|[v12.0.0-nightly.20201106](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201106)|2020-11-06||yes|87|14.15.0|88.0.4306.0|812|
|[v12.0.0-nightly.20201105](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201105)|2020-11-05||yes|87|14.15.0|88.0.4306.0|680|
|[v12.0.0-nightly.20201104](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201104)|2020-11-04||yes|87|14.15.0|88.0.4306.0|713|
|[v12.0.0-nightly.20201103](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201103)|2020-11-03||yes|87|14.15.0|88.0.4306.0|673|
|[v12.0.0-nightly.20201102](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201102)|2020-11-02||yes|87|14.15.0|88.0.4306.0|693|
|[v12.0.0-nightly.20201030](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201030)|2020-10-30||yes|87|14.15.0|88.0.4306.0|650|
|[v12.0.0-nightly.20201026](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201026)|2020-10-26||yes|87|14.14.0|88.0.4292.0|866|
|[v12.0.0-nightly.20201023](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201023)|2020-10-23||yes|87|14.14.0|88.0.4292.0|738|
|[v12.0.0-nightly.20201015](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201015)|2020-10-15||yes|87|14.13.1|87.0.4268.0|879|
|[v12.0.0-nightly.20201014](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201014)|2020-10-14||yes|87|14.13.1|87.0.4268.0|688|
|[v12.0.0-nightly.20201013](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20201013)|2020-10-13||yes|87|14.13.1|87.0.4268.0|689|
|[v12.0.0-nightly.20200914](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20200914)|2020-09-14||yes|82|12.18.3|86.0.4234.0|1532|
|[v12.0.0-nightly.20200911](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20200911)|2020-09-11||yes|82|12.18.3|86.0.4234.0|655|
|[v12.0.0-nightly.20200910](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20200910)|2020-09-10||yes|82|12.18.3|86.0.4234.0|773|
|[v12.0.0-nightly.20200907](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20200907)|2020-09-07||yes|82|12.18.3|86.0.4234.0|660|
|[v12.0.0-nightly.20200903](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20200903)|2020-09-03||yes|82|12.18.3|86.0.4234.0|952|
|[v12.0.0-nightly.20200902](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20200902)|2020-09-02||yes|82|12.18.3|86.0.4234.0|677|
|[v12.0.0-nightly.20200831](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20200831)|2020-08-31||yes|82|12.18.3|86.0.4234.0|714|
|[v12.0.0-nightly.20200827](https://github.com/electron/electron/releases/tag/v12.0.0-nightly.20200827)|2020-08-27||yes|82|12.18.3|86.0.4234.0|752|
|[v12.0.0-beta.31](https://github.com/electron/electron/releases/tag/v12.0.0-beta.31)|2021-03-01|beta-12-x-y|yes|87|14.16.0|89.0.4389.58|2448|
|[v12.0.0-beta.30](https://github.com/electron/electron/releases/tag/v12.0.0-beta.30)|2021-02-25||yes|87|14.15.1|89.0.4389.58|3434|
|[v12.0.0-beta.29](https://github.com/electron/electron/releases/tag/v12.0.0-beta.29)|2021-02-23||yes|87|14.15.1|89.0.4389.23|2206|
|[v12.0.0-beta.28](https://github.com/electron/electron/releases/tag/v12.0.0-beta.28)|2021-02-22||yes|87|14.15.1|89.0.4389.23|3528|
|[v12.0.0-beta.27](https://github.com/electron/electron/releases/tag/v12.0.0-beta.27)|2021-02-19||yes|87|14.15.1|89.0.4389.23|4462|
|[v12.0.0-beta.26](https://github.com/electron/electron/releases/tag/v12.0.0-beta.26)|2021-02-15||yes|87|14.15.1|89.0.4388.2|6695|
|[v12.0.0-beta.25](https://github.com/electron/electron/releases/tag/v12.0.0-beta.25)|2021-02-11||yes|87|14.15.1|89.0.4388.2|4623|
|[v12.0.0-beta.24](https://github.com/electron/electron/releases/tag/v12.0.0-beta.24)|2021-02-09||yes|87|14.15.1|89.0.4388.2|5979|
|[v12.0.0-beta.23](https://github.com/electron/electron/releases/tag/v12.0.0-beta.23)|2021-02-09||yes|87|14.15.1|89.0.4388.2|1921|
|[v12.0.0-beta.22](https://github.com/electron/electron/releases/tag/v12.0.0-beta.22)|2021-02-04||yes|87|14.15.1|89.0.4388.2|3887|
|[v12.0.0-beta.21](https://github.com/electron/electron/releases/tag/v12.0.0-beta.21)|2021-02-03||yes|87|14.15.1|89.0.4388.2|4707|
|[v12.0.0-beta.20](https://github.com/electron/electron/releases/tag/v12.0.0-beta.20)|2021-02-01||yes|87|14.15.1|89.0.4348.1|3106|
|[v12.0.0-beta.19](https://github.com/electron/electron/releases/tag/v12.0.0-beta.19)|2021-01-28||yes|87|14.15.1|89.0.4348.1|4437|
|[v12.0.0-beta.18](https://github.com/electron/electron/releases/tag/v12.0.0-beta.18)|2021-01-25||yes|87|14.15.1|89.0.4348.1|4589|
|[v12.0.0-beta.16](https://github.com/electron/electron/releases/tag/v12.0.0-beta.16)|2021-01-18||yes|87|14.15.1|89.0.4348.1|5450|
|[v12.0.0-beta.14](https://github.com/electron/electron/releases/tag/v12.0.0-beta.14)|2021-01-11||yes|87|14.15.1|89.0.4328.0|15293|
|[v12.0.0-beta.12](https://github.com/electron/electron/releases/tag/v12.0.0-beta.12)|2020-12-21||yes|87|14.15.1|89.0.4328.0|4601|
|[v12.0.0-beta.11](https://github.com/electron/electron/releases/tag/v12.0.0-beta.11)|2020-12-17||yes|87|14.15.1|89.0.4328.0|4533|
|[v12.0.0-beta.10](https://github.com/electron/electron/releases/tag/v12.0.0-beta.10)|2020-12-14||yes|87|14.15.1|89.0.4328.0|2860|
|[v12.0.0-beta.9](https://github.com/electron/electron/releases/tag/v12.0.0-beta.9)|2020-12-11||yes|87|14.15.1|89.0.4328.0|4653|
|[v12.0.0-beta.8](https://github.com/electron/electron/releases/tag/v12.0.0-beta.8)|2020-12-10||yes|87|14.15.1|89.0.4328.0|1882|
|[v12.0.0-beta.7](https://github.com/electron/electron/releases/tag/v12.0.0-beta.7)|2020-12-07||yes|87|14.15.1|89.0.4328.0|4877|
|[v12.0.0-beta.6](https://github.com/electron/electron/releases/tag/v12.0.0-beta.6)|2020-12-03||yes|87|14.15.1|89.0.4328.0|4887|
|[v12.0.0-beta.5](https://github.com/electron/electron/releases/tag/v12.0.0-beta.5)|2020-11-30||yes|87|14.15.1|89.0.4328.0|2515|
|[v12.0.0-beta.4](https://github.com/electron/electron/releases/tag/v12.0.0-beta.4)|2020-11-26||yes|87|14.15.1|89.0.4328.0|3595|
|[v12.0.0-beta.3](https://github.com/electron/electron/releases/tag/v12.0.0-beta.3)|2020-11-23||yes|87|14.15.1|89.0.4328.0|2229|
|[v12.0.0-beta.1](https://github.com/electron/electron/releases/tag/v12.0.0-beta.1)|2020-11-19||yes|87|14.15.1|89.0.4328.0|2514|
|[v11.5.0](https://github.com/electron/electron/releases/tag/v11.5.0)|2021-08-31|11-x-y|no|85|12.18.3|87.0.4280.141|1667699|
|[v11.4.12](https://github.com/electron/electron/releases/tag/v11.4.12)|2021-08-18||no|85|12.18.3|87.0.4280.141|127084|
|[v11.4.11](https://github.com/electron/electron/releases/tag/v11.4.11)|2021-08-03||no|85|12.18.3|87.0.4280.141|98005|
|[v11.4.10](https://github.com/electron/electron/releases/tag/v11.4.10)|2021-07-06||no|85|12.18.3|87.0.4280.141|277127|
|[v11.4.9](https://github.com/electron/electron/releases/tag/v11.4.9)|2021-06-21||no|85|12.18.3|87.0.4280.141|210011|
|[v11.4.8](https://github.com/electron/electron/releases/tag/v11.4.8)|2021-06-03||no|85|12.18.3|87.0.4280.141|197697|
|[v11.4.7](https://github.com/electron/electron/releases/tag/v11.4.7)|2021-05-17||no|85|12.18.3|87.0.4280.141|167008|
|[v11.4.6](https://github.com/electron/electron/releases/tag/v11.4.6)|2021-05-08||no|85|12.18.3|87.0.4280.141|195862|
|[v11.4.5](https://github.com/electron/electron/releases/tag/v11.4.5)|2021-05-05||no|85|12.18.3|87.0.4280.141|45892|
|[v11.4.4](https://github.com/electron/electron/releases/tag/v11.4.4)|2021-04-27||no|85|12.18.3|87.0.4280.141|94697|
|[v11.4.3](https://github.com/electron/electron/releases/tag/v11.4.3)|2021-04-14||no|85|12.18.3|87.0.4280.141|250140|
|[v11.4.2](https://github.com/electron/electron/releases/tag/v11.4.2)|2021-04-02||no|85|12.18.3|87.0.4280.141|122126|
|[v11.4.1](https://github.com/electron/electron/releases/tag/v11.4.1)|2021-03-23||no|85|12.18.3|87.0.4280.141|94395|
|[v11.4.0](https://github.com/electron/electron/releases/tag/v11.4.0)|2021-03-23|origin/11-x-y|no|85|12.18.3|87.0.4280.141|10507|
|[v11.3.0](https://github.com/electron/electron/releases/tag/v11.3.0)|2021-02-19||no|85|12.18.3|87.0.4280.141|603236|
|[v11.2.3](https://github.com/electron/electron/releases/tag/v11.2.3)|2021-02-06||no|85|12.18.3|87.0.4280.141|409196|
|[v11.2.2](https://github.com/electron/electron/releases/tag/v11.2.2)|2021-02-02||no|85|12.18.3|87.0.4280.141|123034|
|[v11.2.1](https://github.com/electron/electron/releases/tag/v11.2.1)|2021-01-23||no|85|12.18.3|87.0.4280.141|276043|
|[v11.2.0](https://github.com/electron/electron/releases/tag/v11.2.0)|2021-01-13||no|85|12.18.3|87.0.4280.141|738912|
|[v11.1.1](https://github.com/electron/electron/releases/tag/v11.1.1)|2020-12-21||no|85|12.18.3|87.0.4280.88|520895|
|[v11.1.0](https://github.com/electron/electron/releases/tag/v11.1.0)|2020-12-12||no|85|12.18.3|87.0.4280.88|379906|
|[v11.0.5](https://github.com/electron/electron/releases/tag/v11.0.5)|2020-12-11||no|85|12.18.3|87.0.4280.88|72955|
|[v11.0.4](https://github.com/electron/electron/releases/tag/v11.0.4)|2020-12-07||no|85|12.18.3|87.0.4280.67|113061|
|[v11.0.3](https://github.com/electron/electron/releases/tag/v11.0.3)|2020-11-24||no|85|12.18.3|87.0.4280.67|269592|
|[v11.0.2](https://github.com/electron/electron/releases/tag/v11.0.2)|2020-11-19||no|85|12.18.3|87.0.4280.67|77954|
|[v11.0.1](https://github.com/electron/electron/releases/tag/v11.0.1)|2020-11-17||no|85|12.18.3|87.0.4280.60|134612|
|[v11.0.0](https://github.com/electron/electron/releases/tag/v11.0.0)|2020-11-16||no|85|12.18.3|87.0.4280.60|694351|
|[v11.0.0-nightly.20200826](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200826)|2020-08-26||yes|82|12.18.3|86.0.4234.0|833|
|[v11.0.0-nightly.20200825](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200825)|2020-08-25||yes|82|12.18.3|86.0.4234.0|809|
|[v11.0.0-nightly.20200824](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200824)|2020-08-24||yes|82|12.18.3|86.0.4234.0|1004|
|[v11.0.0-nightly.20200822](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200822)|2020-08-23||yes|82|12.18.3|86.0.4234.0|531|
|[v11.0.0-nightly.20200812](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200812)|2020-08-12||yes|82|12.18.3|86.0.4209.0|5166|
|[v11.0.0-nightly.20200811](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200811)|2020-08-11||yes|82|12.18.3|86.0.4209.0|762|
|[v11.0.0-nightly.20200805](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200805)|2020-08-05||yes|82|12.18.3|86.0.4209.0|933|
|[v11.0.0-nightly.20200804](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200804)|2020-08-04||yes|82|12.18.3|86.0.4209.0|689|
|[v11.0.0-nightly.20200803](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200803)|2020-08-03||yes|82|12.18.3|86.0.4209.0|2548|
|[v11.0.0-nightly.20200731](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200731)|2020-07-31||yes|82|12.18.3|86.0.4209.0|760|
|[v11.0.0-nightly.20200730](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200730)|2020-07-30||yes|82|12.18.3|86.0.4209.0|694|
|[v11.0.0-nightly.20200729](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200729)|2020-07-29||yes|82|12.18.3|86.0.4209.0|740|
|[v11.0.0-nightly.20200724](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200724)|2020-07-24||yes|82|12.18.2|86.0.4209.0|806|
|[v11.0.0-nightly.20200723](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200723)|2020-07-23||yes|82|12.18.2|86.0.4209.0|695|
|[v11.0.0-nightly.20200721](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200721)|2020-07-22||yes|82|12.18.2|86.0.4203.0|1139|
|[v11.0.0-nightly.20200720](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200720)|2020-07-20||yes|82|12.18.2|86.0.4203.0|618|
|[v11.0.0-nightly.20200717](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200717)|2020-07-17||yes|82|12.18.2|86.0.4203.0|480|
|[v11.0.0-nightly.20200716](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200716)|2020-07-16||yes|82|12.18.2|86.0.4203.0|591|
|[v11.0.0-nightly.20200709](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200709)|2020-07-09||yes|82|12.18.2|85.0.4179.0|607|
|[v11.0.0-nightly.20200708](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200708)|2020-07-08||yes|82|12.18.2|85.0.4179.0|789|
|[v11.0.0-nightly.20200707](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200707)|2020-07-07||yes|82|12.18.2|85.0.4179.0|574|
|[v11.0.0-nightly.20200706](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200706)|2020-07-06||yes|82|12.18.2|85.0.4179.0|575|
|[v11.0.0-nightly.20200703](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200703)|2020-07-03||yes|82|12.18.2|85.0.4179.0|642|
|[v11.0.0-nightly.20200702](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200702)|2020-07-02||yes|82|12.18.2|85.0.4179.0|585|
|[v11.0.0-nightly.20200701](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200701)|2020-07-01||yes|82|12.18.1|85.0.4179.0|534|
|[v11.0.0-nightly.20200619](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200619)|2020-06-19||yes|82|12.18.1|85.0.4162.0|796|
|[v11.0.0-nightly.20200618](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200618)|2020-06-18||yes|82|12.18.0|85.0.4162.0|524|
|[v11.0.0-nightly.20200617](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200617)|2020-06-17||yes|82|12.16.3|85.0.4162.0|522|
|[v11.0.0-nightly.20200616](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200616)|2020-06-16||yes|82|12.16.3|85.0.4162.0|524|
|[v11.0.0-nightly.20200615](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200615)|2020-06-15||yes|82|12.16.3|85.0.4162.0|341|
|[v11.0.0-nightly.20200611](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200611)|2020-06-11||yes|82|12.16.3|85.0.4162.0|618|
|[v11.0.0-nightly.20200610](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200610)|2020-06-10||yes|82|12.16.3|85.0.4162.0|343|
|[v11.0.0-nightly.20200609](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200609)|2020-06-09||yes|82|12.16.3|85.0.4162.0|514|
|[v11.0.0-nightly.20200604](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200604)|2020-06-04||yes|82|12.16.3|85.0.4162.0|329|
|[v11.0.0-nightly.20200603](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200603)|2020-06-03||yes|82|12.16.3|85.0.4162.0|675|
|[v11.0.0-nightly.20200602](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200602)|2020-06-02||yes|82|12.16.3|85.0.4162.0|516|
|[v11.0.0-nightly.20200529](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200529)|2020-05-29||yes|82|12.16.3|85.0.4156.0|541|
|[v11.0.0-nightly.20200526](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200526)|2020-05-26||yes|82|12.16.3|84.0.4129.0|478|
|[v11.0.0-nightly.20200525](https://github.com/electron/electron/releases/tag/v11.0.0-nightly.20200525)|2020-05-25||yes|82|12.16.3|84.0.4129.0|377|
|[v11.0.0-beta.23](https://github.com/electron/electron/releases/tag/v11.0.0-beta.23)|2020-11-14|beta-11-x-y|yes|85|12.18.3|87.0.4280.47|3906|
|[v11.0.0-beta.22](https://github.com/electron/electron/releases/tag/v11.0.0-beta.22)|2020-11-12||yes|85|12.18.3|87.0.4280.47|4419|
|[v11.0.0-beta.20](https://github.com/electron/electron/releases/tag/v11.0.0-beta.20)|2020-11-06||yes|85|12.18.3|87.0.4280.40|11510|
|[v11.0.0-beta.19](https://github.com/electron/electron/releases/tag/v11.0.0-beta.19)|2020-11-02||yes|85|12.18.3|87.0.4280.27|4887|
|[v11.0.0-beta.18](https://github.com/electron/electron/releases/tag/v11.0.0-beta.18)|2020-10-29||yes|85|12.18.3|87.0.4280.27|4843|
|[v11.0.0-beta.17](https://github.com/electron/electron/releases/tag/v11.0.0-beta.17)|2020-10-26||yes|85|12.18.3|87.0.4280.27|6082|
|[v11.0.0-beta.16](https://github.com/electron/electron/releases/tag/v11.0.0-beta.16)|2020-10-24||yes|85|12.18.3|87.0.4280.27|5144|
|[v11.0.0-beta.13](https://github.com/electron/electron/releases/tag/v11.0.0-beta.13)|2020-10-15||yes|85|12.18.3|87.0.4280.11|4107|
|[v11.0.0-beta.12](https://github.com/electron/electron/releases/tag/v11.0.0-beta.12)|2020-10-14||yes|85|12.18.3|87.0.4280.11|5025|
|[v11.0.0-beta.11](https://github.com/electron/electron/releases/tag/v11.0.0-beta.11)|2020-10-05||yes|85|12.18.3|87.0.4251.1|3081|
|[v11.0.0-beta.9](https://github.com/electron/electron/releases/tag/v11.0.0-beta.9)|2020-09-28||yes|82|12.18.3|87.0.4251.1|5285|
|[v11.0.0-beta.8](https://github.com/electron/electron/releases/tag/v11.0.0-beta.8)|2020-09-25||yes|82|12.18.3|87.0.4251.1|2477|
|[v11.0.0-beta.7](https://github.com/electron/electron/releases/tag/v11.0.0-beta.7)|2020-09-14||yes|82|12.18.3|86.0.4234.0|3752|
|[v11.0.0-beta.6](https://github.com/electron/electron/releases/tag/v11.0.0-beta.6)|2020-09-10||yes|82|12.18.3|86.0.4234.0|3319|
|[v11.0.0-beta.5](https://github.com/electron/electron/releases/tag/v11.0.0-beta.5)|2020-09-07||yes|82|12.18.3|86.0.4234.0|2491|
|[v11.0.0-beta.4](https://github.com/electron/electron/releases/tag/v11.0.0-beta.4)|2020-09-03||yes|82|12.18.3|86.0.4234.0|5634|
|[v11.0.0-beta.3](https://github.com/electron/electron/releases/tag/v11.0.0-beta.3)|2020-08-31||yes|82|12.18.3|86.0.4234.0|2557|
|[v11.0.0-beta.1](https://github.com/electron/electron/releases/tag/v11.0.0-beta.1)|2020-08-26||yes|82|12.18.3|86.0.4234.0|3113|
|[v10.4.7](https://github.com/electron/electron/releases/tag/v10.4.7)|2021-05-24|10-x-y|no|82|12.16.3|85.0.4183.121|246275|
|[v10.4.6](https://github.com/electron/electron/releases/tag/v10.4.6)|2021-05-19||no|82|12.16.3|85.0.4183.121|8894|
|[v10.4.5](https://github.com/electron/electron/releases/tag/v10.4.5)|2021-05-05||no|82|12.16.3|85.0.4183.121|51622|
|[v10.4.4](https://github.com/electron/electron/releases/tag/v10.4.4)|2021-04-27||no|82|12.16.3|85.0.4183.121|23236|
|[v10.4.3](https://github.com/electron/electron/releases/tag/v10.4.3)|2021-04-14||no|82|12.16.3|85.0.4183.121|77158|
|[v10.4.2](https://github.com/electron/electron/releases/tag/v10.4.2)|2021-03-23||no|82|12.16.3|85.0.4183.121|51958|
|[v10.4.1](https://github.com/electron/electron/releases/tag/v10.4.1)|2021-03-15||no|82|12.16.3|85.0.4183.121|15595|
|[v10.4.0](https://github.com/electron/electron/releases/tag/v10.4.0)|2021-02-20||no|82|12.16.3|85.0.4183.121|44997|
|[v10.3.2](https://github.com/electron/electron/releases/tag/v10.3.2)|2021-02-05||no|82|12.16.3|85.0.4183.121|51919|
|[v10.3.1](https://github.com/electron/electron/releases/tag/v10.3.1)|2021-01-27||no|82|12.16.3|85.0.4183.121|42095|
|[v10.3.0](https://github.com/electron/electron/releases/tag/v10.3.0)|2021-01-15||no|82|12.16.3|85.0.4183.121|44477|
|[v10.2.0](https://github.com/electron/electron/releases/tag/v10.2.0)|2020-12-12||no|82|12.16.3|85.0.4183.121|172736|
|[v10.1.7](https://github.com/electron/electron/releases/tag/v10.1.7)|2020-12-08||no|82|12.16.3|85.0.4183.121|26314|
|[v10.1.6](https://github.com/electron/electron/releases/tag/v10.1.6)|2020-11-18||no|82|12.16.3|85.0.4183.121|117658|
|[v10.1.5](https://github.com/electron/electron/releases/tag/v10.1.5)|2020-10-23||no|82|12.16.3|85.0.4183.121|436345|
|[v10.1.4](https://github.com/electron/electron/releases/tag/v10.1.4)|2020-10-20||no|82|12.16.3|85.0.4183.121|185552|
|[v10.1.3](https://github.com/electron/electron/releases/tag/v10.1.3)|2020-09-29||no|82|12.16.3|85.0.4183.121|334287|
|[v10.1.2](https://github.com/electron/electron/releases/tag/v10.1.2)|2020-09-14||no|82|12.16.3|85.0.4183.98|228401|
|[v10.1.1](https://github.com/electron/electron/releases/tag/v10.1.1)|2020-09-01||no|82|12.16.3|85.0.4183.93|217346|
|[v10.1.0](https://github.com/electron/electron/releases/tag/v10.1.0)|2020-08-28||no|82|12.16.3|85.0.4183.87|73306|
|[v10.0.1](https://github.com/electron/electron/releases/tag/v10.0.1)|2020-08-27||no|82|12.16.3|85.0.4183.86|5086|
|[v10.0.0](https://github.com/electron/electron/releases/tag/v10.0.0)|2020-08-24||no|82|12.16.3|85.0.4183.84|302922|
|[v10.0.0-nightly.20200521](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200521)|2020-05-21||yes|82|12.16.3|84.0.4129.0|565|
|[v10.0.0-nightly.20200520](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200520)|2020-05-20||yes|82|12.16.3|84.0.4129.0|385|
|[v10.0.0-nightly.20200519](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200519)|2020-05-19||yes|82|12.16.3|84.0.4129.0|376|
|[v10.0.0-nightly.20200518](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200518)|2020-05-18||yes|82|12.16.3|84.0.4129.0|407|
|[v10.0.0-nightly.20200515](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200515)|2020-05-15||yes|82|12.16.3|84.0.4129.0|347|
|[v10.0.0-nightly.20200514](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200514)|2020-05-14||yes|82|12.16.3|84.0.4129.0|485|
|[v10.0.0-nightly.20200513](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200513)|2020-05-13||yes|82|12.16.3|84.0.4129.0|368|
|[v10.0.0-nightly.20200512](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200512)|2020-05-12||yes|82|12.16.3|84.0.4129.0|369|
|[v10.0.0-nightly.20200511](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200511)|2020-05-11||yes|82|12.16.3|84.0.4129.0|392|
|[v10.0.0-nightly.20200508](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200508)|2020-05-08||yes|82|12.16.3|84.0.4129.0|613|
|[v10.0.0-nightly.20200507](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200507)|2020-05-07||yes|82|12.16.3|84.0.4129.0|407|
|[v10.0.0-nightly.20200506](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200506)|2020-05-06||yes|82|12.16.3|84.0.4129.0|358|
|[v10.0.0-nightly.20200505](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200505)|2020-05-05||yes|82|12.16.3|84.0.4129.0|367|
|[v10.0.0-nightly.20200504](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200504)|2020-05-04||yes|82|12.16.3|84.0.4129.0|316|
|[v10.0.0-nightly.20200501](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200501)|2020-05-01||yes|82|12.16.3|84.0.4129.0|467|
|[v10.0.0-nightly.20200430](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200430)|2020-04-30||yes|82|12.16.3|84.0.4125.0|352|
|[v10.0.0-nightly.20200429](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200429)|2020-04-29||yes|82|12.16.2|84.0.4125.0|340|
|[v10.0.0-nightly.20200428](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200428)|2020-04-28||yes|82|12.16.2|84.0.4125.0|374|
|[v10.0.0-nightly.20200427](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200427)|2020-04-27||yes|82|12.16.2|84.0.4125.0|350|
|[v10.0.0-nightly.20200423](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200423)|2020-04-24||yes|82|12.16.2|84.0.4121.0|396|
|[v10.0.0-nightly.20200422](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200422)|2020-04-22||yes|82|12.16.2|84.0.4121.0|484|
|[v10.0.0-nightly.20200417](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200417)|2020-04-17||yes|82|12.16.2|84.0.4115.0|513|
|[v10.0.0-nightly.20200416](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200416)|2020-04-16||yes|82|12.16.2|84.0.4115.0|1035|
|[v10.0.0-nightly.20200415](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200415)|2020-04-15||yes|82|12.16.2|84.0.4115.0|366|
|[v10.0.0-nightly.20200414](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200414)|2020-04-14||yes|82|12.16.1|84.0.4114.0|357|
|[v10.0.0-nightly.20200413](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200413)|2020-04-13||yes|82|12.16.1|83.0.4095.0|361|
|[v10.0.0-nightly.20200410](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200410)|2020-04-10||yes|82|12.16.1|83.0.4095.0|331|
|[v10.0.0-nightly.20200408](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200408)|2020-04-08||yes|82|12.16.1|83.0.4095.0|473|
|[v10.0.0-nightly.20200406](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200406)|2020-04-06||yes|82|12.16.1|83.0.4087.0|431|
|[v10.0.0-nightly.20200403](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200403)|2020-04-03||yes|82|12.16.1|83.0.4087.0|249|
|[v10.0.0-nightly.20200402](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200402)|2020-04-02||yes|82|12.16.1|83.0.4087.0|441|
|[v10.0.0-nightly.20200401](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200401)|2020-04-01||yes|82|12.16.1|83.0.4087.0|364|
|[v10.0.0-nightly.20200331](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200331)|2020-03-31||yes|82|12.16.1|83.0.4087.0|388|
|[v10.0.0-nightly.20200330](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200330)|2020-03-30||yes|82|12.16.1|83.0.4087.0|348|
|[v10.0.0-nightly.20200327](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200327)|2020-03-27||yes|82|12.16.1|83.0.4087.0|415|
|[v10.0.0-nightly.20200326](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200326)|2020-03-26||yes|82|12.16.1|83.0.4087.0|348|
|[v10.0.0-nightly.20200325](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200325)|2020-03-25||yes|82|12.16.1|83.0.4087.0|344|
|[v10.0.0-nightly.20200324](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200324)|2020-03-24||yes|82|12.16.1|83.0.4087.0|372|
|[v10.0.0-nightly.20200323](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200323)|2020-03-23||yes|82|12.16.1|83.0.4087.0|367|
|[v10.0.0-nightly.20200320](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200320)|2020-03-20||yes|82|12.16.1|83.0.4087.0|409|
|[v10.0.0-nightly.20200318](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200318)|2020-03-18||yes|82|12.16.1|83.0.4087.0|350|
|[v10.0.0-nightly.20200317](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200317)|2020-03-17||yes|82|12.16.1|83.0.4087.0|434|
|[v10.0.0-nightly.20200316](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200316)|2020-03-16||yes|82|12.16.1|83.0.4086.0|318|
|[v10.0.0-nightly.20200311](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200311)|2020-03-11||yes|82|12.16.1|82.0.4083.0|313|
|[v10.0.0-nightly.20200310](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200310)|2020-03-10||yes|82|12.16.1|82.0.4076.0|547|
|[v10.0.0-nightly.20200309](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200309)|2020-03-09||yes|82|12.16.1|82.0.4076.0|356|
|[v10.0.0-nightly.20200306](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200306)|2020-03-06||yes|82|12.16.1|82.0.4076.0|419|
|[v10.0.0-nightly.20200305](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200305)|2020-03-05||yes|82|12.16.1|82.0.4076.0|347|
|[v10.0.0-nightly.20200304](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200304)|2020-03-04||yes|82|12.16.1|82.0.4076.0|350|
|[v10.0.0-nightly.20200303](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200303)|2020-03-03||yes|82|12.16.1|82.0.4050.0|354|
|[v10.0.0-nightly.20200226](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200226)|2020-02-26||yes|82|12.16.1|82.0.4050.0|563|
|[v10.0.0-nightly.20200223](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200223)|2020-02-23||yes|82|12.15.0|82.0.4050.0|445|
|[v10.0.0-nightly.20200222](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200222)|2020-02-22||yes|82|12.15.0|82.0.4050.0|368|
|[v10.0.0-nightly.20200221](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200221)|2020-02-21||yes|82|12.15.0|82.0.4050.0|569|
|[v10.0.0-nightly.20200218](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200218)|2020-02-18||yes|82|12.15.0|82.0.4050.0|442|
|[v10.0.0-nightly.20200217](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200217)|2020-02-17||yes|82|12.15.0|82.0.4050.0|371|
|[v10.0.0-nightly.20200216](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200216)|2020-02-16||yes|82|12.15.0|82.0.4050.0|441|
|[v10.0.0-nightly.20200211](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200211)|2020-02-11||yes|76|12.15.0|82.0.4050.0|488|
|[v10.0.0-nightly.20200210](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200210)|2020-02-10||yes|76|12.14.1|82.0.4050.0|874|
|[v10.0.0-nightly.20200209](https://github.com/electron/electron/releases/tag/v10.0.0-nightly.20200209)|2020-02-09||yes|76|12.14.1|82.0.4050.0|403|
|[v10.0.0-beta.25](https://github.com/electron/electron/releases/tag/v10.0.0-beta.25)|2020-08-22|beta-10-x-y|yes|82|12.16.3|85.0.4183.80|21101|
|[v10.0.0-beta.24](https://github.com/electron/electron/releases/tag/v10.0.0-beta.24)|2020-08-20||yes|82|12.16.3|85.0.4183.78|2041|
|[v10.0.0-beta.23](https://github.com/electron/electron/releases/tag/v10.0.0-beta.23)|2020-08-17||yes|82|12.16.3|85.0.4183.70|2819|
|[v10.0.0-beta.21](https://github.com/electron/electron/releases/tag/v10.0.0-beta.21)|2020-08-11||yes|82|12.16.3|85.0.4183.39|7246|
|[v10.0.0-beta.20](https://github.com/electron/electron/releases/tag/v10.0.0-beta.20)|2020-08-10||yes|82|12.16.3|85.0.4183.39|1903|
|[v10.0.0-beta.19](https://github.com/electron/electron/releases/tag/v10.0.0-beta.19)|2020-08-06||yes|82|12.16.3|85.0.4183.39|2374|
|[v10.0.0-beta.17](https://github.com/electron/electron/releases/tag/v10.0.0-beta.17)|2020-08-03||yes|82|12.16.3|85.0.4183.39|2059|
|[v10.0.0-beta.15](https://github.com/electron/electron/releases/tag/v10.0.0-beta.15)|2020-07-29||yes|82|12.16.3|85.0.4183.39|3093|
|[v10.0.0-beta.14](https://github.com/electron/electron/releases/tag/v10.0.0-beta.14)|2020-07-27||yes|82|12.16.3|85.0.4183.39|2097|
|[v10.0.0-beta.13](https://github.com/electron/electron/releases/tag/v10.0.0-beta.13)|2020-07-23||yes|82|12.16.3|85.0.4183.39|1786|
|[v10.0.0-beta.12](https://github.com/electron/electron/releases/tag/v10.0.0-beta.12)|2020-07-16||yes|82|12.16.3|85.0.4183.26|3618|
|[v10.0.0-beta.11](https://github.com/electron/electron/releases/tag/v10.0.0-beta.11)|2020-07-13||yes|82|12.16.3|85.0.4183.20|2288|
|[v10.0.0-beta.10](https://github.com/electron/electron/releases/tag/v10.0.0-beta.10)|2020-07-09||yes|82|12.16.3|85.0.4183.19|2449|
|[v10.0.0-beta.9](https://github.com/electron/electron/releases/tag/v10.0.0-beta.9)|2020-07-06||yes|82|12.16.3|85.0.4181.1|2277|
|[v10.0.0-beta.8](https://github.com/electron/electron/releases/tag/v10.0.0-beta.8)|2020-07-02||yes|82|12.16.3|85.0.4181.1|2067|
|[v10.0.0-beta.4](https://github.com/electron/electron/releases/tag/v10.0.0-beta.4)|2020-06-18||yes|82|12.16.3|85.0.4161.2|2820|
|[v10.0.0-beta.3](https://github.com/electron/electron/releases/tag/v10.0.0-beta.3)|2020-06-15||yes|82|12.16.3|85.0.4161.2|1817|
|[v10.0.0-beta.2](https://github.com/electron/electron/releases/tag/v10.0.0-beta.2)|2020-06-01||yes|82|12.16.3|84.0.4129.0|3087|
|[v10.0.0-beta.1](https://github.com/electron/electron/releases/tag/v10.0.0-beta.1)|2020-05-22||yes|82|12.16.3|84.0.4129.0|9091|
|[v9.4.4](https://github.com/electron/electron/releases/tag/v9.4.4)|2021-03-03|9-x-y|no|80|12.14.1|83.0.4103.122|882825|
|[v9.4.3](https://github.com/electron/electron/releases/tag/v9.4.3)|2021-02-05||no|80|12.14.1|83.0.4103.122|175868|
|[v9.4.2](https://github.com/electron/electron/releases/tag/v9.4.2)|2021-01-27||no|80|12.14.1|83.0.4103.122|137936|
|[v9.4.1](https://github.com/electron/electron/releases/tag/v9.4.1)|2021-01-13||no|80|12.14.1|83.0.4103.122|212705|
|[v9.4.0](https://github.com/electron/electron/releases/tag/v9.4.0)|2020-12-12||no|80|12.14.1|83.0.4103.122|415389|
|[v9.3.5](https://github.com/electron/electron/releases/tag/v9.3.5)|2020-11-24||no|80|12.14.1|83.0.4103.122|181671|
|[v9.3.4](https://github.com/electron/electron/releases/tag/v9.3.4)|2020-11-10||no|80|12.14.1|83.0.4103.122|106232|
|[v9.3.3](https://github.com/electron/electron/releases/tag/v9.3.3)|2020-10-26||no|80|12.14.1|83.0.4103.122|140177|
|[v9.3.2](https://github.com/electron/electron/releases/tag/v9.3.2)|2020-10-05||no|80|12.14.1|83.0.4103.122|328834|
|[v9.3.1](https://github.com/electron/electron/releases/tag/v9.3.1)|2020-09-15||no|80|12.14.1|83.0.4103.122|313202|
|[v9.3.0](https://github.com/electron/electron/releases/tag/v9.3.0)|2020-09-03||no|80|12.14.1|83.0.4103.122|165456|
|[v9.2.1](https://github.com/electron/electron/releases/tag/v9.2.1)|2020-08-18||no|80|12.14.1|83.0.4103.122|288758|
|[v9.2.0](https://github.com/electron/electron/releases/tag/v9.2.0)|2020-08-07||no|80|12.14.1|83.0.4103.122|377878|
|[v9.1.2](https://github.com/electron/electron/releases/tag/v9.1.2)|2020-07-28||no|80|12.14.1|83.0.4103.122|236228|
|[v9.1.1](https://github.com/electron/electron/releases/tag/v9.1.1)|2020-07-20||no|80|12.14.1|83.0.4103.122|181705|
|[v9.1.0](https://github.com/electron/electron/releases/tag/v9.1.0)|2020-07-06||no|80|12.14.1|83.0.4103.122|493978|
|[v9.0.5](https://github.com/electron/electron/releases/tag/v9.0.5)|2020-06-22||no|80|12.14.1|83.0.4103.119|341444|
|[v9.0.4](https://github.com/electron/electron/releases/tag/v9.0.4)|2020-06-12||no|80|12.14.1|83.0.4103.104|196194|
|[v9.0.3](https://github.com/electron/electron/releases/tag/v9.0.3)|2020-06-08||no|80|12.14.1|83.0.4103.100|95332|
|[v9.0.2](https://github.com/electron/electron/releases/tag/v9.0.2)|2020-06-02||no|80|12.14.1|83.0.4103.94|179459|
|[v9.0.1](https://github.com/electron/electron/releases/tag/v9.0.1)|2020-06-01||no|80|12.14.1|83.0.4103.94|62798|
|[v9.0.0](https://github.com/electron/electron/releases/tag/v9.0.0)|2020-05-19||no|80|12.14.1|83.0.4103.64|916209|
|[v9.0.0-nightly.20200121](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200121)|2020-01-21||yes|76|12.14.1|81.0.4030.0|1006|
|[v9.0.0-nightly.20200119](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200119)|2020-01-19||yes|76|12.14.1|81.0.4030.0|406|
|[v9.0.0-nightly.20200117](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200117)|2020-01-17||yes|76|12.14.1|81.0.3994.0|539|
|[v9.0.0-nightly.20200116](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200116)|2020-01-16||yes|76|12.14.1|81.0.3994.0|481|
|[v9.0.0-nightly.20200115](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200115)|2020-01-15||yes|76|12.14.1|81.0.3994.0|440|
|[v9.0.0-nightly.20200113](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200113)|2020-01-13||yes|76|12.14.1|81.0.3994.0|440|
|[v9.0.0-nightly.20200111](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200111)|2020-01-11||yes|76|12.14.1|81.0.3994.0|369|
|[v9.0.0-nightly.20200110](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200110)|2020-01-10||yes|76|12.14.1|81.0.3994.0|448|
|[v9.0.0-nightly.20200109](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200109)|2020-01-09||yes|76|12.14.0|81.0.3994.0|401|
|[v9.0.0-nightly.20200108](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200108)|2020-01-08||yes|76|12.14.0|81.0.3994.0|414|
|[v9.0.0-nightly.20200106](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200106)|2020-01-06||yes|76|12.14.0|81.0.3994.0|382|
|[v9.0.0-nightly.20200105](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200105)|2020-01-05||yes|76|12.14.0|81.0.3994.0|367|
|[v9.0.0-nightly.20200104](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200104)|2020-01-04||yes|76|12.14.0|81.0.3994.0|486|
|[v9.0.0-nightly.20200103](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200103)|2020-01-03||yes|76|12.14.0|81.0.3994.0|379|
|[v9.0.0-nightly.20200101](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20200101)|2020-01-01||yes|76|12.14.0|81.0.3994.0|481|
|[v9.0.0-nightly.20191231](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191231)|2019-12-31||yes|76|12.14.0|81.0.3994.0|388|
|[v9.0.0-nightly.20191230](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191230)|2019-12-30||yes|76|12.14.0|81.0.3994.0|396|
|[v9.0.0-nightly.20191229](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191229)|2019-12-29||yes|76|12.14.0|81.0.3994.0|396|
|[v9.0.0-nightly.20191228](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191228)|2019-12-28||yes|76|12.14.0|81.0.3994.0|384|
|[v9.0.0-nightly.20191226](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191226)|2019-12-26||yes|76|12.14.0|81.0.3994.0|372|
|[v9.0.0-nightly.20191225](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191225)|2019-12-25||yes|76|12.14.0|81.0.3994.0|511|
|[v9.0.0-nightly.20191224](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191224)|2019-12-24||yes|76|12.14.0|81.0.3994.0|389|
|[v9.0.0-nightly.20191223](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191223)|2019-12-23||yes|76|12.14.0|81.0.3994.0|418|
|[v9.0.0-nightly.20191222](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191222)|2019-12-22||yes|76|12.14.0|81.0.3994.0|393|
|[v9.0.0-nightly.20191221](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191221)|2019-12-21||yes|76|12.14.0|81.0.3994.0|410|
|[v9.0.0-nightly.20191220](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191220)|2019-12-20||yes|76|12.14.0|81.0.3994.0|392|
|[v9.0.0-nightly.20191210](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191210)|2019-12-10||yes|76|12.13.0|80.0.3954.0|374|
|[v9.0.0-nightly.20191204](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191204)|2019-12-04||yes|76|12.13.0|80.0.3954.0|761|
|[v9.0.0-nightly.20191203](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191203)|2019-12-03||yes|76|12.13.0|80.0.3954.0|402|
|[v9.0.0-nightly.20191202](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191202)|2019-12-02||yes|76|12.13.0|80.0.3954.0|455|
|[v9.0.0-nightly.20191201](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191201)|2019-12-01||yes|76|12.13.0|80.0.3954.0|402|
|[v9.0.0-nightly.20191130](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191130)|2019-11-30||yes|76|12.13.0|80.0.3954.0|405|
|[v9.0.0-nightly.20191129](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191129)|2019-11-29||yes|76|12.13.0|80.0.3954.0|417|
|[v9.0.0-nightly.20191124](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191124)|2019-11-24||yes|76|12.13.0|80.0.3954.0|484|
|[v9.0.0-nightly.20191123](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191123)|2019-11-23||yes|76|12.13.0|80.0.3954.0|399|
|[v9.0.0-nightly.20191122](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191122)|2019-11-22||yes|76|12.13.0|80.0.3954.0|409|
|[v9.0.0-nightly.20191121](https://github.com/electron/electron/releases/tag/v9.0.0-nightly.20191121)|2019-11-21||yes|76|12.13.0|80.0.3954.0|415|
|[v9.0.0-beta.24](https://github.com/electron/electron/releases/tag/v9.0.0-beta.24)|2020-05-11|beta-9-x-y|yes|80|12.14.1|83.0.4103.45|13882|
|[v9.0.0-beta.23](https://github.com/electron/electron/releases/tag/v9.0.0-beta.23)|2020-05-07||yes|80|12.14.1|83.0.4103.44|1624|
|[v9.0.0-beta.22](https://github.com/electron/electron/releases/tag/v9.0.0-beta.22)|2020-04-30||yes|80|12.14.1|83.0.4103.34|6000|
|[v9.0.0-beta.21](https://github.com/electron/electron/releases/tag/v9.0.0-beta.21)|2020-04-28||yes|80|12.14.1|83.0.4103.26|1817|
|[v9.0.0-beta.20](https://github.com/electron/electron/releases/tag/v9.0.0-beta.20)|2020-04-27||yes|80|12.14.1|83.0.4103.26|1500|
|[v9.0.0-beta.19](https://github.com/electron/electron/releases/tag/v9.0.0-beta.19)|2020-04-24||yes|80|12.14.1|83.0.4103.24|2430|
|[v9.0.0-beta.18](https://github.com/electron/electron/releases/tag/v9.0.0-beta.18)|2020-04-20||yes|80|12.14.1|83.0.4103.16|2351|
|[v9.0.0-beta.17](https://github.com/electron/electron/releases/tag/v9.0.0-beta.17)|2020-04-17||yes|80|12.14.1|83.0.4103.14|1925|
|[v9.0.0-beta.16](https://github.com/electron/electron/releases/tag/v9.0.0-beta.16)|2020-04-13||yes|80|12.14.1|83.0.4102.3|2127|
|[v9.0.0-beta.15](https://github.com/electron/electron/releases/tag/v9.0.0-beta.15)|2020-04-09||yes|80|12.14.1|83.0.4102.3|2745|
|[v9.0.0-beta.14](https://github.com/electron/electron/releases/tag/v9.0.0-beta.14)|2020-04-06||yes|80|12.14.1|82.0.4085.27|2472|
|[v9.0.0-beta.13](https://github.com/electron/electron/releases/tag/v9.0.0-beta.13)|2020-04-02||yes|80|12.14.1|82.0.4085.14|5098|
|[v9.0.0-beta.12](https://github.com/electron/electron/releases/tag/v9.0.0-beta.12)|2020-03-30||yes|80|12.14.1|82.0.4085.14|2125|
|[v9.0.0-beta.10](https://github.com/electron/electron/releases/tag/v9.0.0-beta.10)|2020-03-23||yes|80|12.14.1|82.0.4085.10|2558|
|[v9.0.0-beta.9](https://github.com/electron/electron/releases/tag/v9.0.0-beta.9)|2020-03-16||yes|80|12.14.1|82.0.4058.2|2956|
|[v9.0.0-beta.7](https://github.com/electron/electron/releases/tag/v9.0.0-beta.7)|2020-03-09||yes|80|12.14.1|82.0.4058.2|2545|
|[v9.0.0-beta.6](https://github.com/electron/electron/releases/tag/v9.0.0-beta.6)|2020-03-06||yes|80|12.14.1|82.0.4058.2|3039|
|[v9.0.0-beta.5](https://github.com/electron/electron/releases/tag/v9.0.0-beta.5)|2020-03-02||yes|80|12.14.1|82.0.4048.0|4299|
|[v9.0.0-beta.4](https://github.com/electron/electron/releases/tag/v9.0.0-beta.4)|2020-02-28||yes|80|12.14.1|82.0.4048.0|2143|
|[v9.0.0-beta.3](https://github.com/electron/electron/releases/tag/v9.0.0-beta.3)|2020-02-26||yes|80|12.14.1|82.0.4048.0|1962|
|[v9.0.0-beta.2](https://github.com/electron/electron/releases/tag/v9.0.0-beta.2)|2020-02-16||yes|80|12.14.1|82.0.4048.0|2475|
|[v9.0.0-beta.1](https://github.com/electron/electron/releases/tag/v9.0.0-beta.1)|2020-02-10||yes|76|12.14.1|82.0.4048.0|2230|
|[v8.5.5](https://github.com/electron/electron/releases/tag/v8.5.5)|2020-11-18|8-x-y|no|76|12.13.0|80.0.3987.163|620505|
|[v8.5.4](https://github.com/electron/electron/releases/tag/v8.5.4)|2020-11-17||no|76|12.13.0|80.0.3987.163|17465|
|[v8.5.3](https://github.com/electron/electron/releases/tag/v8.5.3)|2020-10-30||no|76|12.13.0|80.0.3987.163|88271|
|[v8.5.2](https://github.com/electron/electron/releases/tag/v8.5.2)|2020-09-22||no|76|12.13.0|80.0.3987.165|336700|
|[v8.5.1](https://github.com/electron/electron/releases/tag/v8.5.1)|2020-09-03||no|76|12.13.0|80.0.3987.165|78691|
|[v8.5.0](https://github.com/electron/electron/releases/tag/v8.5.0)|2020-08-07||no|76|12.13.0|80.0.3987.165|121303|
|[v8.4.1](https://github.com/electron/electron/releases/tag/v8.4.1)|2020-07-23||no|76|12.13.0|80.0.3987.165|144155|
|[v8.4.0](https://github.com/electron/electron/releases/tag/v8.4.0)|2020-07-07||no|76|12.13.0|80.0.3987.165|79052|
|[v8.3.4](https://github.com/electron/electron/releases/tag/v8.3.4)|2020-06-25||no|76|12.13.0|80.0.3987.165|87870|
|[v8.3.3](https://github.com/electron/electron/releases/tag/v8.3.3)|2020-06-18||no|76|12.13.0|80.0.3987.165|130870|
|[v8.3.2](https://github.com/electron/electron/releases/tag/v8.3.2)|2020-06-15||no|76|12.13.0|80.0.3987.165|28452|
|[v8.3.1](https://github.com/electron/electron/releases/tag/v8.3.1)|2020-06-01||no|76|12.13.0|80.0.3987.165|86000|
|[v8.3.0](https://github.com/electron/electron/releases/tag/v8.3.0)|2020-05-15||no|76|12.13.0|80.0.3987.165|217616|
|[v8.2.5](https://github.com/electron/electron/releases/tag/v8.2.5)|2020-04-30||no|76|12.13.0|80.0.3987.165|474374|
|[v8.2.4](https://github.com/electron/electron/releases/tag/v8.2.4)|2020-04-28||no|76|12.13.0|80.0.3987.165|154594|
|[v8.2.3](https://github.com/electron/electron/releases/tag/v8.2.3)|2020-04-16||no|76|12.13.0|80.0.3987.163|305662|
|[v8.2.2](https://github.com/electron/electron/releases/tag/v8.2.2)|2020-04-13||no|76|12.13.0|80.0.3987.163|96748|
|[v8.2.1](https://github.com/electron/electron/releases/tag/v8.2.1)|2020-04-06||no|76|12.13.0|80.0.3987.163|139291|
|[v8.2.0](https://github.com/electron/electron/releases/tag/v8.2.0)|2020-03-24||no|76|12.13.0|80.0.3987.158|463732|
|[v8.1.1](https://github.com/electron/electron/releases/tag/v8.1.1)|2020-03-10||no|76|12.13.0|80.0.3987.141|259246|
|[v8.1.0](https://github.com/electron/electron/releases/tag/v8.1.0)|2020-03-06||no|76|12.13.0|80.0.3987.137|52276|
|[v8.0.3](https://github.com/electron/electron/releases/tag/v8.0.3)|2020-03-03||no|76|12.13.0|80.0.3987.134|127278|
|[v8.0.2](https://github.com/electron/electron/releases/tag/v8.0.2)|2020-02-26||no|76|12.13.0|80.0.3987.86|254495|
|[v8.0.1](https://github.com/electron/electron/releases/tag/v8.0.1)|2020-02-14||no|76|12.13.0|80.0.3987.86|210585|
|[v8.0.0](https://github.com/electron/electron/releases/tag/v8.0.0)|2020-02-03||no|76|12.13.0|80.0.3987.86|748906|
|[v8.0.0-nightly.20191105](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191105)|2019-11-05||yes|76|12.13.0|80.0.3952.0|633|
|[v8.0.0-nightly.20191101](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191101)|2019-11-01||yes|76|12.13.0|80.0.3952.0|451|
|[v8.0.0-nightly.20191023](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191023)|2019-10-23||yes|76|12.13.0|79.0.3931.0|599|
|[v8.0.0-nightly.20191021](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191021)|2019-10-21||yes|76|12.12.0|79.0.3931.0|439|
|[v8.0.0-nightly.20191020](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191020)|2019-10-20||yes|76|12.12.0|79.0.3931.0|446|
|[v8.0.0-nightly.20191019](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191019)|2019-10-19||yes|76|12.12.0|79.0.3931.0|423|
|[v8.0.0-nightly.20191017](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191017)|2019-10-17||yes|76|12.10.0|79.0.3919.0|374|
|[v8.0.0-nightly.20191012](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191012)|2019-10-12||yes|76|12.9.1|79.0.3919.0|441|
|[v8.0.0-nightly.20191011](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191011)|2019-10-11||yes|76|12.9.1|79.0.3919.0|372|
|[v8.0.0-nightly.20191009](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191009)|2019-10-09||yes|76|12.9.1|79.0.3919.0|392|
|[v8.0.0-nightly.20191006](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191006)|2019-10-06||yes|76|12.9.1|79.0.3919.0|386|
|[v8.0.0-nightly.20191005](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191005)|2019-10-05||yes|76|12.9.1|79.0.3919.0|368|
|[v8.0.0-nightly.20191004](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191004)|2019-10-04||yes|76|12.9.1|79.0.3919.0|354|
|[v8.0.0-nightly.20191001](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20191001)|2019-10-01||yes|76|12.9.1|79.0.3919.0|409|
|[v8.0.0-nightly.20190930](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190930)|2019-09-30||yes|76|12.9.1|79.0.3919.0|372|
|[v8.0.0-nightly.20190929](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190929)|2019-09-29||yes|76|12.9.1|79.0.3919.0|377|
|[v8.0.0-nightly.20190926](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190926)|2019-09-26||yes|76|12.9.1|79.0.3919.0|408|
|[v8.0.0-nightly.20190924](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190924)|2019-09-24||yes|76|12.9.1|79.0.3919.0|365|
|[v8.0.0-nightly.20190923](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190923)|2019-09-23||yes|76|12.9.1|79.0.3919.0|369|
|[v8.0.0-nightly.20190920](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190920)|2019-09-20||yes|76|12.9.1|79.0.3915.0|425|
|[v8.0.0-nightly.20190919](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190919)|2019-09-19||yes|76|12.9.1|79.0.3915.0|389|
|[v8.0.0-nightly.20190917](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190917)|2019-09-17||yes|76|12.9.1|78.0.3892.0|382|
|[v8.0.0-nightly.20190915](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190915)|2019-09-15||yes|76|12.9.1|78.0.3892.0|351|
|[v8.0.0-nightly.20190914](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190914)|2019-09-14||yes|76|12.9.1|78.0.3892.0|376|
|[v8.0.0-nightly.20190913](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190913)|2019-09-13||yes|76|12.9.1|78.0.3892.0|360|
|[v8.0.0-nightly.20190911](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190911)|2019-09-11||yes|76|12.9.1|78.0.3892.0|361|
|[v8.0.0-nightly.20190910](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190910)|2019-09-10||yes|76|12.9.1|78.0.3892.0|367|
|[v8.0.0-nightly.20190909](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190909)|2019-09-09||yes|76|12.9.1|78.0.3892.0|369|
|[v8.0.0-nightly.20190907](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190907)|2019-09-08||yes|76|12.9.1|78.0.3892.0|349|
|[v8.0.0-nightly.20190902](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190902)|2019-09-02||yes|76|12.9.1|78.0.3892.0|310|
|[v8.0.0-nightly.20190901](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190901)|2019-09-01||yes|76|12.9.1|78.0.3892.0|437|
|[v8.0.0-nightly.20190830](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190830)|2019-08-30||yes|76|12.9.1|78.0.3892.0|337|
|[v8.0.0-nightly.20190828](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190828)|2019-08-28||yes|76|12.9.1|78.0.3892.0|236|
|[v8.0.0-nightly.20190827](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190827)|2019-08-28||yes|76|12.9.1|78.0.3892.0|210|
|[v8.0.0-nightly.20190825](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190825)|2019-08-25||yes|76|12.9.0|78.0.3892.0|360|
|[v8.0.0-nightly.20190824](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190824)|2019-08-24||yes|76|12.9.0|78.0.3892.0|312|
|[v8.0.0-nightly.20190820](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190820)|2019-08-20||yes|76|12.8.1|78.0.3881.0|307|
|[v8.0.0-nightly.20190819](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190819)|2019-08-20||yes|76|12.8.0|78.0.3881.0|366|
|[v8.0.0-nightly.20190818](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190818)|2019-08-18||yes|76|12.8.0|78.0.3881.0|332|
|[v8.0.0-nightly.20190817](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190817)|2019-08-17||yes|76|12.8.0|78.0.3881.0|319|
|[v8.0.0-nightly.20190816](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190816)|2019-08-16||yes|76|12.8.0|78.0.3881.0|322|
|[v8.0.0-nightly.20190815](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190815)|2019-08-15||yes|76|12.8.0|78.0.3871.0|321|
|[v8.0.0-nightly.20190814](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190814)|2019-08-14||yes|76|12.8.0|78.0.3871.0|311|
|[v8.0.0-nightly.20190813](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190813)|2019-08-13||yes|76|12.8.0|78.0.3871.0|336|
|[v8.0.0-nightly.20190812](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190812)|2019-08-12||yes|76|12.6.0|78.0.3871.0|331|
|[v8.0.0-nightly.20190811](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190811)|2019-08-12||yes|76|12.6.0|78.0.3871.0|329|
|[v8.0.0-nightly.20190810](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190810)|2019-08-11||yes|76|12.6.0|78.0.3871.0|311|
|[v8.0.0-nightly.20190809](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190809)|2019-08-09||yes|76|12.6.0|78.0.3871.0|318|
|[v8.0.0-nightly.20190808](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190808)|2019-08-08||yes|76|12.6.0|78.0.3871.0|309|
|[v8.0.0-nightly.20190807](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190807)|2019-08-07||yes|76|12.6.0|78.0.3871.0|331|
|[v8.0.0-nightly.20190806](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190806)|2019-08-06||yes|76|12.6.0|78.0.3871.0|335|
|[v8.0.0-nightly.20190803](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190803)|2019-08-04||yes|76|12.6.0|78.0.3871.0|383|
|[v8.0.0-nightly.20190802](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190802)|2019-08-02||yes|76|12.6.0|78.0.3866.0|327|
|[v8.0.0-nightly.20190801](https://github.com/electron/electron/releases/tag/v8.0.0-nightly.20190801)|2019-08-01||yes|76|12.6.0|78.0.3866.0|334|
|[v8.0.0-beta.9](https://github.com/electron/electron/releases/tag/v8.0.0-beta.9)|2020-01-30|beta-8-x-y|yes|76|12.13.0|80.0.3987.75|4844|
|[v8.0.0-beta.8](https://github.com/electron/electron/releases/tag/v8.0.0-beta.8)|2020-01-29||yes|76|12.13.0|80.0.3987.75|1592|
|[v8.0.0-beta.7](https://github.com/electron/electron/releases/tag/v8.0.0-beta.7)|2020-01-16||yes|76|12.13.0|80.0.3987.59|62033|
|[v8.0.0-beta.6](https://github.com/electron/electron/releases/tag/v8.0.0-beta.6)|2020-01-14||yes|76|12.13.0|80.0.3987.51|2371|
|[v8.0.0-beta.5](https://github.com/electron/electron/releases/tag/v8.0.0-beta.5)|2019-12-18||yes|76|12.13.0|80.0.3987.14|40282|
|[v8.0.0-beta.4](https://github.com/electron/electron/releases/tag/v8.0.0-beta.4)|2019-12-04||yes|76|12.13.0|80.0.3955.0|30117|
|[v8.0.0-beta.3](https://github.com/electron/electron/releases/tag/v8.0.0-beta.3)|2019-11-20||yes|76|12.13.0|80.0.3955.0|7521|
|[v8.0.0-beta.2](https://github.com/electron/electron/releases/tag/v8.0.0-beta.2)|2019-11-01||yes|76|12.13.0|79.0.3931.0|6186|
|[v8.0.0-beta.1](https://github.com/electron/electron/releases/tag/v8.0.0-beta.1)|2019-10-24||yes|76|12.13.0|79.0.3931.0|2731|
|[v7.3.3](https://github.com/electron/electron/releases/tag/v7.3.3)|2020-08-25|7-3-x|no|75|12.8.1|78.0.3904.130|806321|
|[v7.3.2](https://github.com/electron/electron/releases/tag/v7.3.2)|2020-06-24||no|75|12.8.1|78.0.3904.130|308238|
|[v7.3.1](https://github.com/electron/electron/releases/tag/v7.3.1)|2020-06-01||no|75|12.8.1|78.0.3904.130|85042|
|[v7.3.0](https://github.com/electron/electron/releases/tag/v7.3.0)|2020-05-15||no|75|12.8.1|78.0.3904.130|65668|
|[v7.2.4](https://github.com/electron/electron/releases/tag/v7.2.4)|2020-04-29|7-2-x|no|75|12.8.1|78.0.3904.130|191966|
|[v7.2.3](https://github.com/electron/electron/releases/tag/v7.2.3)|2020-04-17||no|75|12.8.1|78.0.3904.130|48255|
|[v7.2.2](https://github.com/electron/electron/releases/tag/v7.2.2)|2020-04-14||no|75|12.8.1|78.0.3904.130|25089|
|[v7.2.1](https://github.com/electron/electron/releases/tag/v7.2.1)|2020-03-24||no|75|12.8.1|78.0.3904.130|219741|
|[v7.2.0](https://github.com/electron/electron/releases/tag/v7.2.0)|2020-03-23||no|75|12.8.1|78.0.3904.130|4265|
|[v7.1.14](https://github.com/electron/electron/releases/tag/v7.1.14)|2020-02-28|7-1-x|no|75|12.8.1|78.0.3904.130|287561|
|[v7.1.13](https://github.com/electron/electron/releases/tag/v7.1.13)|2020-02-20||no|75|12.8.1|78.0.3904.130|118289|
|[v7.1.12](https://github.com/electron/electron/releases/tag/v7.1.12)|2020-02-10||no|75|12.8.1|78.0.3904.130|99065|
|[v7.1.11](https://github.com/electron/electron/releases/tag/v7.1.11)|2020-01-30||no|75|12.8.1|78.0.3904.130|380602|
|[v7.1.10](https://github.com/electron/electron/releases/tag/v7.1.10)|2020-01-22||no|75|12.8.1|78.0.3904.130|221545|
|[v7.1.9](https://github.com/electron/electron/releases/tag/v7.1.9)|2020-01-13||no|75|12.8.1|78.0.3904.130|228227|
|[v7.1.8](https://github.com/electron/electron/releases/tag/v7.1.8)|2020-01-08||no|75|12.8.1|78.0.3904.130|116968|
|[v7.1.7](https://github.com/electron/electron/releases/tag/v7.1.7)|2019-12-19||no|75|12.8.1|78.0.3904.130|456348|
|[v7.1.6](https://github.com/electron/electron/releases/tag/v7.1.6)|2019-12-18||no|75|12.8.1|78.0.3904.130|73021|
|[v7.1.5](https://github.com/electron/electron/releases/tag/v7.1.5)|2019-12-13||no|75|12.8.1|78.0.3904.130|103310|
|[v7.1.4](https://github.com/electron/electron/releases/tag/v7.1.4)|2019-12-10||no|75|12.8.1|78.0.3904.130|148944|
|[v7.1.3](https://github.com/electron/electron/releases/tag/v7.1.3)|2019-12-03||no|75|12.8.1|78.0.3904.126|177010|
|[v7.1.2](https://github.com/electron/electron/releases/tag/v7.1.2)|2019-11-20||no|75|12.8.1|78.0.3904.113|386373|
|[v7.1.1](https://github.com/electron/electron/releases/tag/v7.1.1)|2019-11-07||no|75|12.8.1|78.0.3904.99|262729|
|[v7.1.0](https://github.com/electron/electron/releases/tag/v7.1.0)|2019-11-05||no|75|12.8.1|78.0.3904.94|102126|
|[v7.0.1](https://github.com/electron/electron/releases/tag/v7.0.1)|2019-11-01|7-0-x|no|75|12.8.1|78.0.3904.92|121182|
|[v7.0.0](https://github.com/electron/electron/releases/tag/v7.0.0)|2019-10-21||no|75|12.8.1|78.0.3905.1|927668|
|[v7.0.0-nightly.20190731](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190731)|2019-07-31||yes|75|12.6.0|78.0.3866.0|365|
|[v7.0.0-nightly.20190730](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190730)|2019-07-30||yes|75|12.6.0|78.0.3866.0|358|
|[v7.0.0-nightly.20190729](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190729)|2019-07-29||yes|75|12.6.0|78.0.3866.0|312|
|[v7.0.0-nightly.20190728](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190728)|2019-07-28||yes|75|12.6.0|78.0.3866.0|328|
|[v7.0.0-nightly.20190727](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190727)|2019-07-27||yes|75|12.6.0|78.0.3866.0|332|
|[v7.0.0-nightly.20190726](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190726)|2019-07-26||yes|75|12.6.0|77.0.3864.0|328|
|[v7.0.0-nightly.20190721](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190721)|2019-07-21||yes|73|12.6.0|77.0.3848.0|597|
|[v7.0.0-nightly.20190720](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190720)|2019-07-20||yes|73|12.6.0|77.0.3848.0|344|
|[v7.0.0-nightly.20190719](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190719)|2019-07-19||yes|73|12.6.0|77.0.3848.0|322|
|[v7.0.0-nightly.20190705](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190705)|2019-07-05||yes|73|12.0.0|77.0.3843.0|326|
|[v7.0.0-nightly.20190704](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190704)|2019-07-04||yes|73|12.0.0|77.0.3843.0|547|
|[v7.0.0-nightly.20190702](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190702)|2019-07-02||yes|73|12.0.0|77.0.3815.0|350|
|[v7.0.0-nightly.20190701](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190701)|2019-07-01||yes|73|12.0.0|77.0.3815.0|317|
|[v7.0.0-nightly.20190630](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190630)|2019-07-01||yes|73|12.0.0|77.0.3815.0|319|
|[v7.0.0-nightly.20190629](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190629)|2019-06-29||yes|73|12.0.0|77.0.3815.0|332|
|[v7.0.0-nightly.20190627](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190627)|2019-06-27||yes|73|12.0.0|77.0.3815.0|345|
|[v7.0.0-nightly.20190624](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190624)|2019-06-24||yes|73|12.0.0|77.0.3815.0|360|
|[v7.0.0-nightly.20190623](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190623)|2019-06-23||yes|73|12.0.0|77.0.3815.0|314|
|[v7.0.0-nightly.20190622](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190622)|2019-06-22||yes|73|12.0.0|77.0.3815.0|321|
|[v7.0.0-nightly.20190619](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190619)|2019-06-19||yes|73|12.0.0|77.0.3815.0|358|
|[v7.0.0-nightly.20190618](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190618)|2019-06-18||yes|73|12.0.0|77.0.3815.0|319|
|[v7.0.0-nightly.20190616](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190616)|2019-06-16||yes|73|12.0.0|77.0.3815.0|341|
|[v7.0.0-nightly.20190615](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190615)|2019-06-15||yes|73|12.0.0|77.0.3815.0|325|
|[v7.0.0-nightly.20190613](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190613)|2019-06-13||yes|73|12.0.0|77.0.3815.0|348|
|[v7.0.0-nightly.20190612](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190612)|2019-06-12||yes|73|12.0.0|77.0.3815.0|333|
|[v7.0.0-nightly.20190611](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190611)|2019-06-11||yes|73|12.0.0|77.0.3815.0|313|
|[v7.0.0-nightly.20190609](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190609)|2019-06-09||yes|73|12.0.0|77.0.3815.0|308|
|[v7.0.0-nightly.20190608](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190608)|2019-06-08||yes|73|12.0.0|77.0.3815.0|329|
|[v7.0.0-nightly.20190607](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190607)|2019-06-07||yes|73|12.0.0|77.0.3815.0|320|
|[v7.0.0-nightly.20190606](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190606)|2019-06-06||yes|73|12.0.0|77.0.3815.0|325|
|[v7.0.0-nightly.20190605](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190605)|2019-06-05||yes|73|12.0.0|77.0.3815.0|324|
|[v7.0.0-nightly.20190604](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190604)|2019-06-04||yes|73|12.0.0|77.0.3814.0|313|
|[v7.0.0-nightly.20190603](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190603)|2019-06-03||yes|73|12.0.0|76.0.3806.0|315|
|[v7.0.0-nightly.20190602](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190602)|2019-06-02||yes|73|12.0.0|76.0.3806.0|314|
|[v7.0.0-nightly.20190531](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190531)|2019-05-31||yes|73|12.0.0|76.0.3806.0|318|
|[v7.0.0-nightly.20190530](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190530)|2019-05-30||yes|73|12.0.0|76.0.3806.0|321|
|[v7.0.0-nightly.20190529](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190529)|2019-05-29||yes|73|12.0.0|76.0.3806.0|322|
|[v7.0.0-nightly.20190521](https://github.com/electron/electron/releases/tag/v7.0.0-nightly.20190521)|2019-05-21||yes|73|12.0.0|76.0.3784.0|704|
|[v7.0.0-beta.7](https://github.com/electron/electron/releases/tag/v7.0.0-beta.7)|2019-10-16|beta-7-0-x|yes|75|12.8.1|78.0.3905.1|3017|
|[v7.0.0-beta.6](https://github.com/electron/electron/releases/tag/v7.0.0-beta.6)|2019-10-09||yes|75|12.8.1|78.0.3905.1|3110|
|[v7.0.0-beta.5](https://github.com/electron/electron/releases/tag/v7.0.0-beta.5)|2019-09-24||yes|75|12.8.1|78.0.3905.1|4522|
|[v7.0.0-beta.4](https://github.com/electron/electron/releases/tag/v7.0.0-beta.4)|2019-09-03||yes|75|12.8.1|78.0.3896.6|3812|
|[v7.0.0-beta.3](https://github.com/electron/electron/releases/tag/v7.0.0-beta.3)|2019-08-15||yes|75|12.8.0|78.0.3866.0|4146|
|[v7.0.0-beta.2](https://github.com/electron/electron/releases/tag/v7.0.0-beta.2)|2019-08-07||yes|75|12.6.0|78.0.3866.0|2981|
|[v7.0.0-beta.1](https://github.com/electron/electron/releases/tag/v7.0.0-beta.1)|2019-08-01||yes|75|12.6.0|78.0.3866.0|2373|
|[v6.1.12](https://github.com/electron/electron/releases/tag/v6.1.12)|2020-05-18|6-1-x|no|73|12.4.0|76.0.3809.146|554562|
|[v6.1.11](https://github.com/electron/electron/releases/tag/v6.1.11)|2020-05-05||no|73|12.4.0|76.0.3809.146|47033|
|[v6.1.10](https://github.com/electron/electron/releases/tag/v6.1.10)|2020-04-14||no|73|12.4.0|76.0.3809.146|78466|
|[v6.1.9](https://github.com/electron/electron/releases/tag/v6.1.9)|2020-02-28||no|73|12.4.0|76.0.3809.146|91170|
|[v6.1.8](https://github.com/electron/electron/releases/tag/v6.1.8)|2020-02-21||no|73|12.4.0|76.0.3809.146|13969|
|[v6.1.7](https://github.com/electron/electron/releases/tag/v6.1.7)|2019-12-17||no|73|12.4.0|76.0.3809.146|352603|
|[v6.1.6](https://github.com/electron/electron/releases/tag/v6.1.6)|2019-12-11||no|73|12.4.0|76.0.3809.146|136350|
|[v6.1.5](https://github.com/electron/electron/releases/tag/v6.1.5)|2019-11-21||no|73|12.4.0|76.0.3809.146|153227|
|[v6.1.4](https://github.com/electron/electron/releases/tag/v6.1.4)|2019-11-05||no|73|12.4.0|76.0.3809.146|314232|
|[v6.1.3](https://github.com/electron/electron/releases/tag/v6.1.3)|2019-11-01||no|73|12.4.0|76.0.3809.146|18100|
|[v6.1.2](https://github.com/electron/electron/releases/tag/v6.1.2)|2019-10-24||no|73|12.4.0|76.0.3809.146|78413|
|[v6.1.1](https://github.com/electron/electron/releases/tag/v6.1.1)|2019-10-23||no|73|12.4.0|76.0.3809.146|23617|
|[v6.1.0](https://github.com/electron/electron/releases/tag/v6.1.0)|2019-10-22||no|73|12.4.0|76.0.3809.146|16318|
|[v6.0.12](https://github.com/electron/electron/releases/tag/v6.0.12)|2019-10-08|6-0-x|no|73|12.4.0|76.0.3809.146|292487|
|[v6.0.11](https://github.com/electron/electron/releases/tag/v6.0.11)|2019-10-02||no|73|12.4.0|76.0.3809.146|148430|
|[v6.0.10](https://github.com/electron/electron/releases/tag/v6.0.10)|2019-09-19||no|73|12.4.0|76.0.3809.146|381774|
|[v6.0.9](https://github.com/electron/electron/releases/tag/v6.0.9)|2019-09-12||no|73|12.4.0|76.0.3809.146|121074|
|[v6.0.8](https://github.com/electron/electron/releases/tag/v6.0.8)|2019-09-09||no|73|12.4.0|76.0.3809.146|83024|
|[v6.0.7](https://github.com/electron/electron/releases/tag/v6.0.7)|2019-08-31||no|73|12.4.0|76.0.3809.139|232497|
|[v6.0.6](https://github.com/electron/electron/releases/tag/v6.0.6)|2019-08-30||no|73|12.4.0|76.0.3809.138|16047|
|[v6.0.5](https://github.com/electron/electron/releases/tag/v6.0.5)|2019-08-27||no|73|12.4.0|76.0.3809.136|99281|
|[v6.0.4](https://github.com/electron/electron/releases/tag/v6.0.4)|2019-08-24||no|73|12.4.0|76.0.3809.131|42854|
|[v6.0.3](https://github.com/electron/electron/releases/tag/v6.0.3)|2019-08-20||no|73|12.4.0|76.0.3809.126|66545|
|[v6.0.2](https://github.com/electron/electron/releases/tag/v6.0.2)|2019-08-12||no|73|12.4.0|76.0.3809.110|88379|
|[v6.0.1](https://github.com/electron/electron/releases/tag/v6.0.1)|2019-08-07||no|73|12.4.0|76.0.3809.102|89607|
|[v6.0.0](https://github.com/electron/electron/releases/tag/v6.0.0)|2019-07-29||no|73|12.4.0|76.0.3809.88|543513|
|[v6.0.0-nightly.20190311](https://github.com/electron/electron/releases/tag/v6.0.0-nightly.20190311)|2019-03-11||yes|68|12.0.0|74.0.3724.8|3372|
|[v6.0.0-nightly.20190213](https://github.com/electron/electron/releases/tag/v6.0.0-nightly.20190213)|2019-02-14||yes|68|12.0.0|72.0.3626.110|1454|
|[v6.0.0-nightly.20190212](https://github.com/electron/electron/releases/tag/v6.0.0-nightly.20190212)|2019-02-12||yes|68|12.0.0|72.0.3626.107|348|
|[v6.0.0-beta.15](https://github.com/electron/electron/releases/tag/v6.0.0-beta.15)|2019-07-20|beta-6-0-x|yes|73|12.4.0|76.0.3809.74|5100|
|[v6.0.0-beta.14](https://github.com/electron/electron/releases/tag/v6.0.0-beta.14)|2019-07-17||yes|73|12.4.0|76.0.3809.68|2521|
|[v6.0.0-beta.13](https://github.com/electron/electron/releases/tag/v6.0.0-beta.13)|2019-07-10||yes|73|12.0.0|76.0.3809.60|3334|
|[v6.0.0-beta.12](https://github.com/electron/electron/releases/tag/v6.0.0-beta.12)|2019-07-04||yes|73|12.0.0|76.0.3809.54|3164|
|[v6.0.0-beta.11](https://github.com/electron/electron/releases/tag/v6.0.0-beta.11)|2019-06-26||yes|73|12.0.0|76.0.3809.42|2544|
|[v6.0.0-beta.10](https://github.com/electron/electron/releases/tag/v6.0.0-beta.10)|2019-06-22||yes|73|12.0.0|76.0.3809.37|2512|
|[v6.0.0-beta.9](https://github.com/electron/electron/releases/tag/v6.0.0-beta.9)|2019-06-18||yes|73|12.0.0|76.0.3809.26|2166|
|[v6.0.0-beta.8](https://github.com/electron/electron/releases/tag/v6.0.0-beta.8)|2019-06-14||yes|73|12.0.0|76.0.3809.26|1915|
|[v6.0.0-beta.7](https://github.com/electron/electron/releases/tag/v6.0.0-beta.7)|2019-06-11||yes|73|12.0.0|76.0.3809.22|1917|
|[v6.0.0-beta.6](https://github.com/electron/electron/releases/tag/v6.0.0-beta.6)|2019-06-05||yes|73|12.0.0|76.0.3809.3|2215|
|[v6.0.0-beta.5](https://github.com/electron/electron/releases/tag/v6.0.0-beta.5)|2019-05-29||yes|73|12.0.0|76.0.3805.4|1839|
|[v6.0.0-beta.4](https://github.com/electron/electron/releases/tag/v6.0.0-beta.4)|2019-05-21||yes|73|12.0.0|76.0.3783.1|2264|
|[v6.0.0-beta.3](https://github.com/electron/electron/releases/tag/v6.0.0-beta.3)|2019-05-14||yes|73|12.0.0|76.0.3783.1|15019|
|[v6.0.0-beta.2](https://github.com/electron/electron/releases/tag/v6.0.0-beta.2)|2019-05-08||yes|73|12.0.0|76.0.3783.1|2540|
|[v6.0.0-beta.1](https://github.com/electron/electron/releases/tag/v6.0.0-beta.1)|2019-05-01||yes|73|12.0.0|76.0.3774.1|2391|
|[v5.0.13](https://github.com/electron/electron/releases/tag/v5.0.13)|2019-12-17|5-0-x|no|70|12.0.0|73.0.3683.121|993491|
|[v5.0.12](https://github.com/electron/electron/releases/tag/v5.0.12)|2019-11-02||no|70|12.0.0|73.0.3683.121|182106|
|[v5.0.11](https://github.com/electron/electron/releases/tag/v5.0.11)|2019-09-24||no|70|12.0.0|73.0.3683.121|132770|
|[v5.0.10](https://github.com/electron/electron/releases/tag/v5.0.10)|2019-08-20||no|70|12.0.0|73.0.3683.121|221320|
|[v5.0.9](https://github.com/electron/electron/releases/tag/v5.0.9)|2019-08-06||no|70|12.0.0|73.0.3683.121|233067|
|[v5.0.8](https://github.com/electron/electron/releases/tag/v5.0.8)|2019-07-23||no|70|12.0.0|73.0.3683.121|200698|
|[v5.0.7](https://github.com/electron/electron/releases/tag/v5.0.7)|2019-07-16||no|70|12.0.0|73.0.3683.121|157917|
|[v5.0.6](https://github.com/electron/electron/releases/tag/v5.0.6)|2019-06-26||no|70|12.0.0|73.0.3683.121|338665|
|[v5.0.5](https://github.com/electron/electron/releases/tag/v5.0.5)|2019-06-21||no|70|12.0.0|73.0.3683.121|131825|
|[v5.0.4](https://github.com/electron/electron/releases/tag/v5.0.4)|2019-06-15||no|70|12.0.0|73.0.3683.121|149000|
|[v5.0.3](https://github.com/electron/electron/releases/tag/v5.0.3)|2019-06-07||no|70|12.0.0|73.0.3683.121|97361|
|[v5.0.2](https://github.com/electron/electron/releases/tag/v5.0.2)|2019-05-23||no|70|12.0.0|73.0.3683.121|220067|
|[v5.0.1](https://github.com/electron/electron/releases/tag/v5.0.1)|2019-05-04||no|70|12.0.0|73.0.3683.121|907258|
|[v5.0.0](https://github.com/electron/electron/releases/tag/v5.0.0)|2019-04-24||no|70|12.0.0|73.0.3683.119|214715|
|[v5.0.0-nightly.20190122](https://github.com/electron/electron/releases/tag/v5.0.0-nightly.20190122)|2019-01-22||yes|68|12.0.0|71.0.3578.98|225|
|[v5.0.0-nightly.20190121](https://github.com/electron/electron/releases/tag/v5.0.0-nightly.20190121)|2019-01-22||yes|68|12.0.0|71.0.3578.98|406|
|[v5.0.0-nightly.20190107](https://github.com/electron/electron/releases/tag/v5.0.0-nightly.20190107)|2019-01-08||yes|67|11.0.0|70.0.3538.110|818|
|[v5.0.0-beta.9](https://github.com/electron/electron/releases/tag/v5.0.0-beta.9)|2019-04-20|beta-5-0-x|yes|70|12.0.0|73.0.3683.117|3998|
|[v5.0.0-beta.8](https://github.com/electron/electron/releases/tag/v5.0.0-beta.8)|2019-04-04||yes|68|12.0.0|73.0.3683.104|8548|
|[v5.0.0-beta.7](https://github.com/electron/electron/releases/tag/v5.0.0-beta.7)|2019-03-28||yes|68|12.0.0|73.0.3683.94|21233|
|[v5.0.0-beta.6](https://github.com/electron/electron/releases/tag/v5.0.0-beta.6)|2019-03-20||yes|68|12.0.0|73.0.3683.84|49802|
|[v5.0.0-beta.5](https://github.com/electron/electron/releases/tag/v5.0.0-beta.5)|2019-03-05||yes|68|12.0.0|73.0.3683.61|7062|
|[v5.0.0-beta.4](https://github.com/electron/electron/releases/tag/v5.0.0-beta.4)|2019-02-27||yes|68|12.0.0|73.0.3683.54|3055|
|[v5.0.0-beta.3](https://github.com/electron/electron/releases/tag/v5.0.0-beta.3)|2019-02-15||yes|68|12.0.0|73.0.3683.27|5815|
|[v5.0.0-beta.2](https://github.com/electron/electron/releases/tag/v5.0.0-beta.2)|2019-02-04||yes|68|12.0.0|72.0.3626.52|5265|
|[v5.0.0-beta.1](https://github.com/electron/electron/releases/tag/v5.0.0-beta.1)|2019-01-23||yes|68|12.0.0|72.0.3626.52|8673|
|[v4.2.12](https://github.com/electron/electron/releases/tag/v4.2.12)|2019-10-16|4-2-x|no|69|10.11.0|69.0.3497.128|818697|
|[v4.2.11](https://github.com/electron/electron/releases/tag/v4.2.11)|2019-09-24||no|69|10.11.0|69.0.3497.128|82090|
|[v4.2.10](https://github.com/electron/electron/releases/tag/v4.2.10)|2019-08-29||no|69|10.11.0|69.0.3497.128|98582|
|[v4.2.9](https://github.com/electron/electron/releases/tag/v4.2.9)|2019-08-06||no|69|10.11.0|69.0.3497.128|101891|
|[v4.2.8](https://github.com/electron/electron/releases/tag/v4.2.8)|2019-07-20||no|69|10.11.0|69.0.3497.128|72225|
|[v4.2.7](https://github.com/electron/electron/releases/tag/v4.2.7)|2019-07-16||no|69|10.11.0|69.0.3497.128|37608|
|[v4.2.6](https://github.com/electron/electron/releases/tag/v4.2.6)|2019-07-02||no|69|10.11.0|69.0.3497.128|90085|
|[v4.2.5](https://github.com/electron/electron/releases/tag/v4.2.5)|2019-06-21||no|69|10.11.0|69.0.3497.128|79601|
|[v4.2.4](https://github.com/electron/electron/releases/tag/v4.2.4)|2019-06-05||no|69|10.11.0|69.0.3497.128|118528|
|[v4.2.3](https://github.com/electron/electron/releases/tag/v4.2.3)|2019-05-31||no|69|10.11.0|69.0.3497.128|63920|
|[v4.2.2](https://github.com/electron/electron/releases/tag/v4.2.2)|2019-05-17||no|69|10.11.0|69.0.3497.128|91879|
|[v4.2.1](https://github.com/electron/electron/releases/tag/v4.2.1)|2019-05-14||no|69|10.11.0|69.0.3497.128|32763|
|[v4.2.0](https://github.com/electron/electron/releases/tag/v4.2.0)|2019-05-03||no|69|10.11.0|69.0.3497.128|250477|
|[v4.1.5](https://github.com/electron/electron/releases/tag/v4.1.5)|2019-04-24|4-1-x|no|69|10.11.0|69.0.3497.128|76511|
|[v4.1.4](https://github.com/electron/electron/releases/tag/v4.1.4)|2019-04-04||no|69|10.11.0|69.0.3497.128|445381|
|[v4.1.3](https://github.com/electron/electron/releases/tag/v4.1.3)|2019-03-29||no|69|10.11.0|69.0.3497.128|131163|
|[v4.1.2](https://github.com/electron/electron/releases/tag/v4.1.2)|2019-03-28||no|69|10.11.0|69.0.3497.128|18296|
|[v4.1.1](https://github.com/electron/electron/releases/tag/v4.1.1)|2019-03-20||no|69|10.11.0|69.0.3497.128|141711|
|[v4.1.0](https://github.com/electron/electron/releases/tag/v4.1.0)|2019-03-14||no|69|10.11.0|69.0.3497.128|157370|
|[v4.0.8](https://github.com/electron/electron/releases/tag/v4.0.8)|2019-03-08|4-0-x|no|69|10.11.0|69.0.3497.128|104131|
|[v4.0.7](https://github.com/electron/electron/releases/tag/v4.0.7)|2019-03-05||no|69|10.11.0|69.0.3497.128|87833|
|[v4.0.6](https://github.com/electron/electron/releases/tag/v4.0.6)|2019-02-27||no|69|10.11.0|69.0.3497.106|112917|
|[v4.0.5](https://github.com/electron/electron/releases/tag/v4.0.5)|2019-02-15||no|69|10.11.0|69.0.3497.106|166211|
|[v4.0.4](https://github.com/electron/electron/releases/tag/v4.0.4)|2019-02-02||no|69|10.11.0|69.0.3497.106|486805|
|[v4.0.3](https://github.com/electron/electron/releases/tag/v4.0.3)|2019-01-29||no|64|10.11.0|69.0.3497.106|84598|
|[v4.0.2](https://github.com/electron/electron/releases/tag/v4.0.2)|2019-01-22||no|64|10.11.0|69.0.3497.106|119672|
|[v4.0.1](https://github.com/electron/electron/releases/tag/v4.0.1)|2019-01-04||no|64|10.11.0|69.0.3497.106|359927|
|[v4.0.0](https://github.com/electron/electron/releases/tag/v4.0.0)|2018-12-20||no|64|10.11.0|69.0.3497.106|615324|
|[v4.0.0-nightly.20181010](https://github.com/electron/electron/releases/tag/v4.0.0-nightly.20181010)|2018-10-10||yes|64|10.11.0|69.0.3497.106|8801|
|[v4.0.0-nightly.20181006](https://github.com/electron/electron/releases/tag/v4.0.0-nightly.20181006)|2018-10-06||yes|64|10.11.0|68.0.3440.128|691|
|[v4.0.0-nightly.20180929](https://github.com/electron/electron/releases/tag/v4.0.0-nightly.20180929)|2018-09-29||yes|64|10.6.0|67.0.3396.99|819|
|[v4.0.0-nightly.20180821](https://github.com/electron/electron/releases/tag/v4.0.0-nightly.20180821)|2018-08-21||yes|64|10.2.0|66.0.3359.181|588|
|[v4.0.0-nightly.20180819](https://github.com/electron/electron/releases/tag/v4.0.0-nightly.20180819)|2018-08-19||yes|64|10.2.0|66.0.3359.181|385|
|[v4.0.0-nightly.20180817](https://github.com/electron/electron/releases/tag/v4.0.0-nightly.20180817)|2018-08-18||yes|64|10.2.0|66.0.3359.181|336|
|[v4.0.0-beta.11](https://github.com/electron/electron/releases/tag/v4.0.0-beta.11)|2018-12-19|beta-4-0-x|yes|64|10.11.0|69.0.3497.106|6170|
|[v4.0.0-beta.10](https://github.com/electron/electron/releases/tag/v4.0.0-beta.10)|2018-12-17||yes|64|10.11.0|69.0.3497.106|6033|
|[v4.0.0-beta.9](https://github.com/electron/electron/releases/tag/v4.0.0-beta.9)|2018-12-11||yes|64|10.11.0|69.0.3497.106|4666|
|[v4.0.0-beta.8](https://github.com/electron/electron/releases/tag/v4.0.0-beta.8)|2018-11-30||yes|64|10.11.0|69.0.3497.106|4477|
|[v4.0.0-beta.7](https://github.com/electron/electron/releases/tag/v4.0.0-beta.7)|2018-11-06||yes|64|10.11.0|69.0.3497.106|9939|
|[v4.0.0-beta.6](https://github.com/electron/electron/releases/tag/v4.0.0-beta.6)|2018-11-01||yes|64|10.11.0|69.0.3497.106|7296|
|[v4.0.0-beta.5](https://github.com/electron/electron/releases/tag/v4.0.0-beta.5)|2018-10-23||yes|64|10.11.0|69.0.3497.106|7375|
|[v4.0.0-beta.4](https://github.com/electron/electron/releases/tag/v4.0.0-beta.4)|2018-10-19||yes|64|10.11.0|69.0.3497.106|5506|
|[v4.0.0-beta.3](https://github.com/electron/electron/releases/tag/v4.0.0-beta.3)|2018-10-12||yes|64|10.11.0|69.0.3497.106|5382|
|[v4.0.0-beta.2](https://github.com/electron/electron/releases/tag/v4.0.0-beta.2)|2018-10-12||yes|64|10.11.0|69.0.3497.106|4050|
|[v4.0.0-beta.1](https://github.com/electron/electron/releases/tag/v4.0.0-beta.1)|2018-10-11||yes|64|10.11.0|69.0.3497.106|26692|
|[v3.1.13](https://github.com/electron/electron/releases/tag/v3.1.13)|2019-07-31||no|64|10.2.0|66.0.3359.181|527833|
|[v3.1.12](https://github.com/electron/electron/releases/tag/v3.1.12)|2019-07-11|3-1-x|no|64|10.2.0|66.0.3359.181|48505|
|[v3.1.11](https://github.com/electron/electron/releases/tag/v3.1.11)|2019-06-06||no|64|10.2.0|66.0.3359.181|63655|
|[v3.1.10](https://github.com/electron/electron/releases/tag/v3.1.10)|2019-05-29||no|64|10.2.0|66.0.3359.181|48284|
|[v3.1.9](https://github.com/electron/electron/releases/tag/v3.1.9)|2019-05-01||no|64|10.2.0|66.0.3359.181|162685|
|[v3.1.8](https://github.com/electron/electron/releases/tag/v3.1.8)|2019-03-28||no|64|10.2.0|66.0.3359.181|158997|
|[v3.1.7](https://github.com/electron/electron/releases/tag/v3.1.7)|2019-03-21||no|64|10.2.0|66.0.3359.181|85623|
|[v3.1.6](https://github.com/electron/electron/releases/tag/v3.1.6)|2019-03-08||no|64|10.2.0|66.0.3359.181|120017|
|[v3.1.5](https://github.com/electron/electron/releases/tag/v3.1.5)|2019-03-04||no|64|10.2.0|66.0.3359.181|12265|
|[v3.1.4](https://github.com/electron/electron/releases/tag/v3.1.4)|2019-02-15||no|64|10.2.0|66.0.3359.181|43071|
|[v3.1.3](https://github.com/electron/electron/releases/tag/v3.1.3)|2019-01-31||no|64|10.2.0|66.0.3359.181|219504|
|[v3.1.2](https://github.com/electron/electron/releases/tag/v3.1.2)|2019-01-24||no|64|10.2.0|66.0.3359.181|34147|
|[v3.1.1](https://github.com/electron/electron/releases/tag/v3.1.1)|2019-01-14||no|64|10.2.0|66.0.3359.181|65490|
|[v3.1.0](https://github.com/electron/electron/releases/tag/v3.1.0)|2019-01-07||no|64|10.2.0|66.0.3359.181|54280|
|[v3.1.0-beta.5](https://github.com/electron/electron/releases/tag/v3.1.0-beta.5)|2019-01-04|beta-3-1-x|yes|64|10.2.0|66.0.3359.181|7280|
|[v3.1.0-beta.4](https://github.com/electron/electron/releases/tag/v3.1.0-beta.4)|2018-12-17||yes|64|10.2.0|66.0.3359.181|10248|
|[v3.1.0-beta.3](https://github.com/electron/electron/releases/tag/v3.1.0-beta.3)|2018-12-14||yes|64|10.2.0|66.0.3359.181|3022|
|[v3.1.0-beta.2](https://github.com/electron/electron/releases/tag/v3.1.0-beta.2)|2018-12-04||yes|64|10.2.0|66.0.3359.181|3700|
|[v3.1.0-beta.1](https://github.com/electron/electron/releases/tag/v3.1.0-beta.1)|2018-12-02||yes|64|10.2.0|66.0.3359.181|2183|
|[v3.0.16](https://github.com/electron/electron/releases/tag/v3.0.16)|2019-03-08|3-0-x|no|64|10.2.0|66.0.3359.181|34940|
|[v3.0.15](https://github.com/electron/electron/releases/tag/v3.0.15)|2019-01-31||no|64|10.2.0|66.0.3359.181|10139|
|[v3.0.14](https://github.com/electron/electron/releases/tag/v3.0.14)|2019-01-04||no|64|10.2.0|66.0.3359.181|37978|
|[v3.0.13](https://github.com/electron/electron/releases/tag/v3.0.13)|2018-12-17||no|64|10.2.0|66.0.3359.181|229441|
|[v3.0.12](https://github.com/electron/electron/releases/tag/v3.0.12)|2018-12-14||no|64|10.2.0|66.0.3359.181|32065|
|[v3.0.11](https://github.com/electron/electron/releases/tag/v3.0.11)|2018-12-11||no|64|10.2.0|66.0.3359.181|105622|
|[v3.0.10](https://github.com/electron/electron/releases/tag/v3.0.10)|2018-11-19||no|64|10.2.0|66.0.3359.181|370898|
|[v3.0.9](https://github.com/electron/electron/releases/tag/v3.0.9)|2018-11-13||no|64|10.2.0|66.0.3359.181|179430|
|[v3.0.8](https://github.com/electron/electron/releases/tag/v3.0.8)|2018-11-05||no|64|10.2.0|66.0.3359.181|130357|
|[v3.0.7](https://github.com/electron/electron/releases/tag/v3.0.7)|2018-11-01||no|64|10.2.0|66.0.3359.181|131647|
|[v3.0.6](https://github.com/electron/electron/releases/tag/v3.0.6)|2018-10-24||no|64|10.2.0|66.0.3359.181|110600|
|[v3.0.5](https://github.com/electron/electron/releases/tag/v3.0.5)|2018-10-19||no|64|10.2.0|66.0.3359.181|96545|
|[v3.0.4](https://github.com/electron/electron/releases/tag/v3.0.4)|2018-10-11||no|64|10.2.0|66.0.3359.181|124555|
|[v3.0.3](https://github.com/electron/electron/releases/tag/v3.0.3)|2018-10-07||no|64|10.2.0|66.0.3359.181|75937|
|[v3.0.2](https://github.com/electron/electron/releases/tag/v3.0.2)|2018-09-27||no|64|10.2.0|66.0.3359.181|128575|
|[v3.0.1](https://github.com/electron/electron/releases/tag/v3.0.1)|2018-09-27||no|64|10.2.0|66.0.3359.181|16554|
|[v3.0.0](https://github.com/electron/electron/releases/tag/v3.0.0)|2018-09-18||no|64|10.2.0|66.0.3359.181|1521417|
|[v3.0.0-nightly.20180904](https://github.com/electron/electron/releases/tag/v3.0.0-nightly.20180904)|2018-09-05||yes|64|10.2.0|66.0.3359.181|1227|
|[v3.0.0-nightly.20180823](https://github.com/electron/electron/releases/tag/v3.0.0-nightly.20180823)|2018-08-24||yes|64|10.2.0|66.0.3359.181|408|
|[v3.0.0-nightly.20180821](https://github.com/electron/electron/releases/tag/v3.0.0-nightly.20180821)|2018-08-21||yes|64|10.2.0|66.0.3359.181|1156|
|[v3.0.0-nightly.20180818](https://github.com/electron/electron/releases/tag/v3.0.0-nightly.20180818)|2018-08-18||yes|64|10.2.0|66.0.3359.181|529|
|[v3.0.0-beta.13](https://github.com/electron/electron/releases/tag/v3.0.0-beta.13)|2018-09-17||yes|64|10.2.0|66.0.3359.181|3556|
|[v3.0.0-beta.12](https://github.com/electron/electron/releases/tag/v3.0.0-beta.12)|2018-09-12||yes|64|10.2.0|66.0.3359.181|8050|
|[v3.0.0-beta.11](https://github.com/electron/electron/releases/tag/v3.0.0-beta.11)|2018-09-12||yes|64|10.2.0|66.0.3359.181|3257|
|[v3.0.0-beta.10](https://github.com/electron/electron/releases/tag/v3.0.0-beta.10)|2018-09-08||yes|64|10.2.0|66.0.3359.181|4509|
|[v3.0.0-beta.9](https://github.com/electron/electron/releases/tag/v3.0.0-beta.9)|2018-09-06||yes|64|10.2.0|66.0.3359.181|3902|
|[v3.0.0-beta.8](https://github.com/electron/electron/releases/tag/v3.0.0-beta.8)|2018-08-29||yes|64|10.2.0|66.0.3359.181|7066|
|[v3.0.0-beta.7](https://github.com/electron/electron/releases/tag/v3.0.0-beta.7)|2018-08-22||yes|64|10.2.0|66.0.3359.181|5419|
|[v3.0.0-beta.6](https://github.com/electron/electron/releases/tag/v3.0.0-beta.6)|2018-08-20||yes|64|10.2.0|66.0.3359.181|5247|
|[v3.0.0-beta.5](https://github.com/electron/electron/releases/tag/v3.0.0-beta.5)|2018-08-13||yes|64|10.2.0|66.0.3359.181|28652|
|[v3.0.0-beta.4](https://github.com/electron/electron/releases/tag/v3.0.0-beta.4)|2018-08-01||yes|64|10.2.0|66.0.3359.181|16726|
|[v3.0.0-beta.3](https://github.com/electron/electron/releases/tag/v3.0.0-beta.3)|2018-07-17||yes|64|10.2.0|66.0.3359.181|8084|
|[v3.0.0-beta.2](https://github.com/electron/electron/releases/tag/v3.0.0-beta.2)|2018-07-10||yes|64|10.2.0|66.0.3359.181|6200|
|[v3.0.0-beta.1](https://github.com/electron/electron/releases/tag/v3.0.0-beta.1)|2018-06-21||yes|64|10.2.0|66.0.3359.181|35517|
|[v2.1.0-unsupported.20180809](https://github.com/electron/electron/releases/tag/v2.1.0-unsupported.20180809)|2018-08-09|unsupported|no|57|8.9.3|61.0.3163.100|8853|
|[v2.0.18](https://github.com/electron/electron/releases/tag/v2.0.18)|2019-03-08|2-0-x|no|57|8.9.3|61.0.3163.100|2251114|
|[v2.0.17](https://github.com/electron/electron/releases/tag/v2.0.17)|2019-01-31||no|57|8.9.3|61.0.3163.100|111013|
|[v2.0.16](https://github.com/electron/electron/releases/tag/v2.0.16)|2018-12-18||no|57|8.9.3|61.0.3163.100|203694|
|[v2.0.15](https://github.com/electron/electron/releases/tag/v2.0.15)|2018-12-13||no|57|8.9.3|61.0.3163.100|17939|
|[v2.0.14](https://github.com/electron/electron/releases/tag/v2.0.14)|2018-11-19||no|57|8.9.3|61.0.3163.100|123639|
|[v2.0.13](https://github.com/electron/electron/releases/tag/v2.0.13)|2018-11-01||no|57|8.9.3|61.0.3163.100|119125|
|[v2.0.12](https://github.com/electron/electron/releases/tag/v2.0.12)|2018-10-19||no|57|8.9.3|61.0.3163.100|155242|
|[v2.0.11](https://github.com/electron/electron/releases/tag/v2.0.11)|2018-10-01||no|57|8.9.3|61.0.3163.100|107693|
|[v2.0.10](https://github.com/electron/electron/releases/tag/v2.0.10)|2018-09-19||no|57|8.9.3|61.0.3163.100|103070|
|[v2.0.9](https://github.com/electron/electron/releases/tag/v2.0.9)|2018-09-10||no|57|8.9.3|61.0.3163.100|304380|
|[v2.0.8](https://github.com/electron/electron/releases/tag/v2.0.8)|2018-08-22||no|57|8.9.3|61.0.3163.100|937808|
|[v2.0.8-nightly.20180820](https://github.com/electron/electron/releases/tag/v2.0.8-nightly.20180820)|2018-08-21||yes|57|8.9.3|61.0.3163.100|405|
|[v2.0.8-nightly.20180819](https://github.com/electron/electron/releases/tag/v2.0.8-nightly.20180819)|2018-08-20||yes|57|8.9.3|61.0.3163.100|390|
|[v2.0.7](https://github.com/electron/electron/releases/tag/v2.0.7)|2018-08-08||no|57|8.9.3|61.0.3163.100|231606|
|[v2.0.6](https://github.com/electron/electron/releases/tag/v2.0.6)|2018-08-01||no|57|8.9.3|61.0.3163.100|196042|
|[v2.0.5](https://github.com/electron/electron/releases/tag/v2.0.5)|2018-07-13||no|57|8.9.3|61.0.3163.100|281951|
|[v2.0.4](https://github.com/electron/electron/releases/tag/v2.0.4)|2018-07-03||no|57|8.9.3|61.0.3163.100|178326|
|[v2.0.3](https://github.com/electron/electron/releases/tag/v2.0.3)|2018-06-21||no|57|8.9.3|61.0.3163.100|146788|
|[v2.0.2](https://github.com/electron/electron/releases/tag/v2.0.2)|2018-05-22||no|57|8.9.3|61.0.3163.100|488270|
|[v2.0.1](https://github.com/electron/electron/releases/tag/v2.0.1)|2018-05-16||no|57|8.9.3|61.0.3163.100|128683|
|[v2.0.0](https://github.com/electron/electron/releases/tag/v2.0.0)|2018-05-01||no|57|8.9.3|61.0.3163.100|746104|
|[v2.0.0-beta.8](https://github.com/electron/electron/releases/tag/v2.0.0-beta.8)|2018-04-26||yes|57|8.9.3|61.0.3163.100|19650|
|[v2.0.0-beta.7](https://github.com/electron/electron/releases/tag/v2.0.0-beta.7)|2018-04-03||yes|57|8.9.3|61.0.3163.100|44485|
|[v2.0.0-beta.6](https://github.com/electron/electron/releases/tag/v2.0.0-beta.6)|2018-03-27||yes|57|8.9.3|61.0.3163.100|15543|
|[v2.0.0-beta.5](https://github.com/electron/electron/releases/tag/v2.0.0-beta.5)|2018-03-20||yes|57|8.9.3|61.0.3163.100|14354|
|[v2.0.0-beta.4](https://github.com/electron/electron/releases/tag/v2.0.0-beta.4)|2018-03-15||yes|57|8.9.3|61.0.3163.100|13109|
|[v2.0.0-beta.3](https://github.com/electron/electron/releases/tag/v2.0.0-beta.3)|2018-03-09||yes|57|8.9.3|61.0.3163.100|11493|
|[v2.0.0-beta.2](https://github.com/electron/electron/releases/tag/v2.0.0-beta.2)|2018-03-05||yes|57|8.9.3|61.0.3163.100|20766|
|[v2.0.0-beta.1](https://github.com/electron/electron/releases/tag/v2.0.0-beta.1)|2018-02-21||yes|57|8.9.3|61.0.3163.100|15884|
|[v1.8.8](https://github.com/electron/electron/releases/tag/v1.8.8)|2018-08-22|1-8-x|no|57|8.2.1|59.0.3071.115|5387716|
|[v1.8.7](https://github.com/electron/electron/releases/tag/v1.8.7)|2018-05-16||no|57|8.2.1|59.0.3071.115|1119260|
|[v1.8.6](https://github.com/electron/electron/releases/tag/v1.8.6)|2018-04-27||no|57|8.2.1|59.0.3071.115|284949|
|[v1.8.5](https://github.com/electron/electron/releases/tag/v1.8.5)|2018-04-26||no|57|8.2.1|59.0.3071.115|22311|
|[v1.8.4](https://github.com/electron/electron/releases/tag/v1.8.4)|2018-03-16||no|57|8.2.1|59.0.3071.115|954259|
|[v1.8.3](https://github.com/electron/electron/releases/tag/v1.8.3)|2018-03-06||no|57|8.2.1|59.0.3071.115|416606|
|[v1.8.2](https://github.com/electron/electron/releases/tag/v1.8.2)|2018-02-07||no|57|8.2.1|59.0.3071.115|622051|
|[v1.8.2-beta.5](https://github.com/electron/electron/releases/tag/v1.8.2-beta.5)|2018-01-31||yes|57|8.2.1|59.0.3071.115|153700|
|[v1.8.2-beta.4](https://github.com/electron/electron/releases/tag/v1.8.2-beta.4)|2018-01-23||yes|57|8.2.1|59.0.3071.115|23118|
|[v1.8.2-beta.3](https://github.com/electron/electron/releases/tag/v1.8.2-beta.3)|2017-12-04||yes|57|8.2.1|59.0.3071.115|39566|
|[v1.8.2-beta.2](https://github.com/electron/electron/releases/tag/v1.8.2-beta.2)|2017-11-06||yes|57|8.2.1|59.0.3071.115|33587|
|[v1.8.2-beta.1](https://github.com/electron/electron/releases/tag/v1.8.2-beta.1)|2017-10-19||yes|57|8.2.1|59.0.3071.115|20434|
|[v1.8.1](https://github.com/electron/electron/releases/tag/v1.8.1)|2017-09-29||yes|57|8.2.1|59.0.3071.115|380312|
|[v1.8.0](https://github.com/electron/electron/releases/tag/v1.8.0)|2017-12-12||yes|57|8.2.1|59.0.3071.115|1903582|
|[v1.7.16](https://github.com/electron/electron/releases/tag/v1.7.16)|2018-08-22|1-7-x|no|54|7.9.0|58.0.3029.110|272483|
|[v1.7.15](https://github.com/electron/electron/releases/tag/v1.7.15)|2018-05-16||no|54|7.9.0|58.0.3029.110|34214|
|[v1.7.14](https://github.com/electron/electron/releases/tag/v1.7.14)|2018-04-27||no|54|7.9.0|58.0.3029.110|19451|
|[v1.7.13](https://github.com/electron/electron/releases/tag/v1.7.13)|2018-03-15||no|54|7.9.0|58.0.3029.110|84354|
|[v1.7.12](https://github.com/electron/electron/releases/tag/v1.7.12)|2018-01-31||no|54|7.9.0|58.0.3029.110|322315|
|[v1.7.11](https://github.com/electron/electron/releases/tag/v1.7.11)|2018-01-23||no|54|7.9.0|58.0.3029.110|494229|
|[v1.7.10](https://github.com/electron/electron/releases/tag/v1.7.10)|2017-12-18||no|54|7.9.0|58.0.3029.110|888915|
|[v1.7.9](https://github.com/electron/electron/releases/tag/v1.7.9)|2017-10-11||no|54|7.9.0|58.0.3029.110|1335098|
|[v1.7.8](https://github.com/electron/electron/releases/tag/v1.7.8)|2017-09-24||no|54|7.9.0|58.0.3029.110|370921|
|[v1.7.7](https://github.com/electron/electron/releases/tag/v1.7.7)|2017-09-05||yes|54|7.9.0|58.0.3029.110|150545|
|[v1.7.6](https://github.com/electron/electron/releases/tag/v1.7.6)|2017-08-09||no|54|7.9.0|58.0.3029.110|456080|
|[v1.7.5](https://github.com/electron/electron/releases/tag/v1.7.5)|2017-07-17||no|54|7.9.0|58.0.3029.110|445678|
|[v1.7.4](https://github.com/electron/electron/releases/tag/v1.7.4)|2017-06-28||yes|54|7.9.0|58.0.3029.110|81960|
|[v1.7.3](https://github.com/electron/electron/releases/tag/v1.7.3)|2017-06-08||yes|54|7.9.0|58.0.3029.110|94300|
|[v1.7.2](https://github.com/electron/electron/releases/tag/v1.7.2)|2017-05-26||yes|54|7.9.0|58.0.3029.110|51285|
|[v1.7.1](https://github.com/electron/electron/releases/tag/v1.7.1)|2017-05-16||yes|54|7.9.0|58.0.3029.110|222144|
|[v1.7.0](https://github.com/electron/electron/releases/tag/v1.7.0)|2017-05-10||yes|54|7.9.0|58.0.3029.110|836534|
|[v1.6.18](https://github.com/electron/electron/releases/tag/v1.6.18)|2018-05-15||no|53|7.4.0|56.0.2924.87|58085|
|[v1.6.17](https://github.com/electron/electron/releases/tag/v1.6.17)|2018-01-31||no|53|7.4.0|56.0.2924.87|25810|
|[v1.6.16](https://github.com/electron/electron/releases/tag/v1.6.16)|2018-01-23||no|53|7.4.0|56.0.2924.87|30009|
|[v1.6.15](https://github.com/electron/electron/releases/tag/v1.6.15)|2017-10-11||no|53|7.4.0|56.0.2924.87|82444|
|[v1.6.14](https://github.com/electron/electron/releases/tag/v1.6.14)|2017-09-28||no|53|7.4.0|56.0.2924.87|30206|
|[v1.6.13](https://github.com/electron/electron/releases/tag/v1.6.13)|2017-09-06||yes|53|7.4.0|56.0.2924.87|45317|
|[v1.6.12](https://github.com/electron/electron/releases/tag/v1.6.12)|2017-09-06||yes|53|7.4.0|56.0.2924.87|50006|
|[v1.6.11](https://github.com/electron/electron/releases/tag/v1.6.11)|2017-05-25||no|53|7.4.0|56.0.2924.87|794495|
|[v1.6.10](https://github.com/electron/electron/releases/tag/v1.6.10)|2017-05-16||no|53|7.4.0|56.0.2924.87|275371|
|[v1.6.9](https://github.com/electron/electron/releases/tag/v1.6.9)|2017-05-10||no|53|7.4.0|56.0.2924.87|18816|
|[v1.6.8](https://github.com/electron/electron/releases/tag/v1.6.8)|2017-05-01||no|53|7.4.0|56.0.2924.87|155222|
|[v1.6.7](https://github.com/electron/electron/releases/tag/v1.6.7)|2017-04-18||no|53|7.4.0|56.0.2924.87|152975|
|[v1.6.6](https://github.com/electron/electron/releases/tag/v1.6.6)|2017-04-07||no|53|7.4.0|56.0.2924.87|344142|
|[v1.6.5](https://github.com/electron/electron/releases/tag/v1.6.5)|2017-03-31||no|53|7.4.0|56.0.2924.87|160500|
|[v1.6.4](https://github.com/electron/electron/releases/tag/v1.6.4)|2017-03-22||yes|53|7.4.0|56.0.2924.87|37090|
|[v1.6.3](https://github.com/electron/electron/releases/tag/v1.6.3)|2017-03-07||yes|53|7.4.0|56.0.2924.87|58184|
|[v1.6.2](https://github.com/electron/electron/releases/tag/v1.6.2)|2017-03-01||no|53|7.4.0|56.0.2924.87|621396|
|[v1.6.1](https://github.com/electron/electron/releases/tag/v1.6.1)|2017-02-21||no|53|7.4.0|56.0.2924.87|222542|
|[v1.6.0](https://github.com/electron/electron/releases/tag/v1.6.0)|2017-02-07||yes|53|7.4.0|56.0.2924.87|414537|
|[v1.5.1](https://github.com/electron/electron/releases/tag/v1.5.1)|2017-02-06||yes|51|7.4.0|54.0.2840.101|19111|
|[v1.5.0](https://github.com/electron/electron/releases/tag/v1.5.0)|2017-01-24||yes|51|7.4.0|54.0.2840.101|208012|
|[v1.4.16](https://github.com/electron/electron/releases/tag/v1.4.16)|2017-04-05||no|50|6.5.0|53.0.2785.143|254573|
|[v1.4.15](https://github.com/electron/electron/releases/tag/v1.4.15)|2017-01-19||no|50|6.5.0|53.0.2785.143|1303315|
|[v1.4.14](https://github.com/electron/electron/releases/tag/v1.4.14)|2017-01-10||no|50|6.5.0|53.0.2785.143|191111|
|[v1.4.13](https://github.com/electron/electron/releases/tag/v1.4.13)|2016-12-20||no|50|6.5.0|53.0.2785.143|1262877|
|[v1.4.12](https://github.com/electron/electron/releases/tag/v1.4.12)|2016-12-10||no|50|6.5.0|54.0.2840.51|122932|
|[v1.4.11](https://github.com/electron/electron/releases/tag/v1.4.11)|2016-12-07||no|50|6.5.0|53.0.2785.143|27733|
|[v1.4.10](https://github.com/electron/electron/releases/tag/v1.4.10)|2016-11-28||no|50|6.5.0|53.0.2785.143|97674|
|[v1.4.8](https://github.com/electron/electron/releases/tag/v1.4.8)|2016-11-22||no|50|6.5.0|53.0.2785.143|47003|
|[v1.4.7](https://github.com/electron/electron/releases/tag/v1.4.7)|2016-11-16||no|50|6.5.0|53.0.2785.143|51738|
|[v1.4.6](https://github.com/electron/electron/releases/tag/v1.4.6)|2016-11-09||no|50|6.5.0|53.0.2785.143|124939|
|[v1.4.5](https://github.com/electron/electron/releases/tag/v1.4.5)|2016-11-01||no|50|6.5.0|53.0.2785.113|63115|
|[v1.4.4](https://github.com/electron/electron/releases/tag/v1.4.4)|2016-10-20||no|50|6.5.0|53.0.2785.113|100565|
|[v1.4.3](https://github.com/electron/electron/releases/tag/v1.4.3)|2016-10-06||no|50|6.5.0|53.0.2785.113|141327|
|[v1.4.2](https://github.com/electron/electron/releases/tag/v1.4.2)|2016-09-30||no|50|6.5.0|53.0.2785.113|41842|
|[v1.4.1](https://github.com/electron/electron/releases/tag/v1.4.1)|2016-09-22||no|50|6.5.0|53.0.2785.113|63370|
|[v1.4.0](https://github.com/electron/electron/releases/tag/v1.4.0)|2016-09-15||no|50|6.5.0|53.0.2785.113|246062|
|[v1.3.15](https://github.com/electron/electron/releases/tag/v1.3.15)|2017-04-21||no|49|6.5.0|52.0.2743.82|19599|
|[v1.3.14](https://github.com/electron/electron/releases/tag/v1.3.14)|2017-03-14||no|49|6.5.0|52.0.2743.82|21115|
|[v1.3.13](https://github.com/electron/electron/releases/tag/v1.3.13)|2016-12-06||no|49|6.5.0|52.0.2743.82|29450|
|[v1.3.12](https://github.com/electron/electron/releases/tag/v1.3.12)|2016-11-28||no||||2186|
|[v1.3.10](https://github.com/electron/electron/releases/tag/v1.3.10)|2016-11-22||no|49|6.5.0|52.0.2743.82|2022|
|[v1.3.9](https://github.com/electron/electron/releases/tag/v1.3.9)|2016-11-16||no|49|6.5.0|52.0.2743.82|54796|
|[v1.3.8](https://github.com/electron/electron/releases/tag/v1.3.8)|2016-10-20||no||||35993|
|[v1.3.7](https://github.com/electron/electron/releases/tag/v1.3.7)|2016-09-27||no|49|6.5.0|52.0.2743.82|13523|
|[v1.3.6](https://github.com/electron/electron/releases/tag/v1.3.6)|2016-09-15||no|49|6.3.0|52.0.2743.82|39430|
|[v1.3.5](https://github.com/electron/electron/releases/tag/v1.3.5)|2016-09-02||no|49|6.3.0|52.0.2743.82|92691|
|[v1.3.4](https://github.com/electron/electron/releases/tag/v1.3.4)|2016-08-23||no|49|6.3.0|52.0.2743.82|110455|
|[v1.3.3](https://github.com/electron/electron/releases/tag/v1.3.3)|2016-08-10||no|49|6.3.0|52.0.2743.82|135846|
|[v1.3.2](https://github.com/electron/electron/releases/tag/v1.3.2)|2016-08-02||no|49|6.3.0|52.0.2743.82|77464|
|[v1.3.1](https://github.com/electron/electron/releases/tag/v1.3.1)|2016-07-27||no|49|6.3.0|52.0.2743.82|135802|
|[v1.3.0](https://github.com/electron/electron/releases/tag/v1.3.0)|2016-07-25||no|49|6.3.0|52.0.2743.82|133769|
|[v1.2.8](https://github.com/electron/electron/releases/tag/v1.2.8)|2016-07-21||no|48|6.1.0|51.0.2704.106|114500|
|[v1.2.7](https://github.com/electron/electron/releases/tag/v1.2.7)|2016-07-13||no|48|6.1.0|51.0.2704.106|69933|
|[v1.2.6](https://github.com/electron/electron/releases/tag/v1.2.6)|2016-07-06||no|48|6.1.0|51.0.2704.106|75894|
|[v1.2.5](https://github.com/electron/electron/releases/tag/v1.2.5)|2016-06-23||no|48|6.1.0|51.0.2704.103|78475|
|[v1.2.4](https://github.com/electron/electron/releases/tag/v1.2.4)|2016-06-22||no|48|6.1.0|51.0.2704.103|30732|
|[v1.2.3](https://github.com/electron/electron/releases/tag/v1.2.3)|2016-06-16||no|48|6.1.0|51.0.2704.84|54743|
|[v1.2.2](https://github.com/electron/electron/releases/tag/v1.2.2)|2016-06-08||no|48|6.1.0|51.0.2704.84|156893|
|[v1.2.1](https://github.com/electron/electron/releases/tag/v1.2.1)|2016-06-01||no|48|6.1.0|51.0.2704.63|65265|
|[v1.2.0](https://github.com/electron/electron/releases/tag/v1.2.0)|2016-05-26||no|48|6.1.0|51.0.2704.63|120635|
|[v1.1.3](https://github.com/electron/electron/releases/tag/v1.1.3)|2016-05-25||no|48|6.1.0|50.0.2661.102|76527|
|[v1.1.2](https://github.com/electron/electron/releases/tag/v1.1.2)|2016-05-24||no|48|6.1.0|50.0.2661.102|31894|
|[v1.1.1](https://github.com/electron/electron/releases/tag/v1.1.1)|2016-05-20||no|48|6.1.0|50.0.2661.102|74799|
|[v1.1.0](https://github.com/electron/electron/releases/tag/v1.1.0)|2016-05-14||no|48|6.1.0|50.0.2661.102|83891|
|[v1.0.2](https://github.com/electron/electron/releases/tag/v1.0.2)|2016-05-13||no|47|5.10.0|49.0.2623.75|50633|
|[v1.0.1](https://github.com/electron/electron/releases/tag/v1.0.1)|2016-05-11||no|47|5.10.0|49.0.2623.75|44767|
|[v1.0.0](https://github.com/electron/electron/releases/tag/v1.0.0)|2016-05-11||no|47|5.10.0|49.0.2623.75|155467|
|[v0.37.8](https://github.com/electron/electron/releases/tag/v0.37.8)|2016-04-29||no|47|5.10.0|49.0.2623.75|274970|
|[v0.37.7](https://github.com/electron/electron/releases/tag/v0.37.7)|2016-04-22||no|47|5.10.0|49.0.2623.75|58789|
|[v0.37.6](https://github.com/electron/electron/releases/tag/v0.37.6)|2016-04-15||no|47|5.10.0|49.0.2623.75|98505|
|[v0.37.5](https://github.com/electron/electron/releases/tag/v0.37.5)|2016-04-07||no|47|5.10.0|49.0.2623.75|58285|
|[v0.37.4](https://github.com/electron/electron/releases/tag/v0.37.4)|2016-04-03||no|47|6.0.0-pre|49.0.2623.75|61369|
|[v0.37.3](https://github.com/electron/electron/releases/tag/v0.37.3)|2016-03-27||no|47|5.1.1|49.0.2623.75|199939|
|[v0.37.2](https://github.com/electron/electron/releases/tag/v0.37.2)|2016-03-14||no||||76780|
|[v0.37.1](https://github.com/electron/electron/releases/tag/v0.37.1)|2016-03-13||no|47|5.1.1|49.0.2623.75|24481|
|[v0.37.0](https://github.com/electron/electron/releases/tag/v0.37.0)|2016-03-12||no|47|5.1.1|49.0.2623.75|133624|
|[v0.36.12](https://github.com/electron/electron/releases/tag/v0.36.12)|2016-03-27||no|47|5.1.1|47.0.2526.110|242280|
|[v0.36.11](https://github.com/electron/electron/releases/tag/v0.36.11)|2016-03-11||no|47|5.1.1|47.0.2526.110|47210|
|[v0.36.10](https://github.com/electron/electron/releases/tag/v0.36.10)|2016-03-05||no|47|5.1.1|47.0.2526.110|47857|
|[v0.36.9](https://github.com/electron/electron/releases/tag/v0.36.9)|2016-02-26||no|47|5.1.1|47.0.2526.110|63059|
|[v0.36.8](https://github.com/electron/electron/releases/tag/v0.36.8)|2016-02-19||no|47|5.1.1|47.0.2526.110|54239|
|[v0.36.7](https://github.com/electron/electron/releases/tag/v0.36.7)|2016-01-30||no|47|5.1.1|47.0.2526.110|132374|
|[v0.36.6](https://github.com/electron/electron/releases/tag/v0.36.6)|2016-01-29||no|47|5.1.1|47.0.2526.110|20341|
|[v0.36.5](https://github.com/electron/electron/releases/tag/v0.36.5)|2016-01-22||no|47|5.1.1|47.0.2526.110|42678|
|[v0.36.4](https://github.com/electron/electron/releases/tag/v0.36.4)|2016-01-15||no|47|5.1.1|47.0.2526.73|63717|
|[v0.36.3](https://github.com/electron/electron/releases/tag/v0.36.3)|2016-01-11||no|47|5.1.1|47.0.2526.73|37214|
|[v0.36.2](https://github.com/electron/electron/releases/tag/v0.36.2)|2015-12-25||no|47|5.1.1|47.0.2526.73|59893|
|[v0.36.1](https://github.com/electron/electron/releases/tag/v0.36.1)|2015-12-18||no||||34543|
|[v0.36.0](https://github.com/electron/electron/releases/tag/v0.36.0)|2015-12-11||no|47|5.1.1|47.0.2526.73|107367|
|[v0.35.6](https://github.com/electron/electron/releases/tag/v0.35.6)|2016-01-11||no||||126369|
|[v0.35.5](https://github.com/electron/electron/releases/tag/v0.35.5)|2015-12-31||no|46|4.1.1|45.0.2454.85|18104|
|[v0.35.4](https://github.com/electron/electron/releases/tag/v0.35.4)|2015-12-04||no|46|4.1.1|45.0.2454.85|89518|
|[v0.35.3](https://github.com/electron/electron/releases/tag/v0.35.3)|2015-12-04||no|46|4.1.1|45.0.2454.85|55352|
|[v0.35.2](https://github.com/electron/electron/releases/tag/v0.35.2)|2015-11-27||no|46|4.1.1|45.0.2454.85|38286|
|[v0.35.1](https://github.com/electron/electron/releases/tag/v0.35.1)|2015-11-20||no|46|4.1.1|45.0.2454.85|36570|
|[v0.35.0](https://github.com/electron/electron/releases/tag/v0.35.0)|2015-11-16||no||||45038|
|[v0.34.5](https://github.com/electron/electron/releases/tag/v0.34.5)|2015-11-26||no||||65484|
|[v0.34.4](https://github.com/electron/electron/releases/tag/v0.34.4)|2015-11-24||no|46|4.1.1|45.0.2454.85|14855|
|[v0.34.3](https://github.com/electron/electron/releases/tag/v0.34.3)|2015-11-06||no|46|4.1.1|45.0.2454.85|52195|
|[v0.34.2](https://github.com/electron/electron/releases/tag/v0.34.2)|2015-10-30||no|46|4.1.1|45.0.2454.85|38323|
|[v0.34.1](https://github.com/electron/electron/releases/tag/v0.34.1)|2015-10-23||no|46|4.1.1|45.0.2454.85|39299|
|[v0.34.0](https://github.com/electron/electron/releases/tag/v0.34.0)|2015-10-16||no|46|4.1.1|45.0.2454.85|118299|
|[v0.33.9](https://github.com/electron/electron/releases/tag/v0.33.9)|2015-10-16||no|46|4.1.1|45.0.2454.85|52499|
|[v0.33.8](https://github.com/electron/electron/releases/tag/v0.33.8)|2015-10-14||no|46|4.1.1|45.0.2454.85|15413|
|[v0.33.7](https://github.com/electron/electron/releases/tag/v0.33.7)|2015-10-10||no|46|4.1.1|45.0.2454.85|21798|
|[v0.33.6](https://github.com/electron/electron/releases/tag/v0.33.6)|2015-10-05||no|46|4.1.1|45.0.2454.85|23393|
|[v0.33.5](https://github.com/electron/electron/releases/tag/v0.33.5)|2015-10-05||no||||12374|
|[v0.33.4](https://github.com/electron/electron/releases/tag/v0.33.4)|2015-10-02||no|46|4.1.1|45.0.2454.85|17206|
|[v0.33.3](https://github.com/electron/electron/releases/tag/v0.33.3)|2015-09-26||no|46|4.1.1|45.0.2454.85|31059|
|[v0.33.2](https://github.com/electron/electron/releases/tag/v0.33.2)|2015-09-25||no|46|4.1.1|45.0.2454.85|13075|
|[v0.33.1](https://github.com/electron/electron/releases/tag/v0.33.1)|2015-09-22||no|46|4.1.1|45.0.2454.85|16412|
|[v0.33.0](https://github.com/electron/electron/releases/tag/v0.33.0)|2015-09-17||no|46|5.0.0-pre|45.0.2454.85|31527|
|[v0.32.3](https://github.com/electron/electron/releases/tag/v0.32.3)|2015-09-15||no|46|5.0.0-pre|45.0.2454.85|21019|
|[v0.32.2](https://github.com/electron/electron/releases/tag/v0.32.2)|2015-09-10||no|45|3.3.0|45.0.2454.85|15001|
|[v0.32.1](https://github.com/electron/electron/releases/tag/v0.32.1)|2015-09-09||no||||18165|
|[v0.32.0](https://github.com/electron/electron/releases/tag/v0.32.0)|2015-09-09||no||||1502|
|[v0.31.2](https://github.com/electron/electron/releases/tag/v0.31.2)|2015-09-02||no|45|3.3.0|45.0.2454.85|25653|
|[v0.31.1](https://github.com/electron/electron/releases/tag/v0.31.1)|2015-08-28||no||||9140|
|[v0.31.0](https://github.com/electron/electron/releases/tag/v0.31.0)|2015-08-26||no|45|3.1.0|44.0.2403.125|6369|
|[v0.30.8](https://github.com/electron/electron/releases/tag/v0.30.8)|2015-09-26||no||||156874|
|[v0.30.7](https://github.com/electron/electron/releases/tag/v0.30.7)|2015-09-24||no||||23471|
|[v0.30.6](https://github.com/electron/electron/releases/tag/v0.30.6)|2015-08-26||no||||10925|
|[v0.30.5](https://github.com/electron/electron/releases/tag/v0.30.5)|2015-08-21||no||||4092|
|[v0.30.4](https://github.com/electron/electron/releases/tag/v0.30.4)|2015-08-10||no|45|3.1.0|44.0.2403.125|15348|
|[v0.30.3](https://github.com/electron/electron/releases/tag/v0.30.3)|2015-08-07||no||||6387|
|[v0.30.2](https://github.com/electron/electron/releases/tag/v0.30.2)|2015-07-30||no||||25027|
|[v0.30.1](https://github.com/electron/electron/releases/tag/v0.30.1)|2015-07-24||no||||14671|
|[v0.30.0](https://github.com/electron/electron/releases/tag/v0.30.0)|2015-07-16||no||||30564|
|[v0.29.2](https://github.com/electron/electron/releases/tag/v0.29.2)|2015-07-07||no|44|2.3.1|43.0.2357.65|57265|
|[v0.29.1](https://github.com/electron/electron/releases/tag/v0.29.1)|2015-07-03||no|44|2.3.1|43.0.2357.65|3939|
|[v0.29.0](https://github.com/electron/electron/releases/tag/v0.29.0)|2015-07-03||no||||2316|
|[v0.28.3](https://github.com/electron/electron/releases/tag/v0.28.3)|2015-06-23||no|44|2.2.1|43.0.2357.65|26185|
|[v0.28.2](https://github.com/electron/electron/releases/tag/v0.28.2)|2015-06-18||no|44|2.2.1|43.0.2357.65|7239|
|[v0.28.1](https://github.com/electron/electron/releases/tag/v0.28.1)|2015-06-12||no|44|2.2.1|43.0.2357.65|8344|
|[v0.28.0](https://github.com/electron/electron/releases/tag/v0.28.0)|2015-06-11||no|44|2.2.1|43.0.2357.65|1288|
|[v0.27.3](https://github.com/electron/electron/releases/tag/v0.27.3)|2015-06-08||no|43|1.6.3|43.0.2357.65|15261|
|[v0.27.2](https://github.com/electron/electron/releases/tag/v0.27.2)|2015-06-01||no|43|1.6.3|43.0.2357.65|6678|
|[v0.27.1](https://github.com/electron/electron/releases/tag/v0.27.1)|2015-05-28||no|43|1.6.3|42.0.2311.107|3115|
|[v0.27.0](https://github.com/electron/electron/releases/tag/v0.27.0)|2015-05-27||no|43|1.6.3|42.0.2311.107|1491|
|[v0.26.1](https://github.com/electron/electron/releases/tag/v0.26.1)|2015-05-21||no|43|1.6.3|42.0.2311.107|12335|
|[v0.26.0](https://github.com/electron/electron/releases/tag/v0.26.0)|2015-05-12||no|43|1.6.3|42.0.2311.107|10967|
|[v0.25.3](https://github.com/electron/electron/releases/tag/v0.25.3)|2015-05-08||no|43|1.6.3|42.0.2311.107|16201|
|[v0.25.2](https://github.com/electron/electron/releases/tag/v0.25.2)|2015-05-01||no|43|1.6.3|42.0.2311.107|8420|
|[v0.25.1](https://github.com/electron/electron/releases/tag/v0.25.1)|2015-04-23||no|43|1.6.3|42.0.2311.107|15810|
|[v0.25.0](https://github.com/electron/electron/releases/tag/v0.25.0)|2015-04-22||no|43|1.6.3|42.0.2311.107|1710|
|[v0.24.0](https://github.com/electron/electron/releases/tag/v0.24.0)|2015-04-17||no|43|1.6.3|41.0.2272.76|8357|
|[v0.23.0](https://github.com/electron/electron/releases/tag/v0.23.0)|2015-04-12||no|43|1.6.3|41.0.2272.76|3100|
|[v0.22.3](https://github.com/electron/electron/releases/tag/v0.22.3)|2015-03-30||no|43|1.6.3|41.0.2272.76|40917|
|[v0.22.2](https://github.com/electron/electron/releases/tag/v0.22.2)|2015-03-23||no|43|1.5.1|41.0.2272.76|1633|
|[v0.22.1](https://github.com/electron/electron/releases/tag/v0.22.1)|2015-03-18||no|43|1.5.1|41.0.2272.76|4258|
|[v0.22.0](https://github.com/electron/electron/releases/tag/v0.22.0)|2015-03-18||no||||33557|
|[v0.21.3](https://github.com/electron/electron/releases/tag/v0.21.3)|2015-03-03||no|43|1.5.1|41.0.2272.76|8396|
|[v0.21.2](https://github.com/electron/electron/releases/tag/v0.21.2)|2015-02-05||no|41|1.0.0-pre|40.0.2214.91|4478|
|[v0.21.1](https://github.com/electron/electron/releases/tag/v0.21.1)|2015-02-03||no|41|1.0.0-pre|40.0.2214.91|1624|
|[v0.21.0](https://github.com/electron/electron/releases/tag/v0.21.0)|2015-01-28||no|41|1.0.0-pre|40.0.2214.91|13156|
|[v0.20.8](https://github.com/electron/electron/releases/tag/v0.20.8)|2015-01-27||no|17|0.13.0-pre|39.0.2171.65|316|
|[v0.20.7](https://github.com/electron/electron/releases/tag/v0.20.7)|2015-01-20||no|17|0.13.0-pre|39.0.2171.65|1887|
|[v0.20.6](https://github.com/electron/electron/releases/tag/v0.20.6)|2015-01-19||no|17|0.13.0-pre|39.0.2171.65|1511|
|[v0.20.5](https://github.com/electron/electron/releases/tag/v0.20.5)|2015-01-08||no|17|0.13.0-pre|39.0.2171.65|4702|
|[v0.20.4](https://github.com/electron/electron/releases/tag/v0.20.4)|2015-01-06||no|17|0.13.0-pre|39.0.2171.65|1464|
|[v0.20.3](https://github.com/electron/electron/releases/tag/v0.20.3)|2014-12-29||no|17|0.13.0-pre|39.0.2171.65|2948|
|[v0.20.2](https://github.com/electron/electron/releases/tag/v0.20.2)|2014-12-22||no|17|0.13.0-pre|39.0.2171.65|2689|
|[v0.20.1](https://github.com/electron/electron/releases/tag/v0.20.1)|2014-12-18||no|17|0.13.0-pre|39.0.2171.65|1315|
|[v0.20.0](https://github.com/electron/electron/releases/tag/v0.20.0)|2014-12-13||no|17|0.13.0-pre|39.0.2171.65|1172|
|[v0.19.5](https://github.com/electron/electron/releases/tag/v0.19.5)|2014-11-28||no||||7633|
|[v0.19.4](https://github.com/electron/electron/releases/tag/v0.19.4)|2014-11-21||no||||7482|
|[v0.19.3](https://github.com/electron/electron/releases/tag/v0.19.3)|2014-11-20||no||||388|
|[v0.19.2](https://github.com/electron/electron/releases/tag/v0.19.2)|2014-11-15||no||||2910|
|[v0.19.1](https://github.com/electron/electron/releases/tag/v0.19.1)|2014-11-04||no||||4259|
|[v0.19.0](https://github.com/electron/electron/releases/tag/v0.19.0)|2014-10-30||no||||1117|
|[v0.18.2](https://github.com/electron/electron/releases/tag/v0.18.2)|2014-10-21||no||||4464|
|[v0.18.1](https://github.com/electron/electron/releases/tag/v0.18.1)|2014-10-17||no||||2308|
|[v0.18.0](https://github.com/electron/electron/releases/tag/v0.18.0)|2014-10-14||no||||2090|
|[v0.17.2](https://github.com/electron/electron/releases/tag/v0.17.2)|2014-10-06||no||||1835|
|[v0.17.1](https://github.com/electron/electron/releases/tag/v0.17.1)|2014-10-01||no||||4117|
|[v0.17.0](https://github.com/electron/electron/releases/tag/v0.17.0)|2014-10-01||no||||365|
|[v0.16.3](https://github.com/electron/electron/releases/tag/v0.16.3)|2014-09-20||no||||1182|
|[v0.16.2](https://github.com/electron/electron/releases/tag/v0.16.2)|2014-09-09||no||||5565|
|[v0.16.1](https://github.com/electron/electron/releases/tag/v0.16.1)|2014-09-08||no||||497|
|[v0.16.0](https://github.com/electron/electron/releases/tag/v0.16.0)|2014-09-06||no||||464|
|[v0.15.9](https://github.com/electron/electron/releases/tag/v0.15.9)|2014-08-20||no||||6604|
|[v0.15.8](https://github.com/electron/electron/releases/tag/v0.15.8)|2014-08-18||no||||8117|
|[v0.15.7](https://github.com/electron/electron/releases/tag/v0.15.7)|2014-08-15||no||||9027|
|[v0.15.6](https://github.com/electron/electron/releases/tag/v0.15.6)|2014-08-13||no||||10361|
|[v0.15.5](https://github.com/electron/electron/releases/tag/v0.15.5)|2014-08-11||no||||8031|
|[v0.15.4](https://github.com/electron/electron/releases/tag/v0.15.4)|2014-08-07||no||||8412|
|[v0.15.3](https://github.com/electron/electron/releases/tag/v0.15.3)|2014-08-06||no||||10153|
|[v0.15.2](https://github.com/electron/electron/releases/tag/v0.15.2)|2014-08-04||no||||7899|
|[v0.15.1](https://github.com/electron/electron/releases/tag/v0.15.1)|2014-07-31||no||||8335|
|[v0.15.0](https://github.com/electron/electron/releases/tag/v0.15.0)|2014-07-29||no||||8075|
|[v0.14.3](https://github.com/electron/electron/releases/tag/v0.14.3)|2014-07-27||no||||7601|
|[v0.14.2](https://github.com/electron/electron/releases/tag/v0.14.2)|2014-07-25||no||||7431|
|[v0.14.1](https://github.com/electron/electron/releases/tag/v0.14.1)|2014-07-24||no||||7401|
|[v0.14.0](https://github.com/electron/electron/releases/tag/v0.14.0)|2014-07-22||no||||7648|
|[v0.13.3](https://github.com/electron/electron/releases/tag/v0.13.3)|2014-06-25||no||||15511|
|[v0.13.2](https://github.com/electron/electron/releases/tag/v0.13.2)|2014-06-18||no||||4122|
|[v0.13.1](https://github.com/electron/electron/releases/tag/v0.13.1)|2014-06-14||no||||2066|
|[v0.13.0](https://github.com/electron/electron/releases/tag/v0.13.0)|2014-06-05||no||||3911|
|[v0.12.7](https://github.com/electron/electron/releases/tag/v0.12.7)|2014-05-27||no||||4798|
|[v0.12.6](https://github.com/electron/electron/releases/tag/v0.12.6)|2014-05-26||no||||407|
|[v0.12.5](https://github.com/electron/electron/releases/tag/v0.12.5)|2014-05-19||no||||21262|
|[v0.12.4](https://github.com/electron/electron/releases/tag/v0.12.4)|2014-05-12||no||||20165|
|[v0.12.3](https://github.com/electron/electron/releases/tag/v0.12.3)|2014-05-07||no||||6478|
|[v0.12.2](https://github.com/electron/electron/releases/tag/v0.12.2)|2014-05-05||no||||5090|
|[v0.12.1](https://github.com/electron/electron/releases/tag/v0.12.1)|2014-05-05||no||||309|
|[v0.12.0](https://github.com/electron/electron/releases/tag/v0.12.0)|2014-04-29||no||||280|
|[v0.11.10](https://github.com/electron/electron/releases/tag/v0.11.10)|2014-04-14||no||||190|
|[v0.11.9](https://github.com/electron/electron/releases/tag/v0.11.9)|2014-04-11||no||||178|
|[v0.11.8](https://github.com/electron/electron/releases/tag/v0.11.8)|2014-04-10||no||||178|
|[v0.11.7](https://github.com/electron/electron/releases/tag/v0.11.7)|2014-04-08||no||||178|
|[v0.11.6](https://github.com/electron/electron/releases/tag/v0.11.6)|2014-04-07||no||||177|
|[v0.11.5](https://github.com/electron/electron/releases/tag/v0.11.5)|2014-04-02||no||||185|
|[v0.11.4](https://github.com/electron/electron/releases/tag/v0.11.4)|2014-03-28||no||||271|
|[v0.11.3](https://github.com/electron/electron/releases/tag/v0.11.3)|2014-03-25||no||||260|
|[v0.11.2](https://github.com/electron/electron/releases/tag/v0.11.2)|2014-03-24||no||||265|
|[v0.11.1](https://github.com/electron/electron/releases/tag/v0.11.1)|2014-03-18||no||||263|
|[v0.11.0](https://github.com/electron/electron/releases/tag/v0.11.0)|2014-03-16||no||||261|
|[v0.10.7](https://github.com/electron/electron/releases/tag/v0.10.7)|2014-03-11||no||||303|
|[v0.10.6](https://github.com/electron/electron/releases/tag/v0.10.6)|2014-03-07||no||||263|
|[v0.10.5](https://github.com/electron/electron/releases/tag/v0.10.5)|2014-03-05||no||||261|
|[v0.10.4](https://github.com/electron/electron/releases/tag/v0.10.4)|2014-03-02||no||||253|
|[v0.10.3](https://github.com/electron/electron/releases/tag/v0.10.3)|2014-02-28||no||||335|
|[v0.10.2](https://github.com/electron/electron/releases/tag/v0.10.2)|2014-02-27||no||||295|
|[v0.10.1](https://github.com/electron/electron/releases/tag/v0.10.1)|2014-02-25||no||||283|
|[v0.10.0](https://github.com/electron/electron/releases/tag/v0.10.0)|2014-02-24||no||||102|
|[v0.9.3](https://github.com/electron/electron/releases/tag/v0.9.3)|2014-02-17||no||||3723|
|[v0.9.2](https://github.com/electron/electron/releases/tag/v0.9.2)|2014-02-12||no||||3736|
|[v0.9.1](https://github.com/electron/electron/releases/tag/v0.9.1)|2014-02-04||no||||3724|
|[v0.9.0](https://github.com/electron/electron/releases/tag/v0.9.0)|2014-02-02||no||||3711|
|[v0.8.7](https://github.com/electron/electron/releases/tag/v0.8.7)|2014-01-27||no||||3746|
|[v0.8.6](https://github.com/electron/electron/releases/tag/v0.8.6)|2014-01-23||no||||3727|
|[v0.8.5](https://github.com/electron/electron/releases/tag/v0.8.5)|2014-01-14||no||||3754|
|[v0.8.4](https://github.com/electron/electron/releases/tag/v0.8.4)|2014-01-13||no||||3732|
|[v0.8.3](https://github.com/electron/electron/releases/tag/v0.8.3)|2014-01-08||no||||1865|
|[v0.8.2](https://github.com/electron/electron/releases/tag/v0.8.2)|2014-01-07||no||||3807|
|[v0.8.1](https://github.com/electron/electron/releases/tag/v0.8.1)|2013-12-29||no||||3747|
|[v0.8.0](https://github.com/electron/electron/releases/tag/v0.8.0)|2013-12-27||no||||1871|
|[v0.7.6](https://github.com/electron/electron/releases/tag/v0.7.6)|2013-12-09||no||||3824|
|[v0.7.5](https://github.com/electron/electron/releases/tag/v0.7.5)|2013-12-05||no||||3728|
|[v0.7.4](https://github.com/electron/electron/releases/tag/v0.7.4)|2013-12-04||no||||3806|
|[v0.7.3](https://github.com/electron/electron/releases/tag/v0.7.3)|2013-11-29||no||||3819|
|[v0.7.2](https://github.com/electron/electron/releases/tag/v0.7.2)|2013-11-28||no||||3767|
|[v0.7.1](https://github.com/electron/electron/releases/tag/v0.7.1)|2013-11-28||no||||3757|
|[v0.7.0](https://github.com/electron/electron/releases/tag/v0.7.0)|2013-11-27||no||||3744|
|[v0.6.12](https://github.com/electron/electron/releases/tag/v0.6.12)|2013-11-22||no||||1870|
|[v0.6.11](https://github.com/electron/electron/releases/tag/v0.6.11)|2013-11-20||no||||1871|
|[v0.6.10](https://github.com/electron/electron/releases/tag/v0.6.10)|2013-11-11||no||||1881|
|[v0.6.9](https://github.com/electron/electron/releases/tag/v0.6.9)|2013-11-07||no||||1874|
|[v0.6.8](https://github.com/electron/electron/releases/tag/v0.6.8)|2013-11-05||no||||1856|
|[v0.6.7](https://github.com/electron/electron/releases/tag/v0.6.7)|2013-11-02||no||||1865|
|[v0.6.6](https://github.com/electron/electron/releases/tag/v0.6.6)|2013-10-28||no||||1877|
|[v0.6.5](https://github.com/electron/electron/releases/tag/v0.6.5)|2013-10-26||no||||1832|
|[v0.6.4](https://github.com/electron/electron/releases/tag/v0.6.4)|2013-10-22||no||||1870|
|[v0.6.3](https://github.com/electron/electron/releases/tag/v0.6.3)|2013-10-21||no||||912|
|[v0.6.2](https://github.com/electron/electron/releases/tag/v0.6.2)|2013-10-17||no||||914|
|[v0.6.1](https://github.com/electron/electron/releases/tag/v0.6.1)|2013-10-14||no||||915|
|[v0.6.0](https://github.com/electron/electron/releases/tag/v0.6.0)|2013-10-10||no||||918|
|[v0.5.4](https://github.com/electron/electron/releases/tag/v0.5.4)|2013-10-04||no||||941|
|[v0.5.3](https://github.com/electron/electron/releases/tag/v0.5.3)|2013-09-29||no||||902|
|[v0.5.2](https://github.com/electron/electron/releases/tag/v0.5.2)|2013-09-29||no||||904|
|[v0.5.1](https://github.com/electron/electron/releases/tag/v0.5.1)|2013-09-26||no||||923|
|[v0.5.0](https://github.com/electron/electron/releases/tag/v0.5.0)|2013-09-25||no||||912|
|[v0.4.9](https://github.com/electron/electron/releases/tag/v0.4.9)|2013-09-20||no||||903|
|[v0.4.8](https://github.com/electron/electron/releases/tag/v0.4.8)|2013-09-20||no||||901|
|[v0.4.7](https://github.com/electron/electron/releases/tag/v0.4.7)|2013-09-13||no||||903|
|[v0.4.6](https://github.com/electron/electron/releases/tag/v0.4.6)|2013-09-12||no||||906|
|[v0.4.5](https://github.com/electron/electron/releases/tag/v0.4.5)|2013-09-09||no||||906|
|[v0.4.4](https://github.com/electron/electron/releases/tag/v0.4.4)|2013-09-05||no||||905|
|[v0.4.3](https://github.com/electron/electron/releases/tag/v0.4.3)|2013-09-02||no||||904|
|[v0.4.2](https://github.com/electron/electron/releases/tag/v0.4.2)|2013-09-02||no||||1830|
|[v0.4.1](https://github.com/electron/electron/releases/tag/v0.4.1)|2013-08-27||no||||0|
|[v0.4.0](https://github.com/electron/electron/releases/tag/v0.4.0)|2013-08-19||no||||0|
|[v0.3.5](https://github.com/electron/electron/releases/tag/v0.3.5)|2013-08-16||no||||0|
|[v0.3.4](https://github.com/electron/electron/releases/tag/v0.3.4)|2013-08-15||no||||0|
|[v0.3.3](https://github.com/electron/electron/releases/tag/v0.3.3)|2013-08-15||no||||0|
|[v0.3.2](https://github.com/electron/electron/releases/tag/v0.3.2)|2013-08-13||no||||0|
|[v0.3.1](https://github.com/electron/electron/releases/tag/v0.3.1)|2013-08-12||no||||0|

<!-- END RELEASES TABLE -->
